/****************************************************************************
** Meta object code from reading C++ file 'katefiletree.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/filetree/katefiletree.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katefiletree.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateFileTree_t {
    QByteArrayData data[38];
    char stringdata0[586];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateFileTree_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateFileTree_t qt_meta_stringdata_KateFileTree = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KateFileTree"
QT_MOC_LITERAL(1, 13, 13), // "closeDocument"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(4, 51, 16), // "activateDocument"
QT_MOC_LITERAL(5, 68, 12), // "openDocument"
QT_MOC_LITERAL(6, 81, 15), // "viewModeChanged"
QT_MOC_LITERAL(7, 97, 8), // "treeMode"
QT_MOC_LITERAL(8, 106, 15), // "sortRoleChanged"
QT_MOC_LITERAL(9, 122, 17), // "slotDocumentClose"
QT_MOC_LITERAL(10, 140, 19), // "slotExpandRecursive"
QT_MOC_LITERAL(11, 160, 21), // "slotCollapseRecursive"
QT_MOC_LITERAL(12, 182, 22), // "slotDocumentCloseOther"
QT_MOC_LITERAL(13, 205, 18), // "slotDocumentReload"
QT_MOC_LITERAL(14, 224, 16), // "slotCopyFilename"
QT_MOC_LITERAL(15, 241, 18), // "slotCurrentChanged"
QT_MOC_LITERAL(16, 260, 7), // "current"
QT_MOC_LITERAL(17, 268, 8), // "previous"
QT_MOC_LITERAL(18, 277, 17), // "slotDocumentFirst"
QT_MOC_LITERAL(19, 295, 16), // "slotDocumentLast"
QT_MOC_LITERAL(20, 312, 16), // "slotDocumentNext"
QT_MOC_LITERAL(21, 329, 16), // "slotDocumentPrev"
QT_MOC_LITERAL(22, 346, 17), // "slotPrintDocument"
QT_MOC_LITERAL(23, 364, 24), // "slotPrintDocumentPreview"
QT_MOC_LITERAL(24, 389, 16), // "slotResetHistory"
QT_MOC_LITERAL(25, 406, 18), // "slotDocumentDelete"
QT_MOC_LITERAL(26, 425, 12), // "mouseClicked"
QT_MOC_LITERAL(27, 438, 5), // "index"
QT_MOC_LITERAL(28, 444, 12), // "slotTreeMode"
QT_MOC_LITERAL(29, 457, 12), // "slotListMode"
QT_MOC_LITERAL(30, 470, 12), // "slotSortName"
QT_MOC_LITERAL(31, 483, 12), // "slotSortPath"
QT_MOC_LITERAL(32, 496, 20), // "slotSortOpeningOrder"
QT_MOC_LITERAL(33, 517, 19), // "slotFixOpenWithMenu"
QT_MOC_LITERAL(34, 537, 22), // "slotOpenWithMenuAction"
QT_MOC_LITERAL(35, 560, 8), // "QAction*"
QT_MOC_LITERAL(36, 569, 1), // "a"
QT_MOC_LITERAL(37, 571, 14) // "slotRenameFile"

    },
    "KateFileTree\0closeDocument\0\0"
    "KTextEditor::Document*\0activateDocument\0"
    "openDocument\0viewModeChanged\0treeMode\0"
    "sortRoleChanged\0slotDocumentClose\0"
    "slotExpandRecursive\0slotCollapseRecursive\0"
    "slotDocumentCloseOther\0slotDocumentReload\0"
    "slotCopyFilename\0slotCurrentChanged\0"
    "current\0previous\0slotDocumentFirst\0"
    "slotDocumentLast\0slotDocumentNext\0"
    "slotDocumentPrev\0slotPrintDocument\0"
    "slotPrintDocumentPreview\0slotResetHistory\0"
    "slotDocumentDelete\0mouseClicked\0index\0"
    "slotTreeMode\0slotListMode\0slotSortName\0"
    "slotSortPath\0slotSortOpeningOrder\0"
    "slotFixOpenWithMenu\0slotOpenWithMenuAction\0"
    "QAction*\0a\0slotRenameFile"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateFileTree[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  159,    2, 0x06 /* Public */,
       4,    1,  162,    2, 0x06 /* Public */,
       5,    1,  165,    2, 0x06 /* Public */,
       6,    1,  168,    2, 0x06 /* Public */,
       8,    1,  171,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,  174,    2, 0x0a /* Public */,
      10,    0,  175,    2, 0x0a /* Public */,
      11,    0,  176,    2, 0x0a /* Public */,
      12,    0,  177,    2, 0x0a /* Public */,
      13,    0,  178,    2, 0x0a /* Public */,
      14,    0,  179,    2, 0x0a /* Public */,
      15,    2,  180,    2, 0x0a /* Public */,
      18,    0,  185,    2, 0x0a /* Public */,
      19,    0,  186,    2, 0x0a /* Public */,
      20,    0,  187,    2, 0x0a /* Public */,
      21,    0,  188,    2, 0x0a /* Public */,
      22,    0,  189,    2, 0x0a /* Public */,
      23,    0,  190,    2, 0x0a /* Public */,
      24,    0,  191,    2, 0x0a /* Public */,
      25,    0,  192,    2, 0x0a /* Public */,
      26,    1,  193,    2, 0x08 /* Private */,
      28,    0,  196,    2, 0x08 /* Private */,
      29,    0,  197,    2, 0x08 /* Private */,
      30,    0,  198,    2, 0x08 /* Private */,
      31,    0,  199,    2, 0x08 /* Private */,
      32,    0,  200,    2, 0x08 /* Private */,
      33,    0,  201,    2, 0x08 /* Private */,
      34,    1,  202,    2, 0x08 /* Private */,
      37,    0,  205,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,   16,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35,   36,
    QMetaType::Void,

       0        // eod
};

void KateFileTree::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateFileTree *_t = static_cast<KateFileTree *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->closeDocument((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 1: _t->activateDocument((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->openDocument((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 3: _t->viewModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->sortRoleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->slotDocumentClose(); break;
        case 6: _t->slotExpandRecursive(); break;
        case 7: _t->slotCollapseRecursive(); break;
        case 8: _t->slotDocumentCloseOther(); break;
        case 9: _t->slotDocumentReload(); break;
        case 10: _t->slotCopyFilename(); break;
        case 11: _t->slotCurrentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 12: _t->slotDocumentFirst(); break;
        case 13: _t->slotDocumentLast(); break;
        case 14: _t->slotDocumentNext(); break;
        case 15: _t->slotDocumentPrev(); break;
        case 16: _t->slotPrintDocument(); break;
        case 17: _t->slotPrintDocumentPreview(); break;
        case 18: _t->slotResetHistory(); break;
        case 19: _t->slotDocumentDelete(); break;
        case 20: _t->mouseClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 21: _t->slotTreeMode(); break;
        case 22: _t->slotListMode(); break;
        case 23: _t->slotSortName(); break;
        case 24: _t->slotSortPath(); break;
        case 25: _t->slotSortOpeningOrder(); break;
        case 26: _t->slotFixOpenWithMenu(); break;
        case 27: _t->slotOpenWithMenuAction((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 28: _t->slotRenameFile(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateFileTree::*_t)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateFileTree::closeDocument)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateFileTree::*_t)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateFileTree::activateDocument)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KateFileTree::*_t)(QUrl );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateFileTree::openDocument)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KateFileTree::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateFileTree::viewModeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KateFileTree::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateFileTree::sortRoleChanged)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject KateFileTree::staticMetaObject = {
    { &QTreeView::staticMetaObject, qt_meta_stringdata_KateFileTree.data,
      qt_meta_data_KateFileTree,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateFileTree::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateFileTree::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateFileTree.stringdata0))
        return static_cast<void*>(const_cast< KateFileTree*>(this));
    return QTreeView::qt_metacast(_clname);
}

int KateFileTree::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void KateFileTree::closeDocument(KTextEditor::Document * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateFileTree::activateDocument(KTextEditor::Document * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KateFileTree::openDocument(QUrl _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KateFileTree::viewModeChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KateFileTree::sortRoleChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_END_MOC_NAMESPACE
