/****************************************************************************
** Meta object code from reading C++ file 'debugview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/gdbplugin/debugview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'debugview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_DebugView_t {
    QByteArrayData data[41];
    char stringdata0[482];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DebugView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DebugView_t qt_meta_stringdata_DebugView = {
    {
QT_MOC_LITERAL(0, 0, 9), // "DebugView"
QT_MOC_LITERAL(1, 10, 20), // "debugLocationChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 4), // "file"
QT_MOC_LITERAL(4, 37, 7), // "lineNum"
QT_MOC_LITERAL(5, 45, 13), // "breakPointSet"
QT_MOC_LITERAL(6, 59, 17), // "breakPointCleared"
QT_MOC_LITERAL(7, 77, 20), // "clearBreakpointMarks"
QT_MOC_LITERAL(8, 98, 14), // "stackFrameInfo"
QT_MOC_LITERAL(9, 113, 5), // "level"
QT_MOC_LITERAL(10, 119, 4), // "info"
QT_MOC_LITERAL(11, 124, 17), // "stackFrameChanged"
QT_MOC_LITERAL(12, 142, 10), // "threadInfo"
QT_MOC_LITERAL(13, 153, 6), // "number"
QT_MOC_LITERAL(14, 160, 6), // "avtive"
QT_MOC_LITERAL(15, 167, 9), // "infoLocal"
QT_MOC_LITERAL(16, 177, 4), // "line"
QT_MOC_LITERAL(17, 182, 10), // "outputText"
QT_MOC_LITERAL(18, 193, 4), // "text"
QT_MOC_LITERAL(19, 198, 11), // "outputError"
QT_MOC_LITERAL(20, 210, 13), // "readyForInput"
QT_MOC_LITERAL(21, 224, 5), // "ready"
QT_MOC_LITERAL(22, 230, 12), // "programEnded"
QT_MOC_LITERAL(23, 243, 8), // "gdbEnded"
QT_MOC_LITERAL(24, 252, 13), // "slotInterrupt"
QT_MOC_LITERAL(25, 266, 12), // "slotStepInto"
QT_MOC_LITERAL(26, 279, 12), // "slotStepOver"
QT_MOC_LITERAL(27, 292, 11), // "slotStepOut"
QT_MOC_LITERAL(28, 304, 12), // "slotContinue"
QT_MOC_LITERAL(29, 317, 8), // "slotKill"
QT_MOC_LITERAL(30, 326, 9), // "slotReRun"
QT_MOC_LITERAL(31, 336, 15), // "slotQueryLocals"
QT_MOC_LITERAL(32, 352, 7), // "display"
QT_MOC_LITERAL(33, 360, 9), // "slotError"
QT_MOC_LITERAL(34, 370, 19), // "slotReadDebugStdOut"
QT_MOC_LITERAL(35, 390, 19), // "slotReadDebugStdErr"
QT_MOC_LITERAL(36, 410, 17), // "slotDebugFinished"
QT_MOC_LITERAL(37, 428, 8), // "exitCode"
QT_MOC_LITERAL(38, 437, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(39, 458, 6), // "status"
QT_MOC_LITERAL(40, 465, 16) // "issueNextCommand"

    },
    "DebugView\0debugLocationChanged\0\0file\0"
    "lineNum\0breakPointSet\0breakPointCleared\0"
    "clearBreakpointMarks\0stackFrameInfo\0"
    "level\0info\0stackFrameChanged\0threadInfo\0"
    "number\0avtive\0infoLocal\0line\0outputText\0"
    "text\0outputError\0readyForInput\0ready\0"
    "programEnded\0gdbEnded\0slotInterrupt\0"
    "slotStepInto\0slotStepOver\0slotStepOut\0"
    "slotContinue\0slotKill\0slotReRun\0"
    "slotQueryLocals\0display\0slotError\0"
    "slotReadDebugStdOut\0slotReadDebugStdErr\0"
    "slotDebugFinished\0exitCode\0"
    "QProcess::ExitStatus\0status\0"
    "issueNextCommand"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DebugView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      26,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      13,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  144,    2, 0x06 /* Public */,
       5,    2,  149,    2, 0x06 /* Public */,
       6,    2,  154,    2, 0x06 /* Public */,
       7,    0,  159,    2, 0x06 /* Public */,
       8,    2,  160,    2, 0x06 /* Public */,
      11,    1,  165,    2, 0x06 /* Public */,
      12,    2,  168,    2, 0x06 /* Public */,
      15,    1,  173,    2, 0x06 /* Public */,
      17,    1,  176,    2, 0x06 /* Public */,
      19,    1,  179,    2, 0x06 /* Public */,
      20,    1,  182,    2, 0x06 /* Public */,
      22,    0,  185,    2, 0x06 /* Public */,
      23,    0,  186,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      24,    0,  187,    2, 0x0a /* Public */,
      25,    0,  188,    2, 0x0a /* Public */,
      26,    0,  189,    2, 0x0a /* Public */,
      27,    0,  190,    2, 0x0a /* Public */,
      28,    0,  191,    2, 0x0a /* Public */,
      29,    0,  192,    2, 0x0a /* Public */,
      30,    0,  193,    2, 0x0a /* Public */,
      31,    1,  194,    2, 0x0a /* Public */,
      33,    0,  197,    2, 0x08 /* Private */,
      34,    0,  198,    2, 0x08 /* Private */,
      35,    0,  199,    2, 0x08 /* Private */,
      36,    2,  200,    2, 0x08 /* Private */,
      40,    0,  205,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl, QMetaType::Int,    3,    4,
    QMetaType::Void, QMetaType::QUrl, QMetaType::Int,    3,    4,
    QMetaType::Void, QMetaType::QUrl, QMetaType::Int,    3,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    9,   10,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   13,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   32,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 38,   37,   39,
    QMetaType::Void,

       0        // eod
};

void DebugView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DebugView *_t = static_cast<DebugView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->debugLocationChanged((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->breakPointSet((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->breakPointCleared((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->clearBreakpointMarks(); break;
        case 4: _t->stackFrameInfo((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->stackFrameChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->threadInfo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 7: _t->infoLocal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->outputText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->outputError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->readyForInput((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->programEnded(); break;
        case 12: _t->gdbEnded(); break;
        case 13: _t->slotInterrupt(); break;
        case 14: _t->slotStepInto(); break;
        case 15: _t->slotStepOver(); break;
        case 16: _t->slotStepOut(); break;
        case 17: _t->slotContinue(); break;
        case 18: _t->slotKill(); break;
        case 19: _t->slotReRun(); break;
        case 20: _t->slotQueryLocals((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->slotError(); break;
        case 22: _t->slotReadDebugStdOut(); break;
        case 23: _t->slotReadDebugStdErr(); break;
        case 24: _t->slotDebugFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 25: _t->issueNextCommand(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (DebugView::*_t)(const QUrl & , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::debugLocationChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(const QUrl & , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::breakPointSet)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(const QUrl & , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::breakPointCleared)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::clearBreakpointMarks)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(QString const & , QString const & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::stackFrameInfo)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::stackFrameChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(int , bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::threadInfo)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(QString const & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::infoLocal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::outputText)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::outputError)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::readyForInput)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::programEnded)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (DebugView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DebugView::gdbEnded)) {
                *result = 12;
                return;
            }
        }
    }
}

const QMetaObject DebugView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_DebugView.data,
      qt_meta_data_DebugView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *DebugView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DebugView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_DebugView.stringdata0))
        return static_cast<void*>(const_cast< DebugView*>(this));
    return QObject::qt_metacast(_clname);
}

int DebugView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void DebugView::debugLocationChanged(const QUrl & _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DebugView::breakPointSet(const QUrl & _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DebugView::breakPointCleared(const QUrl & _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DebugView::clearBreakpointMarks()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void DebugView::stackFrameInfo(QString const & _t1, QString const & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DebugView::stackFrameChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void DebugView::threadInfo(int _t1, bool _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void DebugView::infoLocal(QString const & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void DebugView::outputText(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void DebugView::outputError(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void DebugView::readyForInput(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void DebugView::programEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 11, Q_NULLPTR);
}

// SIGNAL 12
void DebugView::gdbEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 12, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
