/****************************************************************************
** Meta object code from reading C++ file 'kateappadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/kateappadaptor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateappadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateAppAdaptor_t {
    QByteArrayData data[23];
    char stringdata0[244];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateAppAdaptor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateAppAdaptor_t qt_meta_stringdata_KateAppAdaptor = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KateAppAdaptor"
QT_MOC_LITERAL(1, 15, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 31, 24), // "org.kde.Kate.Application"
QT_MOC_LITERAL(3, 56, 7), // "exiting"
QT_MOC_LITERAL(4, 64, 0), // ""
QT_MOC_LITERAL(5, 65, 14), // "documentClosed"
QT_MOC_LITERAL(6, 80, 5), // "token"
QT_MOC_LITERAL(7, 86, 7), // "openUrl"
QT_MOC_LITERAL(8, 94, 3), // "url"
QT_MOC_LITERAL(9, 98, 8), // "encoding"
QT_MOC_LITERAL(10, 107, 12), // "tokenOpenUrl"
QT_MOC_LITERAL(11, 120, 10), // "isTempFile"
QT_MOC_LITERAL(12, 131, 14), // "tokenOpenUrlAt"
QT_MOC_LITERAL(13, 146, 4), // "line"
QT_MOC_LITERAL(14, 151, 6), // "column"
QT_MOC_LITERAL(15, 158, 9), // "setCursor"
QT_MOC_LITERAL(16, 168, 9), // "openInput"
QT_MOC_LITERAL(17, 178, 4), // "text"
QT_MOC_LITERAL(18, 183, 15), // "activateSession"
QT_MOC_LITERAL(19, 199, 7), // "session"
QT_MOC_LITERAL(20, 207, 13), // "desktopNumber"
QT_MOC_LITERAL(21, 221, 8), // "activate"
QT_MOC_LITERAL(22, 230, 13) // "activeSession"

    },
    "KateAppAdaptor\0D-Bus Interface\0"
    "org.kde.Kate.Application\0exiting\0\0"
    "documentClosed\0token\0openUrl\0url\0"
    "encoding\0tokenOpenUrl\0isTempFile\0"
    "tokenOpenUrlAt\0line\0column\0setCursor\0"
    "openInput\0text\0activateSession\0session\0"
    "desktopNumber\0activate\0activeSession"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateAppAdaptor[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      12,   16, // methods
       1,  130, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   76,    4, 0x06 /* Public */,
       5,    1,   77,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    2,   80,    4, 0x0a /* Public */,
      10,    2,   85,    4, 0x0a /* Public */,
       7,    3,   90,    4, 0x0a /* Public */,
      10,    3,   97,    4, 0x0a /* Public */,
      12,    5,  104,    4, 0x0a /* Public */,
      15,    2,  115,    4, 0x0a /* Public */,
      16,    2,  120,    4, 0x0a /* Public */,
      18,    1,  125,    4, 0x0a /* Public */,
      20,    0,  128,    4, 0x0a /* Public */,
      21,    0,  129,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    6,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,    8,    9,
    QMetaType::QString, QMetaType::QString, QMetaType::QString,    8,    9,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString, QMetaType::Bool,    8,    9,   11,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,    8,    9,   11,
    QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Bool,    8,   13,   14,    9,   11,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   13,   14,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,   17,    9,
    QMetaType::Bool, QMetaType::QString,   19,
    QMetaType::Int,
    QMetaType::Void,

 // properties: name, type, flags
      22, QMetaType::QString, 0x00095001,

       0        // eod
};

void KateAppAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateAppAdaptor *_t = static_cast<KateAppAdaptor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->exiting(); break;
        case 1: _t->documentClosed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: { bool _r = _t->openUrl((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 3: { QString _r = _t->tokenOpenUrl((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 4: { bool _r = _t->openUrl((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 5: { QString _r = _t->tokenOpenUrl((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 6: { QString _r = _t->tokenOpenUrlAt((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 7: { bool _r = _t->setCursor((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 8: { bool _r = _t->openInput((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 9: { bool _r = _t->activateSession((*reinterpret_cast< QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 10: { int _r = _t->desktopNumber();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 11: _t->activate(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateAppAdaptor::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateAppAdaptor::exiting)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateAppAdaptor::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateAppAdaptor::documentClosed)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KateAppAdaptor *_t = static_cast<KateAppAdaptor *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->activeSession(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KateAppAdaptor::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_KateAppAdaptor.data,
      qt_meta_data_KateAppAdaptor,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateAppAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateAppAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateAppAdaptor.stringdata0))
        return static_cast<void*>(const_cast< KateAppAdaptor*>(this));
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KateAppAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KateAppAdaptor::exiting()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void KateAppAdaptor::documentClosed(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_END_MOC_NAMESPACE
