/****************************************************************************
** Meta object code from reading C++ file 'plugin_katesymbolviewer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/symbolviewer/plugin_katesymbolviewer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin_katesymbolviewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KatePluginSymbolViewerConfigPage_t {
    QByteArrayData data[5];
    char stringdata0[113];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginSymbolViewerConfigPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginSymbolViewerConfigPage_t qt_meta_stringdata_KatePluginSymbolViewerConfigPage = {
    {
QT_MOC_LITERAL(0, 0, 32), // "KatePluginSymbolViewerConfigPage"
QT_MOC_LITERAL(1, 33, 22), // "configPageApplyRequest"
QT_MOC_LITERAL(2, 56, 0), // ""
QT_MOC_LITERAL(3, 57, 33), // "KatePluginSymbolViewerConfigP..."
QT_MOC_LITERAL(4, 91, 21) // "configPageInitRequest"

    },
    "KatePluginSymbolViewerConfigPage\0"
    "configPageApplyRequest\0\0"
    "KatePluginSymbolViewerConfigPage*\0"
    "configPageInitRequest"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginSymbolViewerConfigPage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x06 /* Public */,
       4,    1,   27,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,

       0        // eod
};

void KatePluginSymbolViewerConfigPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KatePluginSymbolViewerConfigPage *_t = static_cast<KatePluginSymbolViewerConfigPage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->configPageApplyRequest((*reinterpret_cast< KatePluginSymbolViewerConfigPage*(*)>(_a[1]))); break;
        case 1: _t->configPageInitRequest((*reinterpret_cast< KatePluginSymbolViewerConfigPage*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KatePluginSymbolViewerConfigPage* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KatePluginSymbolViewerConfigPage* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KatePluginSymbolViewerConfigPage::*_t)(KatePluginSymbolViewerConfigPage * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KatePluginSymbolViewerConfigPage::configPageApplyRequest)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KatePluginSymbolViewerConfigPage::*_t)(KatePluginSymbolViewerConfigPage * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KatePluginSymbolViewerConfigPage::configPageInitRequest)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KatePluginSymbolViewerConfigPage::staticMetaObject = {
    { &KTextEditor::ConfigPage::staticMetaObject, qt_meta_stringdata_KatePluginSymbolViewerConfigPage.data,
      qt_meta_data_KatePluginSymbolViewerConfigPage,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginSymbolViewerConfigPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginSymbolViewerConfigPage::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginSymbolViewerConfigPage.stringdata0))
        return static_cast<void*>(const_cast< KatePluginSymbolViewerConfigPage*>(this));
    return KTextEditor::ConfigPage::qt_metacast(_clname);
}

int KatePluginSymbolViewerConfigPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::ConfigPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KatePluginSymbolViewerConfigPage::configPageApplyRequest(KatePluginSymbolViewerConfigPage * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KatePluginSymbolViewerConfigPage::configPageInitRequest(KatePluginSymbolViewerConfigPage * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_KatePluginSymbolViewerView_t {
    QByteArrayData data[20];
    char stringdata0[299];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginSymbolViewerView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginSymbolViewerView_t qt_meta_stringdata_KatePluginSymbolViewerView = {
    {
QT_MOC_LITERAL(0, 0, 26), // "KatePluginSymbolViewerView"
QT_MOC_LITERAL(1, 27, 17), // "slotRefreshSymbol"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 14), // "slotChangeMode"
QT_MOC_LITERAL(4, 61, 17), // "slotEnableSorting"
QT_MOC_LITERAL(5, 79, 14), // "slotDocChanged"
QT_MOC_LITERAL(6, 94, 10), // "goToSymbol"
QT_MOC_LITERAL(7, 105, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(8, 122, 19), // "slotShowContextMenu"
QT_MOC_LITERAL(9, 142, 16), // "toggleShowMacros"
QT_MOC_LITERAL(10, 159, 20), // "toggleShowStructures"
QT_MOC_LITERAL(11, 180, 19), // "toggleShowFunctions"
QT_MOC_LITERAL(12, 200, 21), // "cursorPositionChanged"
QT_MOC_LITERAL(13, 222, 12), // "newActveItem"
QT_MOC_LITERAL(14, 235, 4), // "int&"
QT_MOC_LITERAL(15, 240, 11), // "currMinLine"
QT_MOC_LITERAL(16, 252, 8), // "currLine"
QT_MOC_LITERAL(17, 261, 4), // "item"
QT_MOC_LITERAL(18, 266, 18), // "updateCurrTreeItem"
QT_MOC_LITERAL(19, 285, 13) // "slotDocEdited"

    },
    "KatePluginSymbolViewerView\0slotRefreshSymbol\0"
    "\0slotChangeMode\0slotEnableSorting\0"
    "slotDocChanged\0goToSymbol\0QTreeWidgetItem*\0"
    "slotShowContextMenu\0toggleShowMacros\0"
    "toggleShowStructures\0toggleShowFunctions\0"
    "cursorPositionChanged\0newActveItem\0"
    "int&\0currMinLine\0currLine\0item\0"
    "updateCurrTreeItem\0slotDocEdited"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginSymbolViewerView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x0a /* Public */,
       3,    0,   80,    2, 0x0a /* Public */,
       4,    0,   81,    2, 0x0a /* Public */,
       5,    0,   82,    2, 0x0a /* Public */,
       6,    1,   83,    2, 0x0a /* Public */,
       8,    1,   86,    2, 0x0a /* Public */,
       9,    0,   89,    2, 0x0a /* Public */,
      10,    0,   90,    2, 0x0a /* Public */,
      11,    0,   91,    2, 0x0a /* Public */,
      12,    0,   92,    2, 0x0a /* Public */,
      13,    3,   93,    2, 0x0a /* Public */,
      18,    0,  100,    2, 0x0a /* Public */,
      19,    0,  101,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,    2,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 7, 0x80000000 | 14, QMetaType::Int, 0x80000000 | 7,   15,   16,   17,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KatePluginSymbolViewerView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KatePluginSymbolViewerView *_t = static_cast<KatePluginSymbolViewerView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotRefreshSymbol(); break;
        case 1: _t->slotChangeMode(); break;
        case 2: _t->slotEnableSorting(); break;
        case 3: _t->slotDocChanged(); break;
        case 4: _t->goToSymbol((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 5: _t->slotShowContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 6: _t->toggleShowMacros(); break;
        case 7: _t->toggleShowStructures(); break;
        case 8: _t->toggleShowFunctions(); break;
        case 9: _t->cursorPositionChanged(); break;
        case 10: { QTreeWidgetItem* _r = _t->newActveItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QTreeWidgetItem*(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QTreeWidgetItem**>(_a[0]) = _r; }  break;
        case 11: _t->updateCurrTreeItem(); break;
        case 12: _t->slotDocEdited(); break;
        default: ;
        }
    }
}

const QMetaObject KatePluginSymbolViewerView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KatePluginSymbolViewerView.data,
      qt_meta_data_KatePluginSymbolViewerView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginSymbolViewerView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginSymbolViewerView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginSymbolViewerView.stringdata0))
        return static_cast<void*>(const_cast< KatePluginSymbolViewerView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KatePluginSymbolViewerView*>(this));
    return QObject::qt_metacast(_clname);
}

int KatePluginSymbolViewerView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
struct qt_meta_stringdata_KatePluginSymbolViewer_t {
    QByteArrayData data[5];
    char stringdata0[72];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginSymbolViewer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginSymbolViewer_t qt_meta_stringdata_KatePluginSymbolViewer = {
    {
QT_MOC_LITERAL(0, 0, 22), // "KatePluginSymbolViewer"
QT_MOC_LITERAL(1, 23, 11), // "applyConfig"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 33), // "KatePluginSymbolViewerConfigP..."
QT_MOC_LITERAL(4, 70, 1) // "p"

    },
    "KatePluginSymbolViewer\0applyConfig\0\0"
    "KatePluginSymbolViewerConfigPage*\0p"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginSymbolViewer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void KatePluginSymbolViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KatePluginSymbolViewer *_t = static_cast<KatePluginSymbolViewer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->applyConfig((*reinterpret_cast< KatePluginSymbolViewerConfigPage*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KatePluginSymbolViewerConfigPage* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KatePluginSymbolViewer::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KatePluginSymbolViewer.data,
      qt_meta_data_KatePluginSymbolViewer,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginSymbolViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginSymbolViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginSymbolViewer.stringdata0))
        return static_cast<void*>(const_cast< KatePluginSymbolViewer*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KatePluginSymbolViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
