#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'config.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIG_H
#define UI_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_tabWidget
{
public:
    QWidget *run;
    QFormLayout *formLayout;
    QLabel *label_34;
    QSpinBox *runTime;
    QLabel *label_35;
    QSpinBox *probeLevel;
    QLabel *userOpsLabel;
    KUrlRequester *userModulePath;
    QLabel *userClassLabel;
    KUrlRequester *userClassPath;
    QLabel *label_3;
    QSpinBox *basePeriod;
    QLabel *label_4;
    QSpinBox *reductionCoreCount;
    QLabel *label_5;
    QSpinBox *timeCoreCount;
    QWidget *system;
    QFormLayout *formLayout_2;
    QLabel *label_6;
    QDoubleSpinBox *modelInertiaSuccessRate;
    QLabel *label_7;
    QSpinBox *modelInertiacount;
    QLabel *label_8;
    QDoubleSpinBox *tpxDeltaSuccessRate;
    QLabel *label_9;
    QSpinBox *minSimTimeHoriz;
    QLabel *label_10;
    QSpinBox *maxSimTimeHoriz;
    QLabel *label_11;
    QDoubleSpinBox *simTimeHoriz;
    QLabel *label_12;
    QSpinBox *tpxTimeHoriz;
    QLabel *label_13;
    QSpinBox *perfSamplePeriod;
    QLabel *label_14;
    QDoubleSpinBox *floatTolerance;
    QLabel *label_15;
    QSpinBox *timerTolerance;
    QLabel *label_16;
    QSpinBox *primaryTimeHoriz;
    QLabel *label_17;
    QSpinBox *secondaryTimeHoriz;
    QLabel *label_18;
    QSpinBox *notifMarkerRes;
    QLabel *label_19;
    QSpinBox *goalPredSuccessRes;
    QWidget *debugtab;
    QFormLayout *formLayout_3;
    QLabel *label_22;
    QCheckBox *debug;
    QLabel *label_23;
    QSpinBox *debugWindows;
    QLabel *label_24;
    QCheckBox *traceCompInputs;
    QCheckBox *traceCompOutputs;
    QCheckBox *traceModelIn;
    QCheckBox *traceModelOut;
    QCheckBox *tracePredMon;
    QCheckBox *traceGoalMon;
    QCheckBox *traceModelRev;
    QCheckBox *traceModComInj;
    QLabel *label_21;
    QCheckBox *decompileObjects;
    QLabel *decompileFileLabel;
    KUrlRequester *decObjFile;
    QLabel *label_26;
    QCheckBox *ignoreNamedObj;
    QLabel *label_27;
    KUrlRequester *dumpObjFile;
    QLabel *label_28;
    QCheckBox *testObj;
    QLabel *label_30;
    QCheckBox *decompileModels;
    QLabel *label_31;
    QCheckBox *ignoreNamedModels;
    QLabel *dumpFileLabel;
    KUrlRequester *dumpModelsFile;
    QLabel *label_33;
    QCheckBox *testModels;

    void setupUi(QTabWidget *tabWidget)
    {
        if (tabWidget->objectName().isEmpty())
            tabWidget->setObjectName(QStringLiteral("tabWidget"));
        tabWidget->resize(461, 530);
        run = new QWidget();
        run->setObjectName(QStringLiteral("run"));
        formLayout = new QFormLayout(run);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        label_34 = new QLabel(run);
        label_34->setObjectName(QStringLiteral("label_34"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label_34);

        runTime = new QSpinBox(run);
        runTime->setObjectName(QStringLiteral("runTime"));
        runTime->setMaximum(2147483647);

        formLayout->setWidget(0, QFormLayout::FieldRole, runTime);

        label_35 = new QLabel(run);
        label_35->setObjectName(QStringLiteral("label_35"));

        formLayout->setWidget(1, QFormLayout::LabelRole, label_35);

        probeLevel = new QSpinBox(run);
        probeLevel->setObjectName(QStringLiteral("probeLevel"));
        probeLevel->setMaximum(2147483647);

        formLayout->setWidget(1, QFormLayout::FieldRole, probeLevel);

        userOpsLabel = new QLabel(run);
        userOpsLabel->setObjectName(QStringLiteral("userOpsLabel"));

        formLayout->setWidget(2, QFormLayout::LabelRole, userOpsLabel);

        userModulePath = new KUrlRequester(run);
        userModulePath->setObjectName(QStringLiteral("userModulePath"));

        formLayout->setWidget(2, QFormLayout::FieldRole, userModulePath);

        userClassLabel = new QLabel(run);
        userClassLabel->setObjectName(QStringLiteral("userClassLabel"));

        formLayout->setWidget(3, QFormLayout::LabelRole, userClassLabel);

        userClassPath = new KUrlRequester(run);
        userClassPath->setObjectName(QStringLiteral("userClassPath"));

        formLayout->setWidget(3, QFormLayout::FieldRole, userClassPath);

        label_3 = new QLabel(run);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout->setWidget(4, QFormLayout::LabelRole, label_3);

        basePeriod = new QSpinBox(run);
        basePeriod->setObjectName(QStringLiteral("basePeriod"));
        basePeriod->setMaximum(2147483647);

        formLayout->setWidget(4, QFormLayout::FieldRole, basePeriod);

        label_4 = new QLabel(run);
        label_4->setObjectName(QStringLiteral("label_4"));

        formLayout->setWidget(5, QFormLayout::LabelRole, label_4);

        reductionCoreCount = new QSpinBox(run);
        reductionCoreCount->setObjectName(QStringLiteral("reductionCoreCount"));
        reductionCoreCount->setMaximum(2147483647);

        formLayout->setWidget(5, QFormLayout::FieldRole, reductionCoreCount);

        label_5 = new QLabel(run);
        label_5->setObjectName(QStringLiteral("label_5"));

        formLayout->setWidget(6, QFormLayout::LabelRole, label_5);

        timeCoreCount = new QSpinBox(run);
        timeCoreCount->setObjectName(QStringLiteral("timeCoreCount"));
        timeCoreCount->setMaximum(2147483647);

        formLayout->setWidget(6, QFormLayout::FieldRole, timeCoreCount);

        tabWidget->addTab(run, QString());
        system = new QWidget();
        system->setObjectName(QStringLiteral("system"));
        formLayout_2 = new QFormLayout(system);
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        label_6 = new QLabel(system);
        label_6->setObjectName(QStringLiteral("label_6"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, label_6);

        modelInertiaSuccessRate = new QDoubleSpinBox(system);
        modelInertiaSuccessRate->setObjectName(QStringLiteral("modelInertiaSuccessRate"));
        modelInertiaSuccessRate->setDecimals(7);

        formLayout_2->setWidget(0, QFormLayout::FieldRole, modelInertiaSuccessRate);

        label_7 = new QLabel(system);
        label_7->setObjectName(QStringLiteral("label_7"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, label_7);

        modelInertiacount = new QSpinBox(system);
        modelInertiacount->setObjectName(QStringLiteral("modelInertiacount"));
        modelInertiacount->setMaximum(2147483647);

        formLayout_2->setWidget(1, QFormLayout::FieldRole, modelInertiacount);

        label_8 = new QLabel(system);
        label_8->setObjectName(QStringLiteral("label_8"));

        formLayout_2->setWidget(2, QFormLayout::LabelRole, label_8);

        tpxDeltaSuccessRate = new QDoubleSpinBox(system);
        tpxDeltaSuccessRate->setObjectName(QStringLiteral("tpxDeltaSuccessRate"));
        tpxDeltaSuccessRate->setDecimals(7);

        formLayout_2->setWidget(2, QFormLayout::FieldRole, tpxDeltaSuccessRate);

        label_9 = new QLabel(system);
        label_9->setObjectName(QStringLiteral("label_9"));

        formLayout_2->setWidget(3, QFormLayout::LabelRole, label_9);

        minSimTimeHoriz = new QSpinBox(system);
        minSimTimeHoriz->setObjectName(QStringLiteral("minSimTimeHoriz"));
        minSimTimeHoriz->setMaximum(2147483647);

        formLayout_2->setWidget(3, QFormLayout::FieldRole, minSimTimeHoriz);

        label_10 = new QLabel(system);
        label_10->setObjectName(QStringLiteral("label_10"));

        formLayout_2->setWidget(4, QFormLayout::LabelRole, label_10);

        maxSimTimeHoriz = new QSpinBox(system);
        maxSimTimeHoriz->setObjectName(QStringLiteral("maxSimTimeHoriz"));
        maxSimTimeHoriz->setMaximum(2147483647);

        formLayout_2->setWidget(4, QFormLayout::FieldRole, maxSimTimeHoriz);

        label_11 = new QLabel(system);
        label_11->setObjectName(QStringLiteral("label_11"));

        formLayout_2->setWidget(5, QFormLayout::LabelRole, label_11);

        simTimeHoriz = new QDoubleSpinBox(system);
        simTimeHoriz->setObjectName(QStringLiteral("simTimeHoriz"));
        simTimeHoriz->setDecimals(7);

        formLayout_2->setWidget(5, QFormLayout::FieldRole, simTimeHoriz);

        label_12 = new QLabel(system);
        label_12->setObjectName(QStringLiteral("label_12"));

        formLayout_2->setWidget(6, QFormLayout::LabelRole, label_12);

        tpxTimeHoriz = new QSpinBox(system);
        tpxTimeHoriz->setObjectName(QStringLiteral("tpxTimeHoriz"));
        tpxTimeHoriz->setMaximum(2147483647);

        formLayout_2->setWidget(6, QFormLayout::FieldRole, tpxTimeHoriz);

        label_13 = new QLabel(system);
        label_13->setObjectName(QStringLiteral("label_13"));

        formLayout_2->setWidget(7, QFormLayout::LabelRole, label_13);

        perfSamplePeriod = new QSpinBox(system);
        perfSamplePeriod->setObjectName(QStringLiteral("perfSamplePeriod"));
        perfSamplePeriod->setMaximum(2147483647);

        formLayout_2->setWidget(7, QFormLayout::FieldRole, perfSamplePeriod);

        label_14 = new QLabel(system);
        label_14->setObjectName(QStringLiteral("label_14"));

        formLayout_2->setWidget(8, QFormLayout::LabelRole, label_14);

        floatTolerance = new QDoubleSpinBox(system);
        floatTolerance->setObjectName(QStringLiteral("floatTolerance"));
        floatTolerance->setDecimals(7);

        formLayout_2->setWidget(8, QFormLayout::FieldRole, floatTolerance);

        label_15 = new QLabel(system);
        label_15->setObjectName(QStringLiteral("label_15"));

        formLayout_2->setWidget(9, QFormLayout::LabelRole, label_15);

        timerTolerance = new QSpinBox(system);
        timerTolerance->setObjectName(QStringLiteral("timerTolerance"));
        timerTolerance->setMinimum(0);
        timerTolerance->setMaximum(2147483647);

        formLayout_2->setWidget(9, QFormLayout::FieldRole, timerTolerance);

        label_16 = new QLabel(system);
        label_16->setObjectName(QStringLiteral("label_16"));

        formLayout_2->setWidget(10, QFormLayout::LabelRole, label_16);

        primaryTimeHoriz = new QSpinBox(system);
        primaryTimeHoriz->setObjectName(QStringLiteral("primaryTimeHoriz"));
        primaryTimeHoriz->setMaximum(2147483647);

        formLayout_2->setWidget(10, QFormLayout::FieldRole, primaryTimeHoriz);

        label_17 = new QLabel(system);
        label_17->setObjectName(QStringLiteral("label_17"));

        formLayout_2->setWidget(11, QFormLayout::LabelRole, label_17);

        secondaryTimeHoriz = new QSpinBox(system);
        secondaryTimeHoriz->setObjectName(QStringLiteral("secondaryTimeHoriz"));
        secondaryTimeHoriz->setMaximum(2147483647);

        formLayout_2->setWidget(11, QFormLayout::FieldRole, secondaryTimeHoriz);

        label_18 = new QLabel(system);
        label_18->setObjectName(QStringLiteral("label_18"));

        formLayout_2->setWidget(12, QFormLayout::LabelRole, label_18);

        notifMarkerRes = new QSpinBox(system);
        notifMarkerRes->setObjectName(QStringLiteral("notifMarkerRes"));
        notifMarkerRes->setMaximum(2147483647);

        formLayout_2->setWidget(12, QFormLayout::FieldRole, notifMarkerRes);

        label_19 = new QLabel(system);
        label_19->setObjectName(QStringLiteral("label_19"));

        formLayout_2->setWidget(13, QFormLayout::LabelRole, label_19);

        goalPredSuccessRes = new QSpinBox(system);
        goalPredSuccessRes->setObjectName(QStringLiteral("goalPredSuccessRes"));
        goalPredSuccessRes->setMaximum(2147483647);

        formLayout_2->setWidget(13, QFormLayout::FieldRole, goalPredSuccessRes);

        tabWidget->addTab(system, QString());
        debugtab = new QWidget();
        debugtab->setObjectName(QStringLiteral("debugtab"));
        formLayout_3 = new QFormLayout(debugtab);
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        formLayout_3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_22 = new QLabel(debugtab);
        label_22->setObjectName(QStringLiteral("label_22"));

        formLayout_3->setWidget(0, QFormLayout::LabelRole, label_22);

        debug = new QCheckBox(debugtab);
        debug->setObjectName(QStringLiteral("debug"));

        formLayout_3->setWidget(0, QFormLayout::FieldRole, debug);

        label_23 = new QLabel(debugtab);
        label_23->setObjectName(QStringLiteral("label_23"));

        formLayout_3->setWidget(1, QFormLayout::LabelRole, label_23);

        debugWindows = new QSpinBox(debugtab);
        debugWindows->setObjectName(QStringLiteral("debugWindows"));

        formLayout_3->setWidget(1, QFormLayout::FieldRole, debugWindows);

        label_24 = new QLabel(debugtab);
        label_24->setObjectName(QStringLiteral("label_24"));

        formLayout_3->setWidget(2, QFormLayout::LabelRole, label_24);

        traceCompInputs = new QCheckBox(debugtab);
        traceCompInputs->setObjectName(QStringLiteral("traceCompInputs"));

        formLayout_3->setWidget(2, QFormLayout::FieldRole, traceCompInputs);

        traceCompOutputs = new QCheckBox(debugtab);
        traceCompOutputs->setObjectName(QStringLiteral("traceCompOutputs"));

        formLayout_3->setWidget(3, QFormLayout::FieldRole, traceCompOutputs);

        traceModelIn = new QCheckBox(debugtab);
        traceModelIn->setObjectName(QStringLiteral("traceModelIn"));

        formLayout_3->setWidget(4, QFormLayout::FieldRole, traceModelIn);

        traceModelOut = new QCheckBox(debugtab);
        traceModelOut->setObjectName(QStringLiteral("traceModelOut"));

        formLayout_3->setWidget(5, QFormLayout::FieldRole, traceModelOut);

        tracePredMon = new QCheckBox(debugtab);
        tracePredMon->setObjectName(QStringLiteral("tracePredMon"));

        formLayout_3->setWidget(6, QFormLayout::FieldRole, tracePredMon);

        traceGoalMon = new QCheckBox(debugtab);
        traceGoalMon->setObjectName(QStringLiteral("traceGoalMon"));

        formLayout_3->setWidget(7, QFormLayout::FieldRole, traceGoalMon);

        traceModelRev = new QCheckBox(debugtab);
        traceModelRev->setObjectName(QStringLiteral("traceModelRev"));

        formLayout_3->setWidget(8, QFormLayout::FieldRole, traceModelRev);

        traceModComInj = new QCheckBox(debugtab);
        traceModComInj->setObjectName(QStringLiteral("traceModComInj"));

        formLayout_3->setWidget(9, QFormLayout::FieldRole, traceModComInj);

        label_21 = new QLabel(debugtab);
        label_21->setObjectName(QStringLiteral("label_21"));

        formLayout_3->setWidget(10, QFormLayout::LabelRole, label_21);

        decompileObjects = new QCheckBox(debugtab);
        decompileObjects->setObjectName(QStringLiteral("decompileObjects"));

        formLayout_3->setWidget(10, QFormLayout::FieldRole, decompileObjects);

        decompileFileLabel = new QLabel(debugtab);
        decompileFileLabel->setObjectName(QStringLiteral("decompileFileLabel"));

        formLayout_3->setWidget(11, QFormLayout::LabelRole, decompileFileLabel);

        decObjFile = new KUrlRequester(debugtab);
        decObjFile->setObjectName(QStringLiteral("decObjFile"));

        formLayout_3->setWidget(11, QFormLayout::FieldRole, decObjFile);

        label_26 = new QLabel(debugtab);
        label_26->setObjectName(QStringLiteral("label_26"));

        formLayout_3->setWidget(12, QFormLayout::LabelRole, label_26);

        ignoreNamedObj = new QCheckBox(debugtab);
        ignoreNamedObj->setObjectName(QStringLiteral("ignoreNamedObj"));

        formLayout_3->setWidget(12, QFormLayout::FieldRole, ignoreNamedObj);

        label_27 = new QLabel(debugtab);
        label_27->setObjectName(QStringLiteral("label_27"));

        formLayout_3->setWidget(13, QFormLayout::LabelRole, label_27);

        dumpObjFile = new KUrlRequester(debugtab);
        dumpObjFile->setObjectName(QStringLiteral("dumpObjFile"));

        formLayout_3->setWidget(13, QFormLayout::FieldRole, dumpObjFile);

        label_28 = new QLabel(debugtab);
        label_28->setObjectName(QStringLiteral("label_28"));

        formLayout_3->setWidget(14, QFormLayout::LabelRole, label_28);

        testObj = new QCheckBox(debugtab);
        testObj->setObjectName(QStringLiteral("testObj"));

        formLayout_3->setWidget(14, QFormLayout::FieldRole, testObj);

        label_30 = new QLabel(debugtab);
        label_30->setObjectName(QStringLiteral("label_30"));

        formLayout_3->setWidget(15, QFormLayout::LabelRole, label_30);

        decompileModels = new QCheckBox(debugtab);
        decompileModels->setObjectName(QStringLiteral("decompileModels"));

        formLayout_3->setWidget(15, QFormLayout::FieldRole, decompileModels);

        label_31 = new QLabel(debugtab);
        label_31->setObjectName(QStringLiteral("label_31"));

        formLayout_3->setWidget(16, QFormLayout::LabelRole, label_31);

        ignoreNamedModels = new QCheckBox(debugtab);
        ignoreNamedModels->setObjectName(QStringLiteral("ignoreNamedModels"));

        formLayout_3->setWidget(16, QFormLayout::FieldRole, ignoreNamedModels);

        dumpFileLabel = new QLabel(debugtab);
        dumpFileLabel->setObjectName(QStringLiteral("dumpFileLabel"));

        formLayout_3->setWidget(17, QFormLayout::LabelRole, dumpFileLabel);

        dumpModelsFile = new KUrlRequester(debugtab);
        dumpModelsFile->setObjectName(QStringLiteral("dumpModelsFile"));

        formLayout_3->setWidget(17, QFormLayout::FieldRole, dumpModelsFile);

        label_33 = new QLabel(debugtab);
        label_33->setObjectName(QStringLiteral("label_33"));

        formLayout_3->setWidget(18, QFormLayout::LabelRole, label_33);

        testModels = new QCheckBox(debugtab);
        testModels->setObjectName(QStringLiteral("testModels"));

        formLayout_3->setWidget(18, QFormLayout::FieldRole, testModels);

        tabWidget->addTab(debugtab, QString());
#ifndef UI_QT_NO_SHORTCUT
        label_34->setBuddy(runTime);
        label_35->setBuddy(probeLevel);
        userOpsLabel->setBuddy(userModulePath);
        userClassLabel->setBuddy(userClassPath);
        label_3->setBuddy(basePeriod);
        label_4->setBuddy(reductionCoreCount);
        label_5->setBuddy(timeCoreCount);
        label_6->setBuddy(modelInertiaSuccessRate);
        label_7->setBuddy(modelInertiacount);
        label_8->setBuddy(tpxDeltaSuccessRate);
        label_9->setBuddy(minSimTimeHoriz);
        label_10->setBuddy(maxSimTimeHoriz);
        label_11->setBuddy(simTimeHoriz);
        label_12->setBuddy(tpxTimeHoriz);
        label_13->setBuddy(perfSamplePeriod);
        label_14->setBuddy(floatTolerance);
        label_15->setBuddy(timerTolerance);
        label_16->setBuddy(primaryTimeHoriz);
        label_17->setBuddy(secondaryTimeHoriz);
        label_18->setBuddy(notifMarkerRes);
        label_19->setBuddy(goalPredSuccessRes);
        label_22->setBuddy(debug);
        label_23->setBuddy(debugWindows);
        label_21->setBuddy(decompileObjects);
        label_26->setBuddy(ignoreNamedObj);
        label_28->setBuddy(testObj);
        label_30->setBuddy(decompileModels);
        label_31->setBuddy(ignoreNamedModels);
        label_33->setBuddy(testModels);
#endif // QT_NO_SHORTCUT

        retranslateUi(tabWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(tabWidget);
    } // setupUi

    void retranslateUi(QTabWidget *tabWidget)
    {
        label_34->setText(tr2i18n("Run time (milliseconds):", 0));
        label_35->setText(tr2i18n("Probe level:", 0));
        userOpsLabel->setText(tr2i18n("User operations layout module:", 0));
        userClassLabel->setText(tr2i18n("User classes file:", 0));
        label_3->setText(tr2i18n("Base period:", 0));
        label_4->setText(tr2i18n("Reduction core count:", 0));
        label_5->setText(tr2i18n("Time core count:", 0));
        tabWidget->setTabText(tabWidget->indexOf(run), tr2i18n("Run", 0));
        label_6->setText(tr2i18n("Model inertia success rate threshold:", 0));
        label_7->setText(tr2i18n("Model inertia count threshold:", 0));
        label_8->setText(tr2i18n("Targeted pattern extractor delta success rate threshold:", 0));
        label_9->setText(tr2i18n("Minimum simulation time horizon:", 0));
        label_10->setText(tr2i18n("Maximum simulation time horizon:", 0));
        label_11->setText(tr2i18n("Simulation time horizon:", 0));
        simTimeHoriz->setSuffix(QString());
        label_12->setText(tr2i18n("Targeted pattern extractor time horizon:", 0));
        label_13->setText(tr2i18n("Perf sampling period:", 0));
        label_14->setText(tr2i18n("Float tolerance:", 0));
        label_15->setText(tr2i18n("Timer tolerance:", 0));
        label_16->setText(tr2i18n("Primary time horizon:", 0));
        label_17->setText(tr2i18n("Secondary time horizon:", 0));
        label_18->setText(tr2i18n("Notification marker resilience:", 0));
        label_19->setText(tr2i18n("Goal prediction success resilience:", 0));
        tabWidget->setTabText(tabWidget->indexOf(system), tr2i18n("System", 0));
        label_22->setText(tr2i18n("Debug:", 0));
        debug->setText(QString());
        label_23->setText(tr2i18n("Debug windows:", 0));
        label_24->setText(tr2i18n("Traces:", 0));
        traceCompInputs->setText(tr2i18n("Composite inputs", 0));
        traceCompOutputs->setText(tr2i18n("Composite outputs", 0));
        traceModelIn->setText(tr2i18n("Model inputs", 0));
        traceModelOut->setText(tr2i18n("Model outputs", 0));
        tracePredMon->setText(tr2i18n("Prediction monitoring", 0));
        traceGoalMon->setText(tr2i18n("Goal monitoring", 0));
        traceModelRev->setText(tr2i18n("Model revision", 0));
        traceModComInj->setText(tr2i18n("Model/composite injections", 0));
        label_21->setText(tr2i18n("Decompile objects:", 0));
        decompileObjects->setText(QString());
        decompileFileLabel->setText(tr2i18n("Decompile to file:", 0));
        label_26->setText(tr2i18n("Ignore named objects:", 0));
        ignoreNamedObj->setText(QString());
        label_27->setText(tr2i18n("Dump objects to file:", 0));
        label_28->setText(tr2i18n("Test objects:", 0));
        testObj->setText(QString());
        label_30->setText(tr2i18n("Decompile models:", 0));
        decompileModels->setText(QString());
        label_31->setText(tr2i18n("Ignore named models:", 0));
        ignoreNamedModels->setText(QString());
        dumpFileLabel->setText(tr2i18n("Dump models to file:", 0));
        label_33->setText(tr2i18n("Test models:", 0));
        testModels->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(debugtab), tr2i18n("Debug", 0));
        Q_UNUSED(tabWidget);
    } // retranslateUi

};

namespace Ui {
    class tabWidget: public Ui_tabWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIG_H

