/****************************************************************************
** Meta object code from reading C++ file 'katemdi.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/katemdi.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katemdi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateMDI__ToggleToolViewAction_t {
    QByteArrayData data[4];
    char stringdata0[62];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateMDI__ToggleToolViewAction_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateMDI__ToggleToolViewAction_t qt_meta_stringdata_KateMDI__ToggleToolViewAction = {
    {
QT_MOC_LITERAL(0, 0, 29), // "KateMDI::ToggleToolViewAction"
QT_MOC_LITERAL(1, 30, 11), // "slotToggled"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 18) // "toolVisibleChanged"

    },
    "KateMDI::ToggleToolViewAction\0slotToggled\0"
    "\0toolVisibleChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateMDI__ToggleToolViewAction[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x09 /* Protected */,
       3,    1,   27,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void KateMDI::ToggleToolViewAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ToggleToolViewAction *_t = static_cast<ToggleToolViewAction *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->toolVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KateMDI::ToggleToolViewAction::staticMetaObject = {
    { &KToggleAction::staticMetaObject, qt_meta_stringdata_KateMDI__ToggleToolViewAction.data,
      qt_meta_data_KateMDI__ToggleToolViewAction,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateMDI::ToggleToolViewAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateMDI::ToggleToolViewAction::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateMDI__ToggleToolViewAction.stringdata0))
        return static_cast<void*>(const_cast< ToggleToolViewAction*>(this));
    return KToggleAction::qt_metacast(_clname);
}

int KateMDI::ToggleToolViewAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KToggleAction::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_KateMDI__GUIClient_t {
    QByteArrayData data[6];
    char stringdata0[68];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateMDI__GUIClient_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateMDI__GUIClient_t qt_meta_stringdata_KateMDI__GUIClient = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KateMDI::GUIClient"
QT_MOC_LITERAL(1, 19, 11), // "clientAdded"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 14), // "KXMLGUIClient*"
QT_MOC_LITERAL(4, 47, 6), // "client"
QT_MOC_LITERAL(5, 54, 13) // "updateActions"

    },
    "KateMDI::GUIClient\0clientAdded\0\0"
    "KXMLGUIClient*\0client\0updateActions"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateMDI__GUIClient[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x08 /* Private */,
       5,    0,   27,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

       0        // eod
};

void KateMDI::GUIClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GUIClient *_t = static_cast<GUIClient *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->clientAdded((*reinterpret_cast< KXMLGUIClient*(*)>(_a[1]))); break;
        case 1: _t->updateActions(); break;
        default: ;
        }
    }
}

const QMetaObject KateMDI::GUIClient::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateMDI__GUIClient.data,
      qt_meta_data_KateMDI__GUIClient,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateMDI::GUIClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateMDI::GUIClient::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateMDI__GUIClient.stringdata0))
        return static_cast<void*>(const_cast< GUIClient*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< GUIClient*>(this));
    return QObject::qt_metacast(_clname);
}

int KateMDI::GUIClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_KateMDI__ToolView_t {
    QByteArrayData data[4];
    char stringdata0[46];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateMDI__ToolView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateMDI__ToolView_t qt_meta_stringdata_KateMDI__ToolView = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KateMDI::ToolView"
QT_MOC_LITERAL(1, 18, 18), // "toolVisibleChanged"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 7) // "visible"

    },
    "KateMDI::ToolView\0toolVisibleChanged\0"
    "\0visible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateMDI__ToolView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

       0        // eod
};

void KateMDI::ToolView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ToolView *_t = static_cast<ToolView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->toolVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ToolView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ToolView::toolVisibleChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KateMDI::ToolView::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_KateMDI__ToolView.data,
      qt_meta_data_KateMDI__ToolView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateMDI::ToolView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateMDI::ToolView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateMDI__ToolView.stringdata0))
        return static_cast<void*>(const_cast< ToolView*>(this));
    return QFrame::qt_metacast(_clname);
}

int KateMDI::ToolView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KateMDI::ToolView::toolVisibleChanged(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KateMDI__Sidebar_t {
    QByteArrayData data[11];
    char stringdata0[145];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateMDI__Sidebar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateMDI__Sidebar_t qt_meta_stringdata_KateMDI__Sidebar = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KateMDI::Sidebar"
QT_MOC_LITERAL(1, 17, 23), // "sigShowPluginConfigPage"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 20), // "KTextEditor::Plugin*"
QT_MOC_LITERAL(4, 63, 19), // "configpageinterface"
QT_MOC_LITERAL(5, 83, 2), // "id"
QT_MOC_LITERAL(6, 86, 10), // "setVisible"
QT_MOC_LITERAL(7, 97, 7), // "visible"
QT_MOC_LITERAL(8, 105, 10), // "tabClicked"
QT_MOC_LITERAL(9, 116, 19), // "buttonPopupActivate"
QT_MOC_LITERAL(10, 136, 8) // "QAction*"

    },
    "KateMDI::Sidebar\0sigShowPluginConfigPage\0"
    "\0KTextEditor::Plugin*\0configpageinterface\0"
    "id\0setVisible\0visible\0tabClicked\0"
    "buttonPopupActivate\0QAction*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateMDI__Sidebar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   39,    2, 0x0a /* Public */,
       8,    1,   42,    2, 0x08 /* Private */,
       9,    1,   45,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::UInt,    4,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 10,    2,

       0        // eod
};

void KateMDI::Sidebar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Sidebar *_t = static_cast<Sidebar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sigShowPluginConfigPage((*reinterpret_cast< KTextEditor::Plugin*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 1: _t->setVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->tabClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->buttonPopupActivate((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Plugin* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Sidebar::*_t)(KTextEditor::Plugin * , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Sidebar::sigShowPluginConfigPage)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KateMDI::Sidebar::staticMetaObject = {
    { &KMultiTabBar::staticMetaObject, qt_meta_stringdata_KateMDI__Sidebar.data,
      qt_meta_data_KateMDI__Sidebar,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateMDI::Sidebar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateMDI::Sidebar::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateMDI__Sidebar.stringdata0))
        return static_cast<void*>(const_cast< Sidebar*>(this));
    return KMultiTabBar::qt_metacast(_clname);
}

int KateMDI::Sidebar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMultiTabBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KateMDI::Sidebar::sigShowPluginConfigPage(KTextEditor::Plugin * _t1, uint _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KateMDI__MainWindow_t {
    QByteArrayData data[8];
    char stringdata0[116];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateMDI__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateMDI__MainWindow_t qt_meta_stringdata_KateMDI__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateMDI::MainWindow"
QT_MOC_LITERAL(1, 20, 23), // "sigShowPluginConfigPage"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 20), // "KTextEditor::Plugin*"
QT_MOC_LITERAL(4, 66, 19), // "configpageinterface"
QT_MOC_LITERAL(5, 86, 2), // "id"
QT_MOC_LITERAL(6, 89, 18), // "setSidebarsVisible"
QT_MOC_LITERAL(7, 108, 7) // "visible"

    },
    "KateMDI::MainWindow\0sigShowPluginConfigPage\0"
    "\0KTextEditor::Plugin*\0configpageinterface\0"
    "id\0setSidebarsVisible\0visible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateMDI__MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   29,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::UInt,    4,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    7,

       0        // eod
};

void KateMDI::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sigShowPluginConfigPage((*reinterpret_cast< KTextEditor::Plugin*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 1: _t->setSidebarsVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Plugin* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MainWindow::*_t)(KTextEditor::Plugin * , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MainWindow::sigShowPluginConfigPage)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KateMDI::MainWindow::staticMetaObject = {
    { &KParts::MainWindow::staticMetaObject, qt_meta_stringdata_KateMDI__MainWindow.data,
      qt_meta_data_KateMDI__MainWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateMDI::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateMDI::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateMDI__MainWindow.stringdata0))
        return static_cast<void*>(const_cast< MainWindow*>(this));
    return KParts::MainWindow::qt_metacast(_clname);
}

int KateMDI::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KateMDI::MainWindow::sigShowPluginConfigPage(KTextEditor::Plugin * _t1, uint _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
