/****************************************************************************
** Meta object code from reading C++ file 'sqlmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/katesql/sqlmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sqlmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_SQLManager_t {
    QByteArrayData data[21];
    char stringdata0[255];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SQLManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SQLManager_t qt_meta_stringdata_SQLManager = {
    {
QT_MOC_LITERAL(0, 0, 10), // "SQLManager"
QT_MOC_LITERAL(1, 11, 17), // "connectionCreated"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 4), // "name"
QT_MOC_LITERAL(4, 35, 17), // "connectionRemoved"
QT_MOC_LITERAL(5, 53, 25), // "connectionAboutToBeClosed"
QT_MOC_LITERAL(6, 79, 14), // "queryActivated"
QT_MOC_LITERAL(7, 94, 10), // "QSqlQuery&"
QT_MOC_LITERAL(8, 105, 5), // "query"
QT_MOC_LITERAL(9, 111, 10), // "connection"
QT_MOC_LITERAL(10, 122, 5), // "error"
QT_MOC_LITERAL(11, 128, 7), // "message"
QT_MOC_LITERAL(12, 136, 7), // "success"
QT_MOC_LITERAL(13, 144, 16), // "removeConnection"
QT_MOC_LITERAL(14, 161, 16), // "reopenConnection"
QT_MOC_LITERAL(15, 178, 15), // "loadConnections"
QT_MOC_LITERAL(16, 194, 13), // "KConfigGroup*"
QT_MOC_LITERAL(17, 208, 16), // "connectionsGroup"
QT_MOC_LITERAL(18, 225, 15), // "saveConnections"
QT_MOC_LITERAL(19, 241, 8), // "runQuery"
QT_MOC_LITERAL(20, 250, 4) // "text"

    },
    "SQLManager\0connectionCreated\0\0name\0"
    "connectionRemoved\0connectionAboutToBeClosed\0"
    "queryActivated\0QSqlQuery&\0query\0"
    "connection\0error\0message\0success\0"
    "removeConnection\0reopenConnection\0"
    "loadConnections\0KConfigGroup*\0"
    "connectionsGroup\0saveConnections\0"
    "runQuery\0text"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SQLManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    1,   72,    2, 0x06 /* Public */,
       5,    1,   75,    2, 0x06 /* Public */,
       6,    2,   78,    2, 0x06 /* Public */,
      10,    1,   83,    2, 0x06 /* Public */,
      12,    1,   86,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,   89,    2, 0x0a /* Public */,
      14,    1,   92,    2, 0x0a /* Public */,
      15,    1,   95,    2, 0x0a /* Public */,
      18,    1,   98,    2, 0x0a /* Public */,
      19,    2,  101,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QString,    8,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QString,   11,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   20,    9,

       0        // eod
};

void SQLManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SQLManager *_t = static_cast<SQLManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connectionCreated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->connectionRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->connectionAboutToBeClosed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->queryActivated((*reinterpret_cast< QSqlQuery(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->error((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->success((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->removeConnection((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->reopenConnection((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->loadConnections((*reinterpret_cast< KConfigGroup*(*)>(_a[1]))); break;
        case 9: _t->saveConnections((*reinterpret_cast< KConfigGroup*(*)>(_a[1]))); break;
        case 10: _t->runQuery((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (SQLManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SQLManager::connectionCreated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SQLManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SQLManager::connectionRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (SQLManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SQLManager::connectionAboutToBeClosed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (SQLManager::*_t)(QSqlQuery & , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SQLManager::queryActivated)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (SQLManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SQLManager::error)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (SQLManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SQLManager::success)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject SQLManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_SQLManager.data,
      qt_meta_data_SQLManager,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *SQLManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SQLManager::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_SQLManager.stringdata0))
        return static_cast<void*>(const_cast< SQLManager*>(this));
    return QObject::qt_metacast(_clname);
}

int SQLManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void SQLManager::connectionCreated(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void SQLManager::connectionRemoved(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void SQLManager::connectionAboutToBeClosed(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void SQLManager::queryActivated(QSqlQuery & _t1, const QString & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void SQLManager::error(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void SQLManager::success(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_END_MOC_NAMESPACE
