/****************************************************************************
** Meta object code from reading C++ file 'kate_ctags_view.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/kate-ctags/kate_ctags_view.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kate_ctags_view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateCTagsView_t {
    QByteArrayData data[22];
    char stringdata0[251];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateCTagsView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateCTagsView_t qt_meta_stringdata_KateCTagsView = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KateCTagsView"
QT_MOC_LITERAL(1, 14, 14), // "gotoDefinition"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 15), // "gotoDeclaration"
QT_MOC_LITERAL(4, 46, 9), // "lookupTag"
QT_MOC_LITERAL(5, 56, 8), // "stepBack"
QT_MOC_LITERAL(6, 65, 10), // "editLookUp"
QT_MOC_LITERAL(7, 76, 11), // "aboutToShow"
QT_MOC_LITERAL(8, 88, 13), // "tagHitClicked"
QT_MOC_LITERAL(9, 102, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(10, 119, 12), // "startEditTmr"
QT_MOC_LITERAL(11, 132, 12), // "addTagTarget"
QT_MOC_LITERAL(12, 145, 12), // "delTagTarget"
QT_MOC_LITERAL(13, 158, 15), // "updateSessionDB"
QT_MOC_LITERAL(14, 174, 10), // "updateDone"
QT_MOC_LITERAL(15, 185, 8), // "exitCode"
QT_MOC_LITERAL(16, 194, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(17, 215, 6), // "status"
QT_MOC_LITERAL(18, 222, 8), // "resetCMD"
QT_MOC_LITERAL(19, 231, 9), // "handleEsc"
QT_MOC_LITERAL(20, 241, 7), // "QEvent*"
QT_MOC_LITERAL(21, 249, 1) // "e"

    },
    "KateCTagsView\0gotoDefinition\0\0"
    "gotoDeclaration\0lookupTag\0stepBack\0"
    "editLookUp\0aboutToShow\0tagHitClicked\0"
    "QTreeWidgetItem*\0startEditTmr\0"
    "addTagTarget\0delTagTarget\0updateSessionDB\0"
    "updateDone\0exitCode\0QProcess::ExitStatus\0"
    "status\0resetCMD\0handleEsc\0QEvent*\0e"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateCTagsView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x0a /* Public */,
       3,    0,   85,    2, 0x0a /* Public */,
       4,    0,   86,    2, 0x0a /* Public */,
       5,    0,   87,    2, 0x0a /* Public */,
       6,    0,   88,    2, 0x0a /* Public */,
       7,    0,   89,    2, 0x0a /* Public */,
       8,    1,   90,    2, 0x0a /* Public */,
      10,    0,   93,    2, 0x0a /* Public */,
      11,    0,   94,    2, 0x0a /* Public */,
      12,    0,   95,    2, 0x0a /* Public */,
      13,    0,   96,    2, 0x0a /* Public */,
      14,    2,   97,    2, 0x0a /* Public */,
      18,    0,  102,    2, 0x08 /* Private */,
      19,    1,  103,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 16,   15,   17,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,

       0        // eod
};

void KateCTagsView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateCTagsView *_t = static_cast<KateCTagsView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->gotoDefinition(); break;
        case 1: _t->gotoDeclaration(); break;
        case 2: _t->lookupTag(); break;
        case 3: _t->stepBack(); break;
        case 4: _t->editLookUp(); break;
        case 5: _t->aboutToShow(); break;
        case 6: _t->tagHitClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 7: _t->startEditTmr(); break;
        case 8: _t->addTagTarget(); break;
        case 9: _t->delTagTarget(); break;
        case 10: _t->updateSessionDB(); break;
        case 11: _t->updateDone((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 12: _t->resetCMD(); break;
        case 13: _t->handleEsc((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KateCTagsView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateCTagsView.data,
      qt_meta_data_KateCTagsView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateCTagsView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateCTagsView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateCTagsView.stringdata0))
        return static_cast<void*>(const_cast< KateCTagsView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KateCTagsView*>(this));
    if (!strcmp(_clname, "KTextEditor::SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KateCTagsView*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KateCTagsView*>(this));
    return QObject::qt_metacast(_clname);
}

int KateCTagsView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
