/****************************************************************************
** Meta object code from reading C++ file 'kateprojectworker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/project/kateprojectworker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateprojectworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateProjectWorker_t {
    QByteArrayData data[10];
    char stringdata0[160];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateProjectWorker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateProjectWorker_t qt_meta_stringdata_KateProjectWorker = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KateProjectWorker"
QT_MOC_LITERAL(1, 18, 8), // "loadDone"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 30), // "KateProjectSharedQStandardItem"
QT_MOC_LITERAL(4, 59, 8), // "topLevel"
QT_MOC_LITERAL(5, 68, 31), // "KateProjectSharedQMapStringItem"
QT_MOC_LITERAL(6, 100, 9), // "file2Item"
QT_MOC_LITERAL(7, 110, 13), // "loadIndexDone"
QT_MOC_LITERAL(8, 124, 29), // "KateProjectSharedProjectIndex"
QT_MOC_LITERAL(9, 154, 5) // "index"

    },
    "KateProjectWorker\0loadDone\0\0"
    "KateProjectSharedQStandardItem\0topLevel\0"
    "KateProjectSharedQMapStringItem\0"
    "file2Item\0loadIndexDone\0"
    "KateProjectSharedProjectIndex\0index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateProjectWorker[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,
       7,    1,   29,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 8,    9,

       0        // eod
};

void KateProjectWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateProjectWorker *_t = static_cast<KateProjectWorker *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->loadDone((*reinterpret_cast< KateProjectSharedQStandardItem(*)>(_a[1])),(*reinterpret_cast< KateProjectSharedQMapStringItem(*)>(_a[2]))); break;
        case 1: _t->loadIndexDone((*reinterpret_cast< KateProjectSharedProjectIndex(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProjectSharedQMapStringItem >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProjectSharedQStandardItem >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProjectSharedProjectIndex >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateProjectWorker::*_t)(KateProjectSharedQStandardItem , KateProjectSharedQMapStringItem );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProjectWorker::loadDone)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateProjectWorker::*_t)(KateProjectSharedProjectIndex );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProjectWorker::loadIndexDone)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KateProjectWorker::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateProjectWorker.data,
      qt_meta_data_KateProjectWorker,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateProjectWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateProjectWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateProjectWorker.stringdata0))
        return static_cast<void*>(const_cast< KateProjectWorker*>(this));
    if (!strcmp(_clname, "ThreadWeaver::Job"))
        return static_cast< ThreadWeaver::Job*>(const_cast< KateProjectWorker*>(this));
    return QObject::qt_metacast(_clname);
}

int KateProjectWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KateProjectWorker::loadDone(KateProjectSharedQStandardItem _t1, KateProjectSharedQMapStringItem _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateProjectWorker::loadIndexDone(KateProjectSharedProjectIndex _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_END_MOC_NAMESPACE
