#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'editsnippet.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSNIPPET_H
#define UI_EDITSNIPPET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kkeysequencewidget.h"
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_EditSnippetBase
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *messageWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *snippetName;
    QLineEdit *snippetNameEdit;
    KKeySequenceWidget *snippetShortcut;
    QSplitter *splitter;
    QTabWidget *editorTabs;
    QWidget *snippetTab;
    QVBoxLayout *verticalLayout_2;
    QLabel *snippetLabel;
    QWidget *scriptTab;
    QVBoxLayout *verticalLayout_4;
    QLabel *scriptLabel;
    QWidget *testWidget;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *dotest_button;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QWidget *EditSnippetBase)
    {
        if (EditSnippetBase->objectName().isEmpty())
            EditSnippetBase->setObjectName(QStringLiteral("EditSnippetBase"));
        EditSnippetBase->resize(500, 525);
        EditSnippetBase->setMinimumSize(QSize(500, 0));
        verticalLayout = new QVBoxLayout(EditSnippetBase);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        messageWidget = new KMessageWidget(EditSnippetBase);
        messageWidget->setObjectName(QStringLiteral("messageWidget"));
        messageWidget->setVisible(true);
        messageWidget->setProperty("closeButtonVisible", QVariant(false));

        verticalLayout->addWidget(messageWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        snippetName = new QLabel(EditSnippetBase);
        snippetName->setObjectName(QStringLiteral("snippetName"));

        horizontalLayout->addWidget(snippetName);

        snippetNameEdit = new QLineEdit(EditSnippetBase);
        snippetNameEdit->setObjectName(QStringLiteral("snippetNameEdit"));

        horizontalLayout->addWidget(snippetNameEdit);

        snippetShortcut = new KKeySequenceWidget(EditSnippetBase);
        snippetShortcut->setObjectName(QStringLiteral("snippetShortcut"));

        horizontalLayout->addWidget(snippetShortcut);


        verticalLayout->addLayout(horizontalLayout);

        splitter = new QSplitter(EditSnippetBase);
        splitter->setObjectName(QStringLiteral("splitter"));
        splitter->setOrientation(Qt::Vertical);
        editorTabs = new QTabWidget(splitter);
        editorTabs->setObjectName(QStringLiteral("editorTabs"));
        snippetTab = new QWidget();
        snippetTab->setObjectName(QStringLiteral("snippetTab"));
        verticalLayout_2 = new QVBoxLayout(snippetTab);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        snippetLabel = new QLabel(snippetTab);
        snippetLabel->setObjectName(QStringLiteral("snippetLabel"));
        snippetLabel->setTextFormat(Qt::RichText);
        snippetLabel->setWordWrap(true);

        verticalLayout_2->addWidget(snippetLabel);

        editorTabs->addTab(snippetTab, QString());
        scriptTab = new QWidget();
        scriptTab->setObjectName(QStringLiteral("scriptTab"));
        verticalLayout_4 = new QVBoxLayout(scriptTab);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        scriptLabel = new QLabel(scriptTab);
        scriptLabel->setObjectName(QStringLiteral("scriptLabel"));
        scriptLabel->setWordWrap(true);

        verticalLayout_4->addWidget(scriptLabel);

        editorTabs->addTab(scriptTab, QString());
        splitter->addWidget(editorTabs);
        testWidget = new QWidget(splitter);
        testWidget->setObjectName(QStringLiteral("testWidget"));
        verticalLayout_3 = new QVBoxLayout(testWidget);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        dotest_button = new QPushButton(testWidget);
        dotest_button->setObjectName(QStringLiteral("dotest_button"));

        horizontalLayout_4->addWidget(dotest_button);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout_4);

        splitter->addWidget(testWidget);

        verticalLayout->addWidget(splitter);

        buttons = new QDialogButtonBox(EditSnippetBase);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttons);


        retranslateUi(EditSnippetBase);

        editorTabs->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(EditSnippetBase);
    } // setupUi

    void retranslateUi(QWidget *EditSnippetBase)
    {
        snippetName->setText(tr2i18n("Name:", 0));
        snippetNameEdit->setPlaceholderText(tr2i18n("will be shown in the completion list", 0));
        snippetLabel->setText(tr2i18n("The text your snippet will insert into the document. <a href=\"A snippet can contain editable fields. They can be cycled by pressing Tab. The following expressions can be used in the template text to create fields: <br><tt>${field_name}</tt> creates a simple, editable field. All subsequent occurrences of the same field_name create fields which mirror the contents of the first during editing.<br><tt>${field_name=default}</tt> can be used to specify a default value for the field. <tt>default</tt> can be any JavaScript expression.<br>Use <tt>${field_name=text}</tt> to specify a fixed string as default value.<br><tt>${func(other_field1, other_field2, ...)}</tt> can be used to create a field which evaluates a JavaScript function on each edit and contains its contents. See the Scripts tab for more information.<br><tt>${cursor}</tt> can be used to mark the end position of the cursor after everything else was filled in.\">More...</a>", 0));
        editorTabs->setTabText(editorTabs->indexOf(snippetTab), tr2i18n("&Snippet", 0));
        scriptLabel->setText(tr2i18n("Write down JavaScript helper functions to use in your snippets here. <a href=\"All JavaScript functions should return the contents you want to place in a template field as a string.<br>Functions are called in a scope which contains the contents of all editable template fields as local variables. For example in a snippet containing <tt>${field}</tt>, a variable called <tt>field</tt> will be present which contains the up-to-date contents of the template field. Those variables can either be used in the function statically or passed as arguments, by using the <tt>${func(field)}</tt> or <tt>${field2=func(field)}</tt> syntax in the snippet string.<br>You can use the kate scripting API to get the selected text, full text, file name and more by using the appropriate methods of the <tt>document</tt> and <tt>view</tt> objects. Refer to the scripting API documentation for more information.\">More...</a>", 0));
        editorTabs->setTabText(editorTabs->indexOf(scriptTab), tr2i18n("S&cripts", 0));
        dotest_button->setText(tr2i18n("Test this snippet", 0));
        Q_UNUSED(EditSnippetBase);
    } // retranslateUi

};

namespace Ui {
    class EditSnippetBase: public Ui_EditSnippetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITSNIPPET_H

