/****************************************************************************
** Meta object code from reading C++ file 'katemainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/katemainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katemainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateContainerStackedLayout_t {
    QByteArrayData data[1];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateContainerStackedLayout_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateContainerStackedLayout_t qt_meta_stringdata_KateContainerStackedLayout = {
    {
QT_MOC_LITERAL(0, 0, 26) // "KateContainerStackedLayout"

    },
    "KateContainerStackedLayout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateContainerStackedLayout[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateContainerStackedLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateContainerStackedLayout::staticMetaObject = {
    { &QStackedLayout::staticMetaObject, qt_meta_stringdata_KateContainerStackedLayout.data,
      qt_meta_data_KateContainerStackedLayout,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateContainerStackedLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateContainerStackedLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateContainerStackedLayout.stringdata0))
        return static_cast<void*>(const_cast< KateContainerStackedLayout*>(this));
    return QStackedLayout::qt_metacast(_clname);
}

int KateContainerStackedLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStackedLayout::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KateMainWindow_t {
    QByteArrayData data[95];
    char stringdata0[1300];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateMainWindow_t qt_meta_stringdata_KateMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KateMainWindow"
QT_MOC_LITERAL(1, 15, 16), // "statusBarToggled"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 13), // "tabBarToggled"
QT_MOC_LITERAL(4, 47, 25), // "unhandledShortcutOverride"
QT_MOC_LITERAL(5, 73, 7), // "QEvent*"
QT_MOC_LITERAL(6, 81, 1), // "e"
QT_MOC_LITERAL(7, 83, 13), // "slotFileClose"
QT_MOC_LITERAL(8, 97, 12), // "slotFileQuit"
QT_MOC_LITERAL(9, 110, 19), // "queueModifiedOnDisc"
QT_MOC_LITERAL(10, 130, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(11, 153, 3), // "doc"
QT_MOC_LITERAL(12, 157, 16), // "slotFocusPrevTab"
QT_MOC_LITERAL(13, 174, 16), // "slotFocusNextTab"
QT_MOC_LITERAL(14, 191, 13), // "slotQuickOpen"
QT_MOC_LITERAL(15, 205, 8), // "sizeHint"
QT_MOC_LITERAL(16, 214, 9), // "newWindow"
QT_MOC_LITERAL(17, 224, 13), // "slotConfigure"
QT_MOC_LITERAL(18, 238, 22), // "slotOpenWithMenuAction"
QT_MOC_LITERAL(19, 261, 8), // "QAction*"
QT_MOC_LITERAL(20, 270, 1), // "a"
QT_MOC_LITERAL(21, 272, 16), // "slotEditToolbars"
QT_MOC_LITERAL(22, 289, 20), // "slotNewToolbarConfig"
QT_MOC_LITERAL(23, 310, 18), // "slotUpdateOpenWith"
QT_MOC_LITERAL(24, 329, 16), // "slotOpenDocument"
QT_MOC_LITERAL(25, 346, 13), // "slotDropEvent"
QT_MOC_LITERAL(26, 360, 11), // "QDropEvent*"
QT_MOC_LITERAL(27, 372, 8), // "editKeys"
QT_MOC_LITERAL(28, 381, 20), // "mSlotFixOpenWithMenu"
QT_MOC_LITERAL(29, 402, 12), // "reloadXmlGui"
QT_MOC_LITERAL(30, 415, 19), // "slotDocumentCreated"
QT_MOC_LITERAL(31, 435, 13), // "updateCaption"
QT_MOC_LITERAL(32, 449, 10), // "pluginHelp"
QT_MOC_LITERAL(33, 460, 11), // "aboutEditor"
QT_MOC_LITERAL(34, 472, 14), // "slotFullScreen"
QT_MOC_LITERAL(35, 487, 24), // "slotListRecursiveEntries"
QT_MOC_LITERAL(36, 512, 9), // "KIO::Job*"
QT_MOC_LITERAL(37, 522, 3), // "job"
QT_MOC_LITERAL(38, 526, 17), // "KIO::UDSEntryList"
QT_MOC_LITERAL(39, 544, 4), // "list"
QT_MOC_LITERAL(40, 549, 17), // "toggleShowMenuBar"
QT_MOC_LITERAL(41, 567, 11), // "showMessage"
QT_MOC_LITERAL(42, 579, 19), // "toggleShowStatusBar"
QT_MOC_LITERAL(43, 599, 16), // "toggleShowTabBar"
QT_MOC_LITERAL(44, 616, 6), // "window"
QT_MOC_LITERAL(45, 623, 8), // "QWidget*"
QT_MOC_LITERAL(46, 632, 10), // "guiFactory"
QT_MOC_LITERAL(47, 643, 15), // "KXMLGUIFactory*"
QT_MOC_LITERAL(48, 659, 5), // "views"
QT_MOC_LITERAL(49, 665, 25), // "QList<KTextEditor::View*>"
QT_MOC_LITERAL(50, 691, 10), // "activeView"
QT_MOC_LITERAL(51, 702, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(52, 721, 12), // "activateView"
QT_MOC_LITERAL(53, 734, 8), // "document"
QT_MOC_LITERAL(54, 743, 7), // "openUrl"
QT_MOC_LITERAL(55, 751, 3), // "url"
QT_MOC_LITERAL(56, 755, 8), // "encoding"
QT_MOC_LITERAL(57, 764, 9), // "closeView"
QT_MOC_LITERAL(58, 774, 4), // "view"
QT_MOC_LITERAL(59, 779, 14), // "closeSplitView"
QT_MOC_LITERAL(60, 794, 20), // "viewsInSameSplitView"
QT_MOC_LITERAL(61, 815, 5), // "view1"
QT_MOC_LITERAL(62, 821, 5), // "view2"
QT_MOC_LITERAL(63, 827, 9), // "splitView"
QT_MOC_LITERAL(64, 837, 15), // "Qt::Orientation"
QT_MOC_LITERAL(65, 853, 11), // "orientation"
QT_MOC_LITERAL(66, 865, 13), // "createViewBar"
QT_MOC_LITERAL(67, 879, 13), // "deleteViewBar"
QT_MOC_LITERAL(68, 893, 18), // "addWidgetToViewBar"
QT_MOC_LITERAL(69, 912, 3), // "bar"
QT_MOC_LITERAL(70, 916, 11), // "showViewBar"
QT_MOC_LITERAL(71, 928, 11), // "hideViewBar"
QT_MOC_LITERAL(72, 940, 14), // "createToolView"
QT_MOC_LITERAL(73, 955, 20), // "KTextEditor::Plugin*"
QT_MOC_LITERAL(74, 976, 6), // "plugin"
QT_MOC_LITERAL(75, 983, 10), // "identifier"
QT_MOC_LITERAL(76, 994, 41), // "KTextEditor::MainWindow::Tool..."
QT_MOC_LITERAL(77, 1036, 3), // "pos"
QT_MOC_LITERAL(78, 1040, 4), // "icon"
QT_MOC_LITERAL(79, 1045, 4), // "text"
QT_MOC_LITERAL(80, 1050, 12), // "moveToolView"
QT_MOC_LITERAL(81, 1063, 6), // "widget"
QT_MOC_LITERAL(82, 1070, 12), // "showToolView"
QT_MOC_LITERAL(83, 1083, 12), // "hideToolView"
QT_MOC_LITERAL(84, 1096, 10), // "pluginView"
QT_MOC_LITERAL(85, 1107, 4), // "name"
QT_MOC_LITERAL(86, 1112, 23), // "slotUpdateBottomViewBar"
QT_MOC_LITERAL(87, 1136, 20), // "slotDocumentCloseAll"
QT_MOC_LITERAL(88, 1157, 22), // "slotDocumentCloseOther"
QT_MOC_LITERAL(89, 1180, 25), // "slotDocumentCloseSelected"
QT_MOC_LITERAL(90, 1206, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(91, 1236, 20), // "showPluginConfigPage"
QT_MOC_LITERAL(92, 1257, 19), // "configpageinterface"
QT_MOC_LITERAL(93, 1277, 2), // "id"
QT_MOC_LITERAL(94, 1280, 19) // "slotWindowActivated"

    },
    "KateMainWindow\0statusBarToggled\0\0"
    "tabBarToggled\0unhandledShortcutOverride\0"
    "QEvent*\0e\0slotFileClose\0slotFileQuit\0"
    "queueModifiedOnDisc\0KTextEditor::Document*\0"
    "doc\0slotFocusPrevTab\0slotFocusNextTab\0"
    "slotQuickOpen\0sizeHint\0newWindow\0"
    "slotConfigure\0slotOpenWithMenuAction\0"
    "QAction*\0a\0slotEditToolbars\0"
    "slotNewToolbarConfig\0slotUpdateOpenWith\0"
    "slotOpenDocument\0slotDropEvent\0"
    "QDropEvent*\0editKeys\0mSlotFixOpenWithMenu\0"
    "reloadXmlGui\0slotDocumentCreated\0"
    "updateCaption\0pluginHelp\0aboutEditor\0"
    "slotFullScreen\0slotListRecursiveEntries\0"
    "KIO::Job*\0job\0KIO::UDSEntryList\0list\0"
    "toggleShowMenuBar\0showMessage\0"
    "toggleShowStatusBar\0toggleShowTabBar\0"
    "window\0QWidget*\0guiFactory\0KXMLGUIFactory*\0"
    "views\0QList<KTextEditor::View*>\0"
    "activeView\0KTextEditor::View*\0"
    "activateView\0document\0openUrl\0url\0"
    "encoding\0closeView\0view\0closeSplitView\0"
    "viewsInSameSplitView\0view1\0view2\0"
    "splitView\0Qt::Orientation\0orientation\0"
    "createViewBar\0deleteViewBar\0"
    "addWidgetToViewBar\0bar\0showViewBar\0"
    "hideViewBar\0createToolView\0"
    "KTextEditor::Plugin*\0plugin\0identifier\0"
    "KTextEditor::MainWindow::ToolViewPosition\0"
    "pos\0icon\0text\0moveToolView\0widget\0"
    "showToolView\0hideToolView\0pluginView\0"
    "name\0slotUpdateBottomViewBar\0"
    "slotDocumentCloseAll\0slotDocumentCloseOther\0"
    "slotDocumentCloseSelected\0"
    "QList<KTextEditor::Document*>\0"
    "showPluginConfigPage\0configpageinterface\0"
    "id\0slotWindowActivated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateMainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      60,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  314,    2, 0x06 /* Public */,
       3,    0,  315,    2, 0x06 /* Public */,
       4,    1,  316,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,  319,    2, 0x0a /* Public */,
       8,    0,  320,    2, 0x0a /* Public */,
       9,    1,  321,    2, 0x0a /* Public */,
      12,    0,  324,    2, 0x0a /* Public */,
      13,    0,  325,    2, 0x0a /* Public */,
      14,    0,  326,    2, 0x0a /* Public */,
      15,    0,  327,    2, 0x0a /* Public */,
      16,    0,  328,    2, 0x08 /* Private */,
      17,    0,  329,    2, 0x08 /* Private */,
      18,    1,  330,    2, 0x08 /* Private */,
      21,    0,  333,    2, 0x08 /* Private */,
      22,    0,  334,    2, 0x08 /* Private */,
      23,    0,  335,    2, 0x08 /* Private */,
      24,    1,  336,    2, 0x08 /* Private */,
      25,    1,  339,    2, 0x08 /* Private */,
      27,    0,  342,    2, 0x08 /* Private */,
      28,    0,  343,    2, 0x08 /* Private */,
      29,    0,  344,    2, 0x08 /* Private */,
      30,    1,  345,    2, 0x08 /* Private */,
      31,    1,  348,    2, 0x08 /* Private */,
      31,    0,  351,    2, 0x08 /* Private */,
      32,    0,  352,    2, 0x08 /* Private */,
      33,    0,  353,    2, 0x08 /* Private */,
      34,    1,  354,    2, 0x08 /* Private */,
      35,    2,  357,    2, 0x08 /* Private */,
      40,    1,  362,    2, 0x08 /* Private */,
      40,    0,  365,    2, 0x28 /* Private | MethodCloned */,
      42,    0,  366,    2, 0x08 /* Private */,
      43,    0,  367,    2, 0x08 /* Private */,
      44,    0,  368,    2, 0x0a /* Public */,
      46,    0,  369,    2, 0x0a /* Public */,
      48,    0,  370,    2, 0x0a /* Public */,
      50,    0,  371,    2, 0x0a /* Public */,
      52,    1,  372,    2, 0x0a /* Public */,
      54,    2,  375,    2, 0x0a /* Public */,
      54,    1,  380,    2, 0x2a /* Public | MethodCloned */,
      57,    1,  383,    2, 0x0a /* Public */,
      59,    1,  386,    2, 0x0a /* Public */,
      60,    2,  389,    2, 0x0a /* Public */,
      63,    1,  394,    2, 0x0a /* Public */,
      66,    1,  397,    2, 0x0a /* Public */,
      67,    1,  400,    2, 0x0a /* Public */,
      68,    2,  403,    2, 0x0a /* Public */,
      70,    1,  408,    2, 0x0a /* Public */,
      71,    1,  411,    2, 0x0a /* Public */,
      72,    5,  414,    2, 0x0a /* Public */,
      80,    2,  425,    2, 0x0a /* Public */,
      82,    1,  430,    2, 0x0a /* Public */,
      83,    1,  433,    2, 0x0a /* Public */,
      84,    1,  436,    2, 0x0a /* Public */,
      86,    0,  439,    2, 0x08 /* Private */,
      87,    0,  440,    2, 0x08 /* Private */,
      88,    0,  441,    2, 0x08 /* Private */,
      88,    1,  442,    2, 0x08 /* Private */,
      89,    1,  445,    2, 0x08 /* Private */,
      91,    2,  448,    2, 0x0a /* Public */,
      94,    0,  453,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::QSize,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, 0x80000000 | 26,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 36, 0x80000000 | 38,   37,   39,
    QMetaType::Void, QMetaType::Bool,   41,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 45,
    0x80000000 | 47,
    0x80000000 | 49,
    0x80000000 | 51,
    0x80000000 | 51, 0x80000000 | 10,   53,
    0x80000000 | 51, QMetaType::QUrl, QMetaType::QString,   55,   56,
    0x80000000 | 51, QMetaType::QUrl,   55,
    QMetaType::Bool, 0x80000000 | 51,   58,
    QMetaType::Bool, 0x80000000 | 51,   58,
    QMetaType::Bool, 0x80000000 | 51, 0x80000000 | 51,   61,   62,
    QMetaType::Void, 0x80000000 | 64,   65,
    0x80000000 | 45, 0x80000000 | 51,    2,
    QMetaType::Void, 0x80000000 | 51,   58,
    QMetaType::Void, 0x80000000 | 51, 0x80000000 | 45,   58,   69,
    QMetaType::Void, 0x80000000 | 51,   58,
    QMetaType::Void, 0x80000000 | 51,   58,
    0x80000000 | 45, 0x80000000 | 73, QMetaType::QString, 0x80000000 | 76, QMetaType::QIcon, QMetaType::QString,   74,   75,   77,   78,   79,
    QMetaType::Bool, 0x80000000 | 45, 0x80000000 | 76,   81,   77,
    QMetaType::Bool, 0x80000000 | 45,   81,
    QMetaType::Bool, 0x80000000 | 45,   81,
    QMetaType::QObjectStar, QMetaType::QString,   85,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   53,
    QMetaType::Void, 0x80000000 | 90,    2,
    QMetaType::Void, 0x80000000 | 73, QMetaType::UInt,   92,   93,
    QMetaType::Void,

       0        // eod
};

void KateMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateMainWindow *_t = static_cast<KateMainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->statusBarToggled(); break;
        case 1: _t->tabBarToggled(); break;
        case 2: _t->unhandledShortcutOverride((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 3: _t->slotFileClose(); break;
        case 4: _t->slotFileQuit(); break;
        case 5: _t->queueModifiedOnDisc((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 6: _t->slotFocusPrevTab(); break;
        case 7: _t->slotFocusNextTab(); break;
        case 8: _t->slotQuickOpen(); break;
        case 9: { QSize _r = _t->sizeHint();
            if (_a[0]) *reinterpret_cast< QSize*>(_a[0]) = _r; }  break;
        case 10: _t->newWindow(); break;
        case 11: _t->slotConfigure(); break;
        case 12: _t->slotOpenWithMenuAction((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 13: _t->slotEditToolbars(); break;
        case 14: _t->slotNewToolbarConfig(); break;
        case 15: _t->slotUpdateOpenWith(); break;
        case 16: _t->slotOpenDocument((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 17: _t->slotDropEvent((*reinterpret_cast< QDropEvent*(*)>(_a[1]))); break;
        case 18: _t->editKeys(); break;
        case 19: _t->mSlotFixOpenWithMenu(); break;
        case 20: _t->reloadXmlGui(); break;
        case 21: _t->slotDocumentCreated((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 22: _t->updateCaption((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 23: _t->updateCaption(); break;
        case 24: _t->pluginHelp(); break;
        case 25: _t->aboutEditor(); break;
        case 26: _t->slotFullScreen((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->slotListRecursiveEntries((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const KIO::UDSEntryList(*)>(_a[2]))); break;
        case 28: _t->toggleShowMenuBar((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->toggleShowMenuBar(); break;
        case 30: _t->toggleShowStatusBar(); break;
        case 31: _t->toggleShowTabBar(); break;
        case 32: { QWidget* _r = _t->window();
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = _r; }  break;
        case 33: { KXMLGUIFactory* _r = _t->guiFactory();
            if (_a[0]) *reinterpret_cast< KXMLGUIFactory**>(_a[0]) = _r; }  break;
        case 34: { QList<KTextEditor::View*> _r = _t->views();
            if (_a[0]) *reinterpret_cast< QList<KTextEditor::View*>*>(_a[0]) = _r; }  break;
        case 35: { KTextEditor::View* _r = _t->activeView();
            if (_a[0]) *reinterpret_cast< KTextEditor::View**>(_a[0]) = _r; }  break;
        case 36: { KTextEditor::View* _r = _t->activateView((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KTextEditor::View**>(_a[0]) = _r; }  break;
        case 37: { KTextEditor::View* _r = _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< KTextEditor::View**>(_a[0]) = _r; }  break;
        case 38: { KTextEditor::View* _r = _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KTextEditor::View**>(_a[0]) = _r; }  break;
        case 39: { bool _r = _t->closeView((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 40: { bool _r = _t->closeSplitView((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 41: { bool _r = _t->viewsInSameSplitView((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::View*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 42: _t->splitView((*reinterpret_cast< Qt::Orientation(*)>(_a[1]))); break;
        case 43: { QWidget* _r = _t->createViewBar((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = _r; }  break;
        case 44: _t->deleteViewBar((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 45: _t->addWidgetToViewBar((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 46: _t->showViewBar((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 47: _t->hideViewBar((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 48: { QWidget* _r = _t->createToolView((*reinterpret_cast< KTextEditor::Plugin*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< KTextEditor::MainWindow::ToolViewPosition(*)>(_a[3])),(*reinterpret_cast< const QIcon(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = _r; }  break;
        case 49: { bool _r = _t->moveToolView((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::MainWindow::ToolViewPosition(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 50: { bool _r = _t->showToolView((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 51: { bool _r = _t->hideToolView((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 52: { QObject* _r = _t->pluginView((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = _r; }  break;
        case 53: _t->slotUpdateBottomViewBar(); break;
        case 54: _t->slotDocumentCloseAll(); break;
        case 55: _t->slotDocumentCloseOther(); break;
        case 56: _t->slotDocumentCloseOther((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 57: _t->slotDocumentCloseSelected((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 58: _t->showPluginConfigPage((*reinterpret_cast< KTextEditor::Plugin*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 59: _t->slotWindowActivated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 48:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Plugin* >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 50:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 56:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 57:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        case 58:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Plugin* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateMainWindow::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateMainWindow::statusBarToggled)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateMainWindow::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateMainWindow::tabBarToggled)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KateMainWindow::*_t)(QEvent * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateMainWindow::unhandledShortcutOverride)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KateMainWindow::staticMetaObject = {
    { &KateMDI::MainWindow::staticMetaObject, qt_meta_stringdata_KateMainWindow.data,
      qt_meta_data_KateMainWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateMainWindow.stringdata0))
        return static_cast<void*>(const_cast< KateMainWindow*>(this));
    if (!strcmp(_clname, "KParts::PartBase"))
        return static_cast< KParts::PartBase*>(const_cast< KateMainWindow*>(this));
    return KateMDI::MainWindow::qt_metacast(_clname);
}

int KateMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KateMDI::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    }
    return _id;
}

// SIGNAL 0
void KateMainWindow::statusBarToggled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void KateMainWindow::tabBarToggled()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void KateMainWindow::unhandledShortcutOverride(QEvent * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_END_MOC_NAMESPACE
