/****************************************************************************
** Meta object code from reading C++ file 'katedocmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/katedocmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katedocmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateDocManager_t {
    QByteArrayData data[27];
    char stringdata0[447];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateDocManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateDocManager_t qt_meta_stringdata_KateDocManager = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KateDocManager"
QT_MOC_LITERAL(1, 15, 15), // "documentCreated"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(4, 55, 8), // "document"
QT_MOC_LITERAL(5, 64, 26), // "documentCreatedViewManager"
QT_MOC_LITERAL(6, 91, 21), // "documentWillBeDeleted"
QT_MOC_LITERAL(7, 113, 15), // "documentDeleted"
QT_MOC_LITERAL(8, 129, 22), // "aboutToCreateDocuments"
QT_MOC_LITERAL(9, 152, 16), // "documentsCreated"
QT_MOC_LITERAL(10, 169, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(11, 199, 9), // "documents"
QT_MOC_LITERAL(12, 209, 22), // "aboutToDeleteDocuments"
QT_MOC_LITERAL(13, 232, 16), // "documentsDeleted"
QT_MOC_LITERAL(14, 249, 7), // "saveAll"
QT_MOC_LITERAL(15, 257, 9), // "reloadAll"
QT_MOC_LITERAL(16, 267, 13), // "closeOrphaned"
QT_MOC_LITERAL(17, 281, 12), // "saveSelected"
QT_MOC_LITERAL(18, 294, 18), // "slotModifiedOnDisc"
QT_MOC_LITERAL(19, 313, 3), // "doc"
QT_MOC_LITERAL(20, 317, 1), // "b"
QT_MOC_LITERAL(21, 319, 56), // "KTextEditor::ModificationInte..."
QT_MOC_LITERAL(22, 376, 6), // "reason"
QT_MOC_LITERAL(23, 383, 14), // "slotModChanged"
QT_MOC_LITERAL(24, 398, 15), // "slotModChanged1"
QT_MOC_LITERAL(25, 414, 17), // "showRestoreErrors"
QT_MOC_LITERAL(26, 432, 14) // "documentOpened"

    },
    "KateDocManager\0documentCreated\0\0"
    "KTextEditor::Document*\0document\0"
    "documentCreatedViewManager\0"
    "documentWillBeDeleted\0documentDeleted\0"
    "aboutToCreateDocuments\0documentsCreated\0"
    "QList<KTextEditor::Document*>\0documents\0"
    "aboutToDeleteDocuments\0documentsDeleted\0"
    "saveAll\0reloadAll\0closeOrphaned\0"
    "saveSelected\0slotModifiedOnDisc\0doc\0"
    "b\0KTextEditor::ModificationInterface::ModifiedOnDiskReason\0"
    "reason\0slotModChanged\0slotModChanged1\0"
    "showRestoreErrors\0documentOpened"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateDocManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,
       5,    1,  102,    2, 0x06 /* Public */,
       6,    1,  105,    2, 0x06 /* Public */,
       7,    1,  108,    2, 0x06 /* Public */,
       8,    0,  111,    2, 0x06 /* Public */,
       9,    1,  112,    2, 0x06 /* Public */,
      12,    1,  115,    2, 0x06 /* Public */,
      13,    1,  118,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,  121,    2, 0x0a /* Public */,
      15,    0,  122,    2, 0x0a /* Public */,
      16,    0,  123,    2, 0x0a /* Public */,
      17,    1,  124,    2, 0x0a /* Public */,
      18,    3,  127,    2, 0x08 /* Private */,
      23,    1,  134,    2, 0x08 /* Private */,
      24,    1,  137,    2, 0x08 /* Private */,
      25,    0,  140,    2, 0x08 /* Private */,
      26,    0,  141,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool, 0x80000000 | 21,   19,   20,   22,
    QMetaType::Void, 0x80000000 | 3,   19,
    QMetaType::Void, 0x80000000 | 3,   19,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateDocManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateDocManager *_t = static_cast<KateDocManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->documentCreated((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 1: _t->documentCreatedViewManager((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->documentWillBeDeleted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->documentDeleted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 4: _t->aboutToCreateDocuments(); break;
        case 5: _t->documentsCreated((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 6: _t->aboutToDeleteDocuments((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 7: _t->documentsDeleted((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 8: _t->saveAll(); break;
        case 9: _t->reloadAll(); break;
        case 10: _t->closeOrphaned(); break;
        case 11: _t->saveSelected((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 12: _t->slotModifiedOnDisc((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< KTextEditor::ModificationInterface::ModifiedOnDiskReason(*)>(_a[3]))); break;
        case 13: _t->slotModChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 14: _t->slotModChanged1((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 15: _t->showRestoreErrors(); break;
        case 16: _t->documentOpened(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateDocManager::*_t)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::documentCreated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateDocManager::*_t)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::documentCreatedViewManager)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KateDocManager::*_t)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::documentWillBeDeleted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KateDocManager::*_t)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::documentDeleted)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KateDocManager::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::aboutToCreateDocuments)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KateDocManager::*_t)(const QList<KTextEditor::Document*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::documentsCreated)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KateDocManager::*_t)(const QList<KTextEditor::Document*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::aboutToDeleteDocuments)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KateDocManager::*_t)(const QList<KTextEditor::Document*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateDocManager::documentsDeleted)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject KateDocManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateDocManager.data,
      qt_meta_data_KateDocManager,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateDocManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateDocManager::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateDocManager.stringdata0))
        return static_cast<void*>(const_cast< KateDocManager*>(this));
    return QObject::qt_metacast(_clname);
}

int KateDocManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void KateDocManager::documentCreated(KTextEditor::Document * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateDocManager::documentCreatedViewManager(KTextEditor::Document * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KateDocManager::documentWillBeDeleted(KTextEditor::Document * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KateDocManager::documentDeleted(KTextEditor::Document * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KateDocManager::aboutToCreateDocuments()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}

// SIGNAL 5
void KateDocManager::documentsCreated(const QList<KTextEditor::Document*> & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KateDocManager::aboutToDeleteDocuments(const QList<KTextEditor::Document*> & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KateDocManager::documentsDeleted(const QList<KTextEditor::Document*> & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_END_MOC_NAMESPACE
