/****************************************************************************
** Meta object code from reading C++ file 'advanced_settings.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/gdbplugin/advanced_settings.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'advanced_settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_AdvancedGDBSettings_t {
    QByteArrayData data[9];
    char stringdata0[132];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AdvancedGDBSettings_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AdvancedGDBSettings_t qt_meta_stringdata_AdvancedGDBSettings = {
    {
QT_MOC_LITERAL(0, 0, 19), // "AdvancedGDBSettings"
QT_MOC_LITERAL(1, 20, 13), // "slotBrowseGDB"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 15), // "slotSetSoPrefix"
QT_MOC_LITERAL(4, 51, 13), // "slotAddSoPath"
QT_MOC_LITERAL(5, 65, 13), // "slotDelSoPath"
QT_MOC_LITERAL(6, 79, 14), // "slotAddSrcPath"
QT_MOC_LITERAL(7, 94, 14), // "slotDelSrcPath"
QT_MOC_LITERAL(8, 109, 22) // "slotLocalRemoteChanged"

    },
    "AdvancedGDBSettings\0slotBrowseGDB\0\0"
    "slotSetSoPrefix\0slotAddSoPath\0"
    "slotDelSoPath\0slotAddSrcPath\0"
    "slotDelSrcPath\0slotLocalRemoteChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AdvancedGDBSettings[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x08 /* Private */,
       3,    0,   50,    2, 0x08 /* Private */,
       4,    0,   51,    2, 0x08 /* Private */,
       5,    0,   52,    2, 0x08 /* Private */,
       6,    0,   53,    2, 0x08 /* Private */,
       7,    0,   54,    2, 0x08 /* Private */,
       8,    0,   55,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void AdvancedGDBSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AdvancedGDBSettings *_t = static_cast<AdvancedGDBSettings *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotBrowseGDB(); break;
        case 1: _t->slotSetSoPrefix(); break;
        case 2: _t->slotAddSoPath(); break;
        case 3: _t->slotDelSoPath(); break;
        case 4: _t->slotAddSrcPath(); break;
        case 5: _t->slotDelSrcPath(); break;
        case 6: _t->slotLocalRemoteChanged(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject AdvancedGDBSettings::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_AdvancedGDBSettings.data,
      qt_meta_data_AdvancedGDBSettings,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *AdvancedGDBSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedGDBSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_AdvancedGDBSettings.stringdata0))
        return static_cast<void*>(const_cast< AdvancedGDBSettings*>(this));
    if (!strcmp(_clname, "Ui::AdvancedGDBSettings"))
        return static_cast< Ui::AdvancedGDBSettings*>(const_cast< AdvancedGDBSettings*>(this));
    return QDialog::qt_metacast(_clname);
}

int AdvancedGDBSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
