/****************************************************************************
** Meta object code from reading C++ file 'replicodeview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/replicode/replicodeview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'replicodeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ReplicodeView_t {
    QByteArrayData data[13];
    char stringdata0[162];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ReplicodeView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ReplicodeView_t qt_meta_stringdata_ReplicodeView = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ReplicodeView"
QT_MOC_LITERAL(1, 14, 12), // "runReplicode"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 13), // "stopReplicode"
QT_MOC_LITERAL(4, 42, 17), // "replicodeFinished"
QT_MOC_LITERAL(5, 60, 9), // "gotStderr"
QT_MOC_LITERAL(6, 70, 9), // "gotStdout"
QT_MOC_LITERAL(7, 80, 10), // "runErrored"
QT_MOC_LITERAL(8, 91, 22), // "QProcess::ProcessError"
QT_MOC_LITERAL(9, 114, 13), // "outputClicked"
QT_MOC_LITERAL(10, 128, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(11, 145, 4), // "item"
QT_MOC_LITERAL(12, 150, 11) // "viewChanged"

    },
    "ReplicodeView\0runReplicode\0\0stopReplicode\0"
    "replicodeFinished\0gotStderr\0gotStdout\0"
    "runErrored\0QProcess::ProcessError\0"
    "outputClicked\0QListWidgetItem*\0item\0"
    "viewChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ReplicodeView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x08 /* Private */,
       3,    0,   55,    2, 0x08 /* Private */,
       4,    0,   56,    2, 0x08 /* Private */,
       5,    0,   57,    2, 0x08 /* Private */,
       6,    0,   58,    2, 0x08 /* Private */,
       7,    1,   59,    2, 0x08 /* Private */,
       9,    1,   62,    2, 0x08 /* Private */,
      12,    0,   65,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,

       0        // eod
};

void ReplicodeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ReplicodeView *_t = static_cast<ReplicodeView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->runReplicode(); break;
        case 1: _t->stopReplicode(); break;
        case 2: _t->replicodeFinished(); break;
        case 3: _t->gotStderr(); break;
        case 4: _t->gotStdout(); break;
        case 5: _t->runErrored((*reinterpret_cast< QProcess::ProcessError(*)>(_a[1]))); break;
        case 6: _t->outputClicked((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 7: _t->viewChanged(); break;
        default: ;
        }
    }
}

const QMetaObject ReplicodeView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ReplicodeView.data,
      qt_meta_data_ReplicodeView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ReplicodeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReplicodeView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ReplicodeView.stringdata0))
        return static_cast<void*>(const_cast< ReplicodeView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< ReplicodeView*>(this));
    if (!strcmp(_clname, "KTextEditor::SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< ReplicodeView*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< ReplicodeView*>(this));
    return QObject::qt_metacast(_clname);
}

int ReplicodeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
