/****************************************************************************
** Meta object code from reading C++ file 'kateprojectplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/project/kateprojectplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateprojectplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateProjectPlugin_t {
    QByteArrayData data[12];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateProjectPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateProjectPlugin_t qt_meta_stringdata_KateProjectPlugin = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KateProjectPlugin"
QT_MOC_LITERAL(1, 18, 14), // "projectCreated"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 12), // "KateProject*"
QT_MOC_LITERAL(4, 47, 7), // "project"
QT_MOC_LITERAL(5, 55, 19), // "slotDocumentCreated"
QT_MOC_LITERAL(6, 75, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(7, 98, 8), // "document"
QT_MOC_LITERAL(8, 107, 21), // "slotDocumentDestroyed"
QT_MOC_LITERAL(9, 129, 22), // "slotDocumentUrlChanged"
QT_MOC_LITERAL(10, 152, 20), // "slotDirectoryChanged"
QT_MOC_LITERAL(11, 173, 4) // "path"

    },
    "KateProjectPlugin\0projectCreated\0\0"
    "KateProject*\0project\0slotDocumentCreated\0"
    "KTextEditor::Document*\0document\0"
    "slotDocumentDestroyed\0slotDocumentUrlChanged\0"
    "slotDirectoryChanged\0path"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateProjectPlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   42,    2, 0x0a /* Public */,
       8,    1,   45,    2, 0x0a /* Public */,
       9,    1,   48,    2, 0x0a /* Public */,
      10,    1,   51,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QObjectStar,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QString,   11,

       0        // eod
};

void KateProjectPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateProjectPlugin *_t = static_cast<KateProjectPlugin *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->projectCreated((*reinterpret_cast< KateProject*(*)>(_a[1]))); break;
        case 1: _t->slotDocumentCreated((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->slotDocumentDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 3: _t->slotDocumentUrlChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 4: _t->slotDirectoryChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProject* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateProjectPlugin::*_t)(KateProject * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProjectPlugin::projectCreated)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KateProjectPlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KateProjectPlugin.data,
      qt_meta_data_KateProjectPlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateProjectPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateProjectPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateProjectPlugin.stringdata0))
        return static_cast<void*>(const_cast< KateProjectPlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KateProjectPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KateProjectPlugin::projectCreated(KateProject * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
