/****************************************************************************
** Meta object code from reading C++ file 'plugin_kategdb.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/gdbplugin/plugin_kategdb.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin_kategdb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KatePluginGDB_t {
    QByteArrayData data[1];
    char stringdata0[14];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginGDB_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginGDB_t qt_meta_stringdata_KatePluginGDB = {
    {
QT_MOC_LITERAL(0, 0, 13) // "KatePluginGDB"

    },
    "KatePluginGDB"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginGDB[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KatePluginGDB::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KatePluginGDB::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KatePluginGDB.data,
      qt_meta_data_KatePluginGDB,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginGDB::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginGDB::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginGDB.stringdata0))
        return static_cast<void*>(const_cast< KatePluginGDB*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KatePluginGDB::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KatePluginGDBView_t {
    QByteArrayData data[40];
    char stringdata0[444];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginGDBView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginGDBView_t qt_meta_stringdata_KatePluginGDBView = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KatePluginGDBView"
QT_MOC_LITERAL(1, 18, 9), // "slotDebug"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 11), // "slotRestart"
QT_MOC_LITERAL(4, 41, 20), // "slotToggleBreakpoint"
QT_MOC_LITERAL(5, 62, 10), // "slotMovePC"
QT_MOC_LITERAL(6, 73, 15), // "slotRunToCursor"
QT_MOC_LITERAL(7, 89, 8), // "slotGoTo"
QT_MOC_LITERAL(8, 98, 8), // "fileName"
QT_MOC_LITERAL(9, 107, 7), // "lineNum"
QT_MOC_LITERAL(10, 115, 9), // "slotValue"
QT_MOC_LITERAL(11, 125, 15), // "aboutToShowMenu"
QT_MOC_LITERAL(12, 141, 17), // "slotBreakpointSet"
QT_MOC_LITERAL(13, 159, 4), // "file"
QT_MOC_LITERAL(14, 164, 4), // "line"
QT_MOC_LITERAL(15, 169, 21), // "slotBreakpointCleared"
QT_MOC_LITERAL(16, 191, 15), // "slotSendCommand"
QT_MOC_LITERAL(17, 207, 18), // "enableDebugActions"
QT_MOC_LITERAL(18, 226, 6), // "enable"
QT_MOC_LITERAL(19, 233, 12), // "programEnded"
QT_MOC_LITERAL(20, 246, 8), // "gdbEnded"
QT_MOC_LITERAL(21, 255, 16), // "insertStackFrame"
QT_MOC_LITERAL(22, 272, 5), // "level"
QT_MOC_LITERAL(23, 278, 4), // "info"
QT_MOC_LITERAL(24, 283, 17), // "stackFrameChanged"
QT_MOC_LITERAL(25, 301, 18), // "stackFrameSelected"
QT_MOC_LITERAL(26, 320, 12), // "insertThread"
QT_MOC_LITERAL(27, 333, 6), // "number"
QT_MOC_LITERAL(28, 340, 6), // "active"
QT_MOC_LITERAL(29, 347, 14), // "threadSelected"
QT_MOC_LITERAL(30, 362, 6), // "thread"
QT_MOC_LITERAL(31, 369, 6), // "showIO"
QT_MOC_LITERAL(32, 376, 4), // "show"
QT_MOC_LITERAL(33, 381, 13), // "addOutputText"
QT_MOC_LITERAL(34, 395, 4), // "text"
QT_MOC_LITERAL(35, 400, 12), // "addErrorText"
QT_MOC_LITERAL(36, 413, 10), // "clearMarks"
QT_MOC_LITERAL(37, 424, 9), // "handleEsc"
QT_MOC_LITERAL(38, 434, 7), // "QEvent*"
QT_MOC_LITERAL(39, 442, 1) // "e"

    },
    "KatePluginGDBView\0slotDebug\0\0slotRestart\0"
    "slotToggleBreakpoint\0slotMovePC\0"
    "slotRunToCursor\0slotGoTo\0fileName\0"
    "lineNum\0slotValue\0aboutToShowMenu\0"
    "slotBreakpointSet\0file\0line\0"
    "slotBreakpointCleared\0slotSendCommand\0"
    "enableDebugActions\0enable\0programEnded\0"
    "gdbEnded\0insertStackFrame\0level\0info\0"
    "stackFrameChanged\0stackFrameSelected\0"
    "insertThread\0number\0active\0threadSelected\0"
    "thread\0showIO\0show\0addOutputText\0text\0"
    "addErrorText\0clearMarks\0handleEsc\0"
    "QEvent*\0e"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginGDBView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      24,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  134,    2, 0x08 /* Private */,
       3,    0,  135,    2, 0x08 /* Private */,
       4,    0,  136,    2, 0x08 /* Private */,
       5,    0,  137,    2, 0x08 /* Private */,
       6,    0,  138,    2, 0x08 /* Private */,
       7,    2,  139,    2, 0x08 /* Private */,
      10,    0,  144,    2, 0x08 /* Private */,
      11,    0,  145,    2, 0x08 /* Private */,
      12,    2,  146,    2, 0x08 /* Private */,
      15,    2,  151,    2, 0x08 /* Private */,
      16,    0,  156,    2, 0x08 /* Private */,
      17,    1,  157,    2, 0x08 /* Private */,
      19,    0,  160,    2, 0x08 /* Private */,
      20,    0,  161,    2, 0x08 /* Private */,
      21,    2,  162,    2, 0x08 /* Private */,
      24,    1,  167,    2, 0x08 /* Private */,
      25,    0,  170,    2, 0x08 /* Private */,
      26,    2,  171,    2, 0x08 /* Private */,
      29,    1,  176,    2, 0x08 /* Private */,
      31,    1,  179,    2, 0x08 /* Private */,
      33,    1,  182,    2, 0x08 /* Private */,
      35,    1,  185,    2, 0x08 /* Private */,
      36,    0,  188,    2, 0x08 /* Private */,
      37,    1,  189,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::Int,    8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::Int,   13,   14,
    QMetaType::Void, QMetaType::QUrl, QMetaType::Int,   13,   14,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   22,   23,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   27,   28,
    QMetaType::Void, QMetaType::Int,   30,
    QMetaType::Void, QMetaType::Bool,   32,
    QMetaType::Void, QMetaType::QString,   34,
    QMetaType::Void, QMetaType::QString,   34,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 38,   39,

       0        // eod
};

void KatePluginGDBView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KatePluginGDBView *_t = static_cast<KatePluginGDBView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotDebug(); break;
        case 1: _t->slotRestart(); break;
        case 2: _t->slotToggleBreakpoint(); break;
        case 3: _t->slotMovePC(); break;
        case 4: _t->slotRunToCursor(); break;
        case 5: _t->slotGoTo((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->slotValue(); break;
        case 7: _t->aboutToShowMenu(); break;
        case 8: _t->slotBreakpointSet((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 9: _t->slotBreakpointCleared((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->slotSendCommand(); break;
        case 11: _t->enableDebugActions((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->programEnded(); break;
        case 13: _t->gdbEnded(); break;
        case 14: _t->insertStackFrame((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 15: _t->stackFrameChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->stackFrameSelected(); break;
        case 17: _t->insertThread((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 18: _t->threadSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->showIO((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->addOutputText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->addErrorText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->clearMarks(); break;
        case 23: _t->handleEsc((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KatePluginGDBView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KatePluginGDBView.data,
      qt_meta_data_KatePluginGDBView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginGDBView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginGDBView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginGDBView.stringdata0))
        return static_cast<void*>(const_cast< KatePluginGDBView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KatePluginGDBView*>(this));
    if (!strcmp(_clname, "KTextEditor::SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KatePluginGDBView*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KatePluginGDBView*>(this));
    return QObject::qt_metacast(_clname);
}

int KatePluginGDBView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 24;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
