/****************************************************************************
** Meta object code from reading C++ file 'kateconfigdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/kateconfigdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateconfigdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateConfigDialog_t {
    QByteArrayData data[9];
    char stringdata0[104];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateConfigDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateConfigDialog_t qt_meta_stringdata_KateConfigDialog = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KateConfigDialog"
QT_MOC_LITERAL(1, 17, 9), // "slotApply"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 11), // "slotChanged"
QT_MOC_LITERAL(4, 40, 8), // "slotHelp"
QT_MOC_LITERAL(5, 49, 22), // "slotCurrentPageChanged"
QT_MOC_LITERAL(6, 72, 16), // "KPageWidgetItem*"
QT_MOC_LITERAL(7, 89, 7), // "current"
QT_MOC_LITERAL(8, 97, 6) // "before"

    },
    "KateConfigDialog\0slotApply\0\0slotChanged\0"
    "slotHelp\0slotCurrentPageChanged\0"
    "KPageWidgetItem*\0current\0before"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateConfigDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x09 /* Protected */,
       3,    0,   35,    2, 0x09 /* Protected */,
       4,    0,   36,    2, 0x09 /* Protected */,
       5,    2,   37,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 6,    7,    8,

       0        // eod
};

void KateConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateConfigDialog *_t = static_cast<KateConfigDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotApply(); break;
        case 1: _t->slotChanged(); break;
        case 2: _t->slotHelp(); break;
        case 3: _t->slotCurrentPageChanged((*reinterpret_cast< KPageWidgetItem*(*)>(_a[1])),(*reinterpret_cast< KPageWidgetItem*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPageWidgetItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KateConfigDialog::staticMetaObject = {
    { &KPageDialog::staticMetaObject, qt_meta_stringdata_KateConfigDialog.data,
      qt_meta_data_KateConfigDialog,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateConfigDialog.stringdata0))
        return static_cast<void*>(const_cast< KateConfigDialog*>(this));
    return KPageDialog::qt_metacast(_clname);
}

int KateConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
