#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'advanced_settings.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADVANCED_SETTINGS_H
#define UI_ADVANCED_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AdvancedGDBSettings
{
public:
    QGridLayout *gridLayout_2;
    QLabel *u_gdbLabel;
    QToolButton *u_gdbBrowse;
    QLabel *u_srcPathsLabel;
    QListWidget *u_srcPaths;
    QVBoxLayout *verticalLayout_2;
    QToolButton *u_addSrcPath;
    QToolButton *u_delSrcPath;
    QSpacerItem *verticalSpacer;
    QComboBox *u_localRemote;
    QStackedWidget *u_remoteStack;
    QWidget *empty_2;
    QWidget *u_remoteTcp;
    QHBoxLayout *horizontalLayout_3;
    QLabel *u_hostLabel;
    QLineEdit *u_tcpHost;
    QLabel *u_tcpPortLabel;
    QLineEdit *u_tcpPort;
    QWidget *page_2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *u_ttyLabel;
    QLineEdit *u_ttyPort;
    QLabel *u_ttyBaudLabel;
    QComboBox *u_baudCombo;
    QLabel *u_soAbsPrefixLabel;
    QToolButton *u_setSoPrefix;
    QLabel *u_soSearchLabel;
    QListWidget *u_soSearchPaths;
    QWidget *u_addDelSoPaths;
    QVBoxLayout *verticalLayout_4;
    QToolButton *u_addSoSearchPath;
    QToolButton *u_delSoSearchPath;
    QSpacerItem *verticalSpacer_2;
    QLineEdit *u_soAbsPrefix;
    QGroupBox *u_customInitGB;
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *u_customInit;
    QLineEdit *u_gdbCmd;
    QDialogButtonBox *u_buttonBox;
    QFrame *line;

    void setupUi(QWidget *AdvancedGDBSettings)
    {
        if (AdvancedGDBSettings->objectName().isEmpty())
            AdvancedGDBSettings->setObjectName(QStringLiteral("AdvancedGDBSettings"));
        AdvancedGDBSettings->resize(637, 580);
        gridLayout_2 = new QGridLayout(AdvancedGDBSettings);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        u_gdbLabel = new QLabel(AdvancedGDBSettings);
        u_gdbLabel->setObjectName(QStringLiteral("u_gdbLabel"));
        u_gdbLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(u_gdbLabel, 0, 0, 1, 1);

        u_gdbBrowse = new QToolButton(AdvancedGDBSettings);
        u_gdbBrowse->setObjectName(QStringLiteral("u_gdbBrowse"));

        gridLayout_2->addWidget(u_gdbBrowse, 0, 3, 1, 1);

        u_srcPathsLabel = new QLabel(AdvancedGDBSettings);
        u_srcPathsLabel->setObjectName(QStringLiteral("u_srcPathsLabel"));
        u_srcPathsLabel->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout_2->addWidget(u_srcPathsLabel, 1, 0, 1, 1);

        u_srcPaths = new QListWidget(AdvancedGDBSettings);
        u_srcPaths->setObjectName(QStringLiteral("u_srcPaths"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Ignored);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(u_srcPaths->sizePolicy().hasHeightForWidth());
        u_srcPaths->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(u_srcPaths, 1, 1, 1, 2);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        u_addSrcPath = new QToolButton(AdvancedGDBSettings);
        u_addSrcPath->setObjectName(QStringLiteral("u_addSrcPath"));

        verticalLayout_2->addWidget(u_addSrcPath);

        u_delSrcPath = new QToolButton(AdvancedGDBSettings);
        u_delSrcPath->setObjectName(QStringLiteral("u_delSrcPath"));

        verticalLayout_2->addWidget(u_delSrcPath);

        verticalSpacer = new QSpacerItem(2, 2, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        gridLayout_2->addLayout(verticalLayout_2, 1, 3, 1, 1);

        u_localRemote = new QComboBox(AdvancedGDBSettings);
        u_localRemote->setObjectName(QStringLiteral("u_localRemote"));

        gridLayout_2->addWidget(u_localRemote, 3, 0, 1, 1);

        u_remoteStack = new QStackedWidget(AdvancedGDBSettings);
        u_remoteStack->setObjectName(QStringLiteral("u_remoteStack"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(u_remoteStack->sizePolicy().hasHeightForWidth());
        u_remoteStack->setSizePolicy(sizePolicy1);
        empty_2 = new QWidget();
        empty_2->setObjectName(QStringLiteral("empty_2"));
        u_remoteStack->addWidget(empty_2);
        u_remoteTcp = new QWidget();
        u_remoteTcp->setObjectName(QStringLiteral("u_remoteTcp"));
        horizontalLayout_3 = new QHBoxLayout(u_remoteTcp);
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        u_hostLabel = new QLabel(u_remoteTcp);
        u_hostLabel->setObjectName(QStringLiteral("u_hostLabel"));

        horizontalLayout_3->addWidget(u_hostLabel);

        u_tcpHost = new QLineEdit(u_remoteTcp);
        u_tcpHost->setObjectName(QStringLiteral("u_tcpHost"));
        u_tcpHost->setProperty("showClearButton", QVariant(true));

        horizontalLayout_3->addWidget(u_tcpHost);

        u_tcpPortLabel = new QLabel(u_remoteTcp);
        u_tcpPortLabel->setObjectName(QStringLiteral("u_tcpPortLabel"));

        horizontalLayout_3->addWidget(u_tcpPortLabel);

        u_tcpPort = new QLineEdit(u_remoteTcp);
        u_tcpPort->setObjectName(QStringLiteral("u_tcpPort"));
        u_tcpPort->setProperty("showClearButton", QVariant(true));

        horizontalLayout_3->addWidget(u_tcpPort);

        horizontalLayout_3->setStretch(1, 2);
        horizontalLayout_3->setStretch(3, 1);
        u_remoteStack->addWidget(u_remoteTcp);
        u_tcpPort->raise();
        u_tcpHost->raise();
        u_hostLabel->raise();
        u_tcpPortLabel->raise();
        page_2 = new QWidget();
        page_2->setObjectName(QStringLiteral("page_2"));
        horizontalLayout_4 = new QHBoxLayout(page_2);
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        u_ttyLabel = new QLabel(page_2);
        u_ttyLabel->setObjectName(QStringLiteral("u_ttyLabel"));

        horizontalLayout_4->addWidget(u_ttyLabel);

        u_ttyPort = new QLineEdit(page_2);
        u_ttyPort->setObjectName(QStringLiteral("u_ttyPort"));
        u_ttyPort->setProperty("showClearButton", QVariant(true));

        horizontalLayout_4->addWidget(u_ttyPort);

        u_ttyBaudLabel = new QLabel(page_2);
        u_ttyBaudLabel->setObjectName(QStringLiteral("u_ttyBaudLabel"));

        horizontalLayout_4->addWidget(u_ttyBaudLabel);

        u_baudCombo = new QComboBox(page_2);
        u_baudCombo->setObjectName(QStringLiteral("u_baudCombo"));
        u_baudCombo->setEditable(true);

        horizontalLayout_4->addWidget(u_baudCombo);

        u_remoteStack->addWidget(page_2);

        gridLayout_2->addWidget(u_remoteStack, 3, 1, 1, 2);

        u_soAbsPrefixLabel = new QLabel(AdvancedGDBSettings);
        u_soAbsPrefixLabel->setObjectName(QStringLiteral("u_soAbsPrefixLabel"));
        u_soAbsPrefixLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(u_soAbsPrefixLabel, 4, 0, 1, 1);

        u_setSoPrefix = new QToolButton(AdvancedGDBSettings);
        u_setSoPrefix->setObjectName(QStringLiteral("u_setSoPrefix"));

        gridLayout_2->addWidget(u_setSoPrefix, 4, 3, 1, 1);

        u_soSearchLabel = new QLabel(AdvancedGDBSettings);
        u_soSearchLabel->setObjectName(QStringLiteral("u_soSearchLabel"));
        u_soSearchLabel->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout_2->addWidget(u_soSearchLabel, 5, 0, 1, 1);

        u_soSearchPaths = new QListWidget(AdvancedGDBSettings);
        u_soSearchPaths->setObjectName(QStringLiteral("u_soSearchPaths"));
        sizePolicy.setHeightForWidth(u_soSearchPaths->sizePolicy().hasHeightForWidth());
        u_soSearchPaths->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(u_soSearchPaths, 5, 1, 1, 2);

        u_addDelSoPaths = new QWidget(AdvancedGDBSettings);
        u_addDelSoPaths->setObjectName(QStringLiteral("u_addDelSoPaths"));
        verticalLayout_4 = new QVBoxLayout(u_addDelSoPaths);
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        u_addSoSearchPath = new QToolButton(u_addDelSoPaths);
        u_addSoSearchPath->setObjectName(QStringLiteral("u_addSoSearchPath"));

        verticalLayout_4->addWidget(u_addSoSearchPath);

        u_delSoSearchPath = new QToolButton(u_addDelSoPaths);
        u_delSoSearchPath->setObjectName(QStringLiteral("u_delSoSearchPath"));

        verticalLayout_4->addWidget(u_delSoSearchPath);

        verticalSpacer_2 = new QSpacerItem(13, 13, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);


        gridLayout_2->addWidget(u_addDelSoPaths, 5, 3, 1, 1);

        u_soAbsPrefix = new QLineEdit(AdvancedGDBSettings);
        u_soAbsPrefix->setObjectName(QStringLiteral("u_soAbsPrefix"));
        u_soAbsPrefix->setProperty("showClearButton", QVariant(true));

        gridLayout_2->addWidget(u_soAbsPrefix, 4, 1, 1, 2);

        u_customInitGB = new QGroupBox(AdvancedGDBSettings);
        u_customInitGB->setObjectName(QStringLiteral("u_customInitGB"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(u_customInitGB->sizePolicy().hasHeightForWidth());
        u_customInitGB->setSizePolicy(sizePolicy2);
        verticalLayout = new QVBoxLayout(u_customInitGB);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        u_customInit = new QPlainTextEdit(u_customInitGB);
        u_customInit->setObjectName(QStringLiteral("u_customInit"));
        u_customInit->setLineWrapMode(QPlainTextEdit::NoWrap);

        verticalLayout->addWidget(u_customInit);


        gridLayout_2->addWidget(u_customInitGB, 6, 0, 1, 4);

        u_gdbCmd = new QLineEdit(AdvancedGDBSettings);
        u_gdbCmd->setObjectName(QStringLiteral("u_gdbCmd"));
        u_gdbCmd->setProperty("showClearButton", QVariant(true));

        gridLayout_2->addWidget(u_gdbCmd, 0, 1, 1, 2);

        u_buttonBox = new QDialogButtonBox(AdvancedGDBSettings);
        u_buttonBox->setObjectName(QStringLiteral("u_buttonBox"));
        u_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_2->addWidget(u_buttonBox, 7, 0, 1, 4);

        line = new QFrame(AdvancedGDBSettings);
        line->setObjectName(QStringLiteral("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        gridLayout_2->addWidget(line, 2, 0, 1, 4);

        gridLayout_2->setColumnStretch(2, 10);
#ifndef UI_QT_NO_SHORTCUT
        u_gdbLabel->setBuddy(u_gdbCmd);
        u_srcPathsLabel->setBuddy(u_srcPaths);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(u_gdbCmd, u_localRemote);
        QWidget::setTabOrder(u_localRemote, u_soAbsPrefix);
        QWidget::setTabOrder(u_soAbsPrefix, u_setSoPrefix);
        QWidget::setTabOrder(u_setSoPrefix, u_soSearchPaths);
        QWidget::setTabOrder(u_soSearchPaths, u_addSoSearchPath);
        QWidget::setTabOrder(u_addSoSearchPath, u_delSoSearchPath);
        QWidget::setTabOrder(u_delSoSearchPath, u_srcPaths);
        QWidget::setTabOrder(u_srcPaths, u_addSrcPath);
        QWidget::setTabOrder(u_addSrcPath, u_delSrcPath);
        QWidget::setTabOrder(u_delSrcPath, u_customInit);
        QWidget::setTabOrder(u_customInit, u_tcpHost);
        QWidget::setTabOrder(u_tcpHost, u_tcpPort);
        QWidget::setTabOrder(u_tcpPort, u_ttyPort);
        QWidget::setTabOrder(u_ttyPort, u_baudCombo);

        retranslateUi(AdvancedGDBSettings);
        QObject::connect(u_localRemote, SIGNAL(currentIndexChanged(int)), u_remoteStack, SLOT(setCurrentIndex(int)));

        u_remoteStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AdvancedGDBSettings);
    } // setupUi

    void retranslateUi(QWidget *AdvancedGDBSettings)
    {
        u_gdbLabel->setText(tr2i18n("GDB command", 0));
        u_gdbBrowse->setText(tr2i18n("...", 0));
        u_srcPathsLabel->setText(tr2i18n("Source file search paths", 0));
        u_addSrcPath->setText(tr2i18n("...", 0));
        u_delSrcPath->setText(tr2i18n("...", 0));
        u_localRemote->clear();
        u_localRemote->insertItems(0, QStringList()
         << tr2i18n("Local application", 0)
         << tr2i18n("Remote TCP", 0)
         << tr2i18n("Remote Serial Port", 0)
        );
        u_hostLabel->setText(tr2i18n("Host", 0));
        u_tcpPortLabel->setText(tr2i18n("Port", 0));
        u_ttyLabel->setText(tr2i18n("Port", 0));
        u_ttyPort->setText(tr2i18n("/dev/ttyUSB0", "KDE::DoNotExtract"));
        u_ttyBaudLabel->setText(tr2i18n("Baud", 0));
        u_baudCombo->clear();
        u_baudCombo->insertItems(0, QStringList()
         << tr2i18n("9600", "KDE::DoNotExtract")
         << tr2i18n("14400", "KDE::DoNotExtract")
         << tr2i18n("19200", "KDE::DoNotExtract")
         << tr2i18n("38400", "KDE::DoNotExtract")
         << tr2i18n("57600", "KDE::DoNotExtract")
         << tr2i18n("115200", "KDE::DoNotExtract")
        );
        u_soAbsPrefixLabel->setText(tr2i18n("solib-absolute-prefix", 0));
        u_setSoPrefix->setText(tr2i18n("...", 0));
        u_soSearchLabel->setText(tr2i18n("solib-search-path", 0));
        u_addSoSearchPath->setText(tr2i18n("...", 0));
        u_delSoSearchPath->setText(tr2i18n("...", 0));
        u_customInitGB->setTitle(tr2i18n("Custom Init Commands", 0));
        Q_UNUSED(AdvancedGDBSettings);
    } // retranslateUi

};

namespace Ui {
    class AdvancedGDBSettings: public Ui_AdvancedGDBSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADVANCED_SETTINGS_H

