/****************************************************************************
** Meta object code from reading C++ file 'plugin_katebuild.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/katebuild-plugin/plugin_katebuild.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin_katebuild.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateBuildView_t {
    QByteArrayData data[34];
    char stringdata0[478];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateBuildView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateBuildView_t qt_meta_stringdata_KateBuildView = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KateBuildView"
QT_MOC_LITERAL(1, 14, 16), // "slotSelectTarget"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 21), // "slotBuildActiveTarget"
QT_MOC_LITERAL(4, 54, 23), // "slotBuildPreviousTarget"
QT_MOC_LITERAL(5, 78, 22), // "slotBuildDefaultTarget"
QT_MOC_LITERAL(6, 101, 8), // "slotStop"
QT_MOC_LITERAL(7, 110, 14), // "slotProcExited"
QT_MOC_LITERAL(8, 125, 8), // "exitCode"
QT_MOC_LITERAL(9, 134, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(10, 155, 10), // "exitStatus"
QT_MOC_LITERAL(11, 166, 19), // "slotReadReadyStdErr"
QT_MOC_LITERAL(12, 186, 19), // "slotReadReadyStdOut"
QT_MOC_LITERAL(13, 206, 8), // "slotNext"
QT_MOC_LITERAL(14, 215, 8), // "slotPrev"
QT_MOC_LITERAL(15, 224, 17), // "slotErrorSelected"
QT_MOC_LITERAL(16, 242, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(17, 259, 4), // "item"
QT_MOC_LITERAL(18, 264, 12), // "targetSetNew"
QT_MOC_LITERAL(19, 277, 15), // "targetOrSetCopy"
QT_MOC_LITERAL(20, 293, 12), // "targetDelete"
QT_MOC_LITERAL(21, 306, 20), // "slotAddTargetClicked"
QT_MOC_LITERAL(22, 327, 15), // "slotDisplayMode"
QT_MOC_LITERAL(23, 343, 4), // "mode"
QT_MOC_LITERAL(24, 348, 9), // "handleEsc"
QT_MOC_LITERAL(25, 358, 7), // "QEvent*"
QT_MOC_LITERAL(26, 366, 1), // "e"
QT_MOC_LITERAL(27, 368, 21), // "slotPluginViewCreated"
QT_MOC_LITERAL(28, 390, 4), // "name"
QT_MOC_LITERAL(29, 395, 10), // "pluginView"
QT_MOC_LITERAL(30, 406, 21), // "slotPluginViewDeleted"
QT_MOC_LITERAL(31, 428, 21), // "slotProjectMapChanged"
QT_MOC_LITERAL(32, 450, 20), // "slotAddProjectTarget"
QT_MOC_LITERAL(33, 471, 6) // "docUrl"

    },
    "KateBuildView\0slotSelectTarget\0\0"
    "slotBuildActiveTarget\0slotBuildPreviousTarget\0"
    "slotBuildDefaultTarget\0slotStop\0"
    "slotProcExited\0exitCode\0QProcess::ExitStatus\0"
    "exitStatus\0slotReadReadyStdErr\0"
    "slotReadReadyStdOut\0slotNext\0slotPrev\0"
    "slotErrorSelected\0QTreeWidgetItem*\0"
    "item\0targetSetNew\0targetOrSetCopy\0"
    "targetDelete\0slotAddTargetClicked\0"
    "slotDisplayMode\0mode\0handleEsc\0QEvent*\0"
    "e\0slotPluginViewCreated\0name\0pluginView\0"
    "slotPluginViewDeleted\0slotProjectMapChanged\0"
    "slotAddProjectTarget\0docUrl"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateBuildView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       1,  158, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x08 /* Private */,
       3,    0,  120,    2, 0x08 /* Private */,
       4,    0,  121,    2, 0x08 /* Private */,
       5,    0,  122,    2, 0x08 /* Private */,
       6,    0,  123,    2, 0x08 /* Private */,
       7,    2,  124,    2, 0x08 /* Private */,
      11,    0,  129,    2, 0x08 /* Private */,
      12,    0,  130,    2, 0x08 /* Private */,
      13,    0,  131,    2, 0x08 /* Private */,
      14,    0,  132,    2, 0x08 /* Private */,
      15,    1,  133,    2, 0x08 /* Private */,
      18,    0,  136,    2, 0x08 /* Private */,
      19,    0,  137,    2, 0x08 /* Private */,
      20,    0,  138,    2, 0x08 /* Private */,
      21,    0,  139,    2, 0x08 /* Private */,
      22,    1,  140,    2, 0x08 /* Private */,
      24,    1,  143,    2, 0x08 /* Private */,
      27,    2,  146,    2, 0x08 /* Private */,
      30,    2,  151,    2, 0x08 /* Private */,
      31,    0,  156,    2, 0x08 /* Private */,
      32,    0,  157,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 9,    8,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, 0x80000000 | 25,   26,
    QMetaType::Void, QMetaType::QString, QMetaType::QObjectStar,   28,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QObjectStar,   28,   29,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      33, QMetaType::QUrl, 0x00095001,

       0        // eod
};

void KateBuildView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateBuildView *_t = static_cast<KateBuildView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotSelectTarget(); break;
        case 1: _t->slotBuildActiveTarget(); break;
        case 2: _t->slotBuildPreviousTarget(); break;
        case 3: _t->slotBuildDefaultTarget(); break;
        case 4: { bool _r = _t->slotStop();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 5: _t->slotProcExited((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 6: _t->slotReadReadyStdErr(); break;
        case 7: _t->slotReadReadyStdOut(); break;
        case 8: _t->slotNext(); break;
        case 9: _t->slotPrev(); break;
        case 10: _t->slotErrorSelected((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 11: _t->targetSetNew(); break;
        case 12: _t->targetOrSetCopy(); break;
        case 13: _t->targetDelete(); break;
        case 14: _t->slotAddTargetClicked(); break;
        case 15: _t->slotDisplayMode((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->handleEsc((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 17: _t->slotPluginViewCreated((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2]))); break;
        case 18: _t->slotPluginViewDeleted((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2]))); break;
        case 19: _t->slotProjectMapChanged(); break;
        case 20: _t->slotAddProjectTarget(); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KateBuildView *_t = static_cast<KateBuildView *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QUrl*>(_v) = _t->docUrl(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KateBuildView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateBuildView.data,
      qt_meta_data_KateBuildView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateBuildView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateBuildView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateBuildView.stringdata0))
        return static_cast<void*>(const_cast< KateBuildView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KateBuildView*>(this));
    if (!strcmp(_clname, "KTextEditor::SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KateBuildView*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KateBuildView*>(this));
    return QObject::qt_metacast(_clname);
}

int KateBuildView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_KateBuildPlugin_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateBuildPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateBuildPlugin_t qt_meta_stringdata_KateBuildPlugin = {
    {
QT_MOC_LITERAL(0, 0, 15) // "KateBuildPlugin"

    },
    "KateBuildPlugin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateBuildPlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateBuildPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateBuildPlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KateBuildPlugin.data,
      qt_meta_data_KateBuildPlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateBuildPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateBuildPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateBuildPlugin.stringdata0))
        return static_cast<void*>(const_cast< KateBuildPlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KateBuildPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
