/****************************************************************************
** Meta object code from reading C++ file 'replace_matches.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/search/replace_matches.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'replace_matches.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ReplaceMatches_t {
    QByteArrayData data[12];
    char stringdata0[140];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ReplaceMatches_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ReplaceMatches_t qt_meta_stringdata_ReplaceMatches = {
    {
QT_MOC_LITERAL(0, 0, 14), // "ReplaceMatches"
QT_MOC_LITERAL(1, 15, 16), // "replaceNextMatch"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 13), // "matchReplaced"
QT_MOC_LITERAL(4, 47, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(5, 70, 3), // "doc"
QT_MOC_LITERAL(6, 74, 4), // "line"
QT_MOC_LITERAL(7, 79, 6), // "column"
QT_MOC_LITERAL(8, 86, 8), // "matchLen"
QT_MOC_LITERAL(9, 95, 11), // "replaceDone"
QT_MOC_LITERAL(10, 107, 13), // "cancelReplace"
QT_MOC_LITERAL(11, 121, 18) // "doReplaceNextMatch"

    },
    "ReplaceMatches\0replaceNextMatch\0\0"
    "matchReplaced\0KTextEditor::Document*\0"
    "doc\0line\0column\0matchLen\0replaceDone\0"
    "cancelReplace\0doReplaceNextMatch"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ReplaceMatches[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    4,   40,    2, 0x06 /* Public */,
       9,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   50,    2, 0x0a /* Public */,
      11,    0,   51,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int,    5,    6,    7,    8,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ReplaceMatches::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ReplaceMatches *_t = static_cast<ReplaceMatches *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->replaceNextMatch(); break;
        case 1: _t->matchReplaced((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 2: _t->replaceDone(); break;
        case 3: _t->cancelReplace(); break;
        case 4: _t->doReplaceNextMatch(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ReplaceMatches::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ReplaceMatches::replaceNextMatch)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ReplaceMatches::*_t)(KTextEditor::Document * , int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ReplaceMatches::matchReplaced)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ReplaceMatches::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ReplaceMatches::replaceDone)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject ReplaceMatches::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ReplaceMatches.data,
      qt_meta_data_ReplaceMatches,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ReplaceMatches::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReplaceMatches::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ReplaceMatches.stringdata0))
        return static_cast<void*>(const_cast< ReplaceMatches*>(this));
    return QObject::qt_metacast(_clname);
}

int ReplaceMatches::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ReplaceMatches::replaceNextMatch()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void ReplaceMatches::matchReplaced(KTextEditor::Document * _t1, int _t2, int _t3, int _t4)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ReplaceMatches::replaceDone()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
