#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'build.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUILD_H
#define UI_BUILD_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_build
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *u_tabWidget;
    QWidget *errs;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *showLabel;
    QSlider *displayModeSlider;
    QLabel *displayModeLabel;
    QSpacerItem *horizontalSpacer;
    QLabel *buildStatusLabel;
    QPushButton *buildAgainButton;
    QPushButton *cancelBuildButton;
    QHBoxLayout *extraLineLayout;
    QLabel *buildStatusLabel2;
    QPushButton *buildAgainButton2;
    QPushButton *cancelBuildButton2;
    QTreeWidget *errTreeWidget;
    QPlainTextEdit *plainTextEdit;

    void setupUi(QWidget *build)
    {
        if (build->objectName().isEmpty())
            build->setObjectName(QStringLiteral("build"));
        build->resize(407, 178);
        verticalLayout = new QVBoxLayout(build);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        u_tabWidget = new QTabWidget(build);
        u_tabWidget->setObjectName(QStringLiteral("u_tabWidget"));
        errs = new QWidget();
        errs->setObjectName(QStringLiteral("errs"));
        verticalLayout_2 = new QVBoxLayout(errs);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        showLabel = new QLabel(errs);
        showLabel->setObjectName(QStringLiteral("showLabel"));

        horizontalLayout->addWidget(showLabel);

        displayModeSlider = new QSlider(errs);
        displayModeSlider->setObjectName(QStringLiteral("displayModeSlider"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(displayModeSlider->sizePolicy().hasHeightForWidth());
        displayModeSlider->setSizePolicy(sizePolicy);
        displayModeSlider->setMinimumSize(QSize(100, 0));
        displayModeSlider->setMaximum(3);
        displayModeSlider->setPageStep(1);
        displayModeSlider->setOrientation(Qt::Horizontal);
        displayModeSlider->setTickPosition(QSlider::TicksAbove);
        displayModeSlider->setTickInterval(1);

        horizontalLayout->addWidget(displayModeSlider);

        displayModeLabel = new QLabel(errs);
        displayModeLabel->setObjectName(QStringLiteral("displayModeLabel"));

        horizontalLayout->addWidget(displayModeLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buildStatusLabel = new QLabel(errs);
        buildStatusLabel->setObjectName(QStringLiteral("buildStatusLabel"));

        horizontalLayout->addWidget(buildStatusLabel);

        buildAgainButton = new QPushButton(errs);
        buildAgainButton->setObjectName(QStringLiteral("buildAgainButton"));

        horizontalLayout->addWidget(buildAgainButton);

        cancelBuildButton = new QPushButton(errs);
        cancelBuildButton->setObjectName(QStringLiteral("cancelBuildButton"));

        horizontalLayout->addWidget(cancelBuildButton);


        verticalLayout_2->addLayout(horizontalLayout);

        extraLineLayout = new QHBoxLayout();
        extraLineLayout->setObjectName(QStringLiteral("extraLineLayout"));
        buildStatusLabel2 = new QLabel(errs);
        buildStatusLabel2->setObjectName(QStringLiteral("buildStatusLabel2"));

        extraLineLayout->addWidget(buildStatusLabel2);

        buildAgainButton2 = new QPushButton(errs);
        buildAgainButton2->setObjectName(QStringLiteral("buildAgainButton2"));

        extraLineLayout->addWidget(buildAgainButton2);

        cancelBuildButton2 = new QPushButton(errs);
        cancelBuildButton2->setObjectName(QStringLiteral("cancelBuildButton2"));

        extraLineLayout->addWidget(cancelBuildButton2);


        verticalLayout_2->addLayout(extraLineLayout);

        errTreeWidget = new QTreeWidget(errs);
        errTreeWidget->setObjectName(QStringLiteral("errTreeWidget"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(errTreeWidget->sizePolicy().hasHeightForWidth());
        errTreeWidget->setSizePolicy(sizePolicy1);
        errTreeWidget->setAutoScroll(false);
        errTreeWidget->setAlternatingRowColors(true);
        errTreeWidget->setRootIsDecorated(false);
        errTreeWidget->setAllColumnsShowFocus(true);

        verticalLayout_2->addWidget(errTreeWidget);

        plainTextEdit = new QPlainTextEdit(errs);
        plainTextEdit->setObjectName(QStringLiteral("plainTextEdit"));
        plainTextEdit->setReadOnly(true);

        verticalLayout_2->addWidget(plainTextEdit);

        u_tabWidget->addTab(errs, QString());

        verticalLayout->addWidget(u_tabWidget);


        retranslateUi(build);

        u_tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(build);
    } // setupUi

    void retranslateUi(QWidget *build)
    {
        showLabel->setText(tr2i18n("Show:", 0));
        displayModeLabel->setText(QString());
        buildStatusLabel->setText(QString());
        buildAgainButton->setText(tr2i18n("Build again", 0));
        cancelBuildButton->setText(tr2i18n("Cancel", 0));
        buildStatusLabel2->setText(QString());
        buildAgainButton2->setText(tr2i18n("Build again", 0));
        cancelBuildButton2->setText(tr2i18n("Cancel", 0));
        QTreeWidgetItem *___qtreewidgetitem = errTreeWidget->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Message", "Header for the error message column"));
        ___qtreewidgetitem->setText(1, tr2i18n("Line", "Header for the line number column"));
        ___qtreewidgetitem->setText(0, tr2i18n("File", "Header for the file name column"));
        u_tabWidget->setTabText(u_tabWidget->indexOf(errs), tr2i18n("Output", 0));
        Q_UNUSED(build);
    } // retranslateUi

};

namespace Ui {
    class build: public Ui_build {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BUILD_H

