/****************************************************************************
** Meta object code from reading C++ file 'close_except_plugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/close-except-like/close_except_plugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'close_except_plugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_kate__CloseExceptPluginView_t {
    QByteArrayData data[12];
    char stringdata0[172];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_kate__CloseExceptPluginView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_kate__CloseExceptPluginView_t qt_meta_stringdata_kate__CloseExceptPluginView = {
    {
QT_MOC_LITERAL(0, 0, 27), // "kate::CloseExceptPluginView"
QT_MOC_LITERAL(1, 28, 11), // "viewCreated"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(4, 60, 15), // "documentCreated"
QT_MOC_LITERAL(5, 76, 20), // "KTextEditor::Editor*"
QT_MOC_LITERAL(6, 97, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(7, 120, 18), // "updateMenuSlotStub"
QT_MOC_LITERAL(8, 139, 5), // "close"
QT_MOC_LITERAL(9, 145, 11), // "closeExcept"
QT_MOC_LITERAL(10, 157, 4), // "item"
QT_MOC_LITERAL(11, 162, 9) // "closeLike"

    },
    "kate::CloseExceptPluginView\0viewCreated\0"
    "\0KTextEditor::View*\0documentCreated\0"
    "KTextEditor::Editor*\0KTextEditor::Document*\0"
    "updateMenuSlotStub\0close\0closeExcept\0"
    "item\0closeLike"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_kate__CloseExceptPluginView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x08 /* Private */,
       4,    2,   47,    2, 0x08 /* Private */,
       7,    1,   52,    2, 0x08 /* Private */,
       8,    2,   55,    2, 0x08 /* Private */,
       9,    1,   60,    2, 0x08 /* Private */,
      11,    1,   63,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 6,    2,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    2,    2,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,

       0        // eod
};

void kate::CloseExceptPluginView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CloseExceptPluginView *_t = static_cast<CloseExceptPluginView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->viewCreated((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 1: _t->documentCreated((*reinterpret_cast< KTextEditor::Editor*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Document*(*)>(_a[2]))); break;
        case 2: _t->updateMenuSlotStub((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->close((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const bool(*)>(_a[2]))); break;
        case 4: _t->closeExcept((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->closeLike((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Editor* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    }
}

const QMetaObject kate::CloseExceptPluginView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_kate__CloseExceptPluginView.data,
      qt_meta_data_kate__CloseExceptPluginView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *kate::CloseExceptPluginView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kate::CloseExceptPluginView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_kate__CloseExceptPluginView.stringdata0))
        return static_cast<void*>(const_cast< CloseExceptPluginView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< CloseExceptPluginView*>(this));
    return QObject::qt_metacast(_clname);
}

int kate::CloseExceptPluginView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
struct qt_meta_stringdata_kate__CloseExceptPlugin_t {
    QByteArrayData data[4];
    char stringdata0[53];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_kate__CloseExceptPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_kate__CloseExceptPlugin_t qt_meta_stringdata_kate__CloseExceptPlugin = {
    {
QT_MOC_LITERAL(0, 0, 23), // "kate::CloseExceptPlugin"
QT_MOC_LITERAL(1, 24, 22), // "toggleShowConfirmation"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 4) // "flag"

    },
    "kate::CloseExceptPlugin\0toggleShowConfirmation\0"
    "\0flag"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_kate__CloseExceptPlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,

       0        // eod
};

void kate::CloseExceptPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CloseExceptPlugin *_t = static_cast<CloseExceptPlugin *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->toggleShowConfirmation((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject kate::CloseExceptPlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_kate__CloseExceptPlugin.data,
      qt_meta_data_kate__CloseExceptPlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *kate::CloseExceptPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kate::CloseExceptPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_kate__CloseExceptPlugin.stringdata0))
        return static_cast<void*>(const_cast< CloseExceptPlugin*>(this));
    if (!strcmp(_clname, "KTextEditor::SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< CloseExceptPlugin*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< CloseExceptPlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int kate::CloseExceptPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
