/****************************************************************************
** Meta object code from reading C++ file 'katesqlview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/katesql/katesqlview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katesqlview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateSQLView_t {
    QByteArrayData data[23];
    char stringdata0[363];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateSQLView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateSQLView_t qt_meta_stringdata_KateSQLView = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KateSQLView"
QT_MOC_LITERAL(1, 12, 20), // "slotConnectionCreate"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 18), // "slotConnectionEdit"
QT_MOC_LITERAL(4, 53, 20), // "slotConnectionRemove"
QT_MOC_LITERAL(5, 74, 23), // "slotConnectionReconnect"
QT_MOC_LITERAL(6, 98, 21), // "slotConnectionChanged"
QT_MOC_LITERAL(7, 120, 10), // "connection"
QT_MOC_LITERAL(8, 131, 12), // "slotRunQuery"
QT_MOC_LITERAL(9, 144, 9), // "slotError"
QT_MOC_LITERAL(10, 154, 7), // "message"
QT_MOC_LITERAL(11, 162, 11), // "slotSuccess"
QT_MOC_LITERAL(12, 174, 18), // "slotQueryActivated"
QT_MOC_LITERAL(13, 193, 10), // "QSqlQuery&"
QT_MOC_LITERAL(14, 204, 5), // "query"
QT_MOC_LITERAL(15, 210, 21), // "slotConnectionCreated"
QT_MOC_LITERAL(16, 232, 4), // "name"
QT_MOC_LITERAL(17, 237, 25), // "slotGlobalSettingsChanged"
QT_MOC_LITERAL(18, 263, 22), // "slotSQLMenuAboutToShow"
QT_MOC_LITERAL(19, 286, 30), // "slotConnectionSelectedFromMenu"
QT_MOC_LITERAL(20, 317, 8), // "QAction*"
QT_MOC_LITERAL(21, 326, 6), // "action"
QT_MOC_LITERAL(22, 333, 29) // "slotConnectionAboutToBeClosed"

    },
    "KateSQLView\0slotConnectionCreate\0\0"
    "slotConnectionEdit\0slotConnectionRemove\0"
    "slotConnectionReconnect\0slotConnectionChanged\0"
    "connection\0slotRunQuery\0slotError\0"
    "message\0slotSuccess\0slotQueryActivated\0"
    "QSqlQuery&\0query\0slotConnectionCreated\0"
    "name\0slotGlobalSettingsChanged\0"
    "slotSQLMenuAboutToShow\0"
    "slotConnectionSelectedFromMenu\0QAction*\0"
    "action\0slotConnectionAboutToBeClosed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateSQLView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x0a /* Public */,
       3,    0,   85,    2, 0x0a /* Public */,
       4,    0,   86,    2, 0x0a /* Public */,
       5,    0,   87,    2, 0x0a /* Public */,
       6,    1,   88,    2, 0x0a /* Public */,
       8,    0,   91,    2, 0x0a /* Public */,
       9,    1,   92,    2, 0x0a /* Public */,
      11,    1,   95,    2, 0x0a /* Public */,
      12,    2,   98,    2, 0x0a /* Public */,
      15,    1,  103,    2, 0x0a /* Public */,
      17,    0,  106,    2, 0x0a /* Public */,
      18,    0,  107,    2, 0x0a /* Public */,
      19,    1,  108,    2, 0x0a /* Public */,
      22,    1,  111,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, 0x80000000 | 13, QMetaType::QString,   14,    7,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, QMetaType::QString,   16,

       0        // eod
};

void KateSQLView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateSQLView *_t = static_cast<KateSQLView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotConnectionCreate(); break;
        case 1: _t->slotConnectionEdit(); break;
        case 2: _t->slotConnectionRemove(); break;
        case 3: _t->slotConnectionReconnect(); break;
        case 4: _t->slotConnectionChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotRunQuery(); break;
        case 6: _t->slotError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotSuccess((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotQueryActivated((*reinterpret_cast< QSqlQuery(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 9: _t->slotConnectionCreated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->slotGlobalSettingsChanged(); break;
        case 11: _t->slotSQLMenuAboutToShow(); break;
        case 12: _t->slotConnectionSelectedFromMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 13: _t->slotConnectionAboutToBeClosed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KateSQLView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateSQLView.data,
      qt_meta_data_KateSQLView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateSQLView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateSQLView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateSQLView.stringdata0))
        return static_cast<void*>(const_cast< KateSQLView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KateSQLView*>(this));
    return QObject::qt_metacast(_clname);
}

int KateSQLView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
