/****************************************************************************
** Meta object code from reading C++ file 'katebacktracebrowser.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/backtracebrowser/katebacktracebrowser.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katebacktracebrowser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateBtBrowserPlugin_t {
    QByteArrayData data[3];
    char stringdata0[31];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateBtBrowserPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateBtBrowserPlugin_t qt_meta_stringdata_KateBtBrowserPlugin = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateBtBrowserPlugin"
QT_MOC_LITERAL(1, 20, 9), // "newStatus"
QT_MOC_LITERAL(2, 30, 0) // ""

    },
    "KateBtBrowserPlugin\0newStatus\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateBtBrowserPlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void KateBtBrowserPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateBtBrowserPlugin *_t = static_cast<KateBtBrowserPlugin *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newStatus((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateBtBrowserPlugin::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateBtBrowserPlugin::newStatus)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KateBtBrowserPlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KateBtBrowserPlugin.data,
      qt_meta_data_KateBtBrowserPlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateBtBrowserPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateBtBrowserPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateBtBrowserPlugin.stringdata0))
        return static_cast<void*>(const_cast< KateBtBrowserPlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KateBtBrowserPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KateBtBrowserPlugin::newStatus(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KateBtBrowserPluginView_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateBtBrowserPluginView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateBtBrowserPluginView_t qt_meta_stringdata_KateBtBrowserPluginView = {
    {
QT_MOC_LITERAL(0, 0, 23) // "KateBtBrowserPluginView"

    },
    "KateBtBrowserPluginView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateBtBrowserPluginView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateBtBrowserPluginView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateBtBrowserPluginView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateBtBrowserPluginView.data,
      qt_meta_data_KateBtBrowserPluginView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateBtBrowserPluginView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateBtBrowserPluginView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateBtBrowserPluginView.stringdata0))
        return static_cast<void*>(const_cast< KateBtBrowserPluginView*>(this));
    return QObject::qt_metacast(_clname);
}

int KateBtBrowserPluginView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KateBtBrowserWidget_t {
    QByteArrayData data[12];
    char stringdata0[126];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateBtBrowserWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateBtBrowserWidget_t qt_meta_stringdata_KateBtBrowserWidget = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateBtBrowserWidget"
QT_MOC_LITERAL(1, 20, 8), // "loadFile"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 13), // "loadClipboard"
QT_MOC_LITERAL(4, 44, 9), // "configure"
QT_MOC_LITERAL(5, 54, 11), // "clearStatus"
QT_MOC_LITERAL(6, 66, 9), // "setStatus"
QT_MOC_LITERAL(7, 76, 6), // "status"
QT_MOC_LITERAL(8, 83, 13), // "itemActivated"
QT_MOC_LITERAL(9, 97, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(10, 114, 4), // "item"
QT_MOC_LITERAL(11, 119, 6) // "column"

    },
    "KateBtBrowserWidget\0loadFile\0\0"
    "loadClipboard\0configure\0clearStatus\0"
    "setStatus\0status\0itemActivated\0"
    "QTreeWidgetItem*\0item\0column"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateBtBrowserWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x0a /* Public */,
       3,    0,   45,    2, 0x0a /* Public */,
       4,    0,   46,    2, 0x0a /* Public */,
       5,    0,   47,    2, 0x0a /* Public */,
       6,    1,   48,    2, 0x0a /* Public */,
       8,    2,   51,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, 0x80000000 | 9, QMetaType::Int,   10,   11,

       0        // eod
};

void KateBtBrowserWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateBtBrowserWidget *_t = static_cast<KateBtBrowserWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->loadFile(); break;
        case 1: _t->loadClipboard(); break;
        case 2: _t->configure(); break;
        case 3: _t->clearStatus(); break;
        case 4: _t->setStatus((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->itemActivated((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject KateBtBrowserWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KateBtBrowserWidget.data,
      qt_meta_data_KateBtBrowserWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateBtBrowserWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateBtBrowserWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateBtBrowserWidget.stringdata0))
        return static_cast<void*>(const_cast< KateBtBrowserWidget*>(this));
    if (!strcmp(_clname, "Ui::BtBrowserWidget"))
        return static_cast< Ui::BtBrowserWidget*>(const_cast< KateBtBrowserWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int KateBtBrowserWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
struct qt_meta_stringdata_KateBtConfigWidget_t {
    QByteArrayData data[8];
    char stringdata0[64];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateBtConfigWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateBtConfigWidget_t qt_meta_stringdata_KateBtConfigWidget = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KateBtConfigWidget"
QT_MOC_LITERAL(1, 19, 5), // "apply"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 5), // "reset"
QT_MOC_LITERAL(4, 32, 8), // "defaults"
QT_MOC_LITERAL(5, 41, 3), // "add"
QT_MOC_LITERAL(6, 45, 6), // "remove"
QT_MOC_LITERAL(7, 52, 11) // "textChanged"

    },
    "KateBtConfigWidget\0apply\0\0reset\0"
    "defaults\0add\0remove\0textChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateBtConfigWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x0a /* Public */,
       3,    0,   45,    2, 0x0a /* Public */,
       4,    0,   46,    2, 0x0a /* Public */,
       5,    0,   47,    2, 0x08 /* Private */,
       6,    0,   48,    2, 0x08 /* Private */,
       7,    0,   49,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateBtConfigWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateBtConfigWidget *_t = static_cast<KateBtConfigWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->apply(); break;
        case 1: _t->reset(); break;
        case 2: _t->defaults(); break;
        case 3: _t->add(); break;
        case 4: _t->remove(); break;
        case 5: _t->textChanged(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject KateBtConfigWidget::staticMetaObject = {
    { &KTextEditor::ConfigPage::staticMetaObject, qt_meta_stringdata_KateBtConfigWidget.data,
      qt_meta_data_KateBtConfigWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateBtConfigWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateBtConfigWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateBtConfigWidget.stringdata0))
        return static_cast<void*>(const_cast< KateBtConfigWidget*>(this));
    return KTextEditor::ConfigPage::qt_metacast(_clname);
}

int KateBtConfigWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::ConfigPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
struct qt_meta_stringdata_KateBtConfigDialog_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateBtConfigDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateBtConfigDialog_t qt_meta_stringdata_KateBtConfigDialog = {
    {
QT_MOC_LITERAL(0, 0, 18) // "KateBtConfigDialog"

    },
    "KateBtConfigDialog"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateBtConfigDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateBtConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateBtConfigDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KateBtConfigDialog.data,
      qt_meta_data_KateBtConfigDialog,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateBtConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateBtConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateBtConfigDialog.stringdata0))
        return static_cast<void*>(const_cast< KateBtConfigDialog*>(this));
    return QDialog::qt_metacast(_clname);
}

int KateBtConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
