/****************************************************************************
** Meta object code from reading C++ file 'plugin_kateopenheader.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/openheader/plugin_kateopenheader.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin_kateopenheader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_PluginKateOpenHeader_t {
    QByteArrayData data[7];
    char stringdata0[76];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginKateOpenHeader_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginKateOpenHeader_t qt_meta_stringdata_PluginKateOpenHeader = {
    {
QT_MOC_LITERAL(0, 0, 20), // "PluginKateOpenHeader"
QT_MOC_LITERAL(1, 21, 14), // "slotOpenHeader"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 7), // "tryOpen"
QT_MOC_LITERAL(4, 45, 3), // "url"
QT_MOC_LITERAL(5, 49, 10), // "extensions"
QT_MOC_LITERAL(6, 60, 15) // "tryOpenInternal"

    },
    "PluginKateOpenHeader\0slotOpenHeader\0"
    "\0tryOpen\0url\0extensions\0tryOpenInternal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginKateOpenHeader[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x0a /* Public */,
       3,    2,   30,    2, 0x0a /* Public */,
       6,    2,   35,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QStringList,    4,    5,
    QMetaType::Bool, QMetaType::QUrl, QMetaType::QStringList,    4,    5,

       0        // eod
};

void PluginKateOpenHeader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PluginKateOpenHeader *_t = static_cast<PluginKateOpenHeader *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotOpenHeader(); break;
        case 1: _t->tryOpen((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 2: { bool _r = _t->tryOpenInternal((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        default: ;
        }
    }
}

const QMetaObject PluginKateOpenHeader::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_PluginKateOpenHeader.data,
      qt_meta_data_PluginKateOpenHeader,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PluginKateOpenHeader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginKateOpenHeader::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PluginKateOpenHeader.stringdata0))
        return static_cast<void*>(const_cast< PluginKateOpenHeader*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int PluginKateOpenHeader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_PluginViewKateOpenHeader_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginViewKateOpenHeader_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginViewKateOpenHeader_t qt_meta_stringdata_PluginViewKateOpenHeader = {
    {
QT_MOC_LITERAL(0, 0, 24) // "PluginViewKateOpenHeader"

    },
    "PluginViewKateOpenHeader"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginViewKateOpenHeader[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void PluginViewKateOpenHeader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject PluginViewKateOpenHeader::staticMetaObject = {
    { &KTextEditor::Command::staticMetaObject, qt_meta_stringdata_PluginViewKateOpenHeader.data,
      qt_meta_data_PluginViewKateOpenHeader,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PluginViewKateOpenHeader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginViewKateOpenHeader::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PluginViewKateOpenHeader.stringdata0))
        return static_cast<void*>(const_cast< PluginViewKateOpenHeader*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< PluginViewKateOpenHeader*>(this));
    return KTextEditor::Command::qt_metacast(_clname);
}

int PluginViewKateOpenHeader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Command::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
