/****************************************************************************
** Meta object code from reading C++ file 'kateconfigplugindialogpage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/kateconfigplugindialogpage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateconfigplugindialogpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KatePluginListView_t {
    QByteArrayData data[6];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginListView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginListView_t qt_meta_stringdata_KatePluginListView = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KatePluginListView"
QT_MOC_LITERAL(1, 19, 11), // "stateChange"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 19), // "KatePluginListItem*"
QT_MOC_LITERAL(4, 52, 12), // "stateChanged"
QT_MOC_LITERAL(5, 65, 16) // "QTreeWidgetItem*"

    },
    "KatePluginListView\0stateChange\0\0"
    "KatePluginListItem*\0stateChanged\0"
    "QTreeWidgetItem*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginListView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   29,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    2,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 5,    2,

       0        // eod
};

void KatePluginListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KatePluginListView *_t = static_cast<KatePluginListView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->stateChange((*reinterpret_cast< KatePluginListItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->stateChanged((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KatePluginListView::*_t)(KatePluginListItem * , bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KatePluginListView::stateChange)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KatePluginListView::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_KatePluginListView.data,
      qt_meta_data_KatePluginListView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginListView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginListView.stringdata0))
        return static_cast<void*>(const_cast< KatePluginListView*>(this));
    return QTreeWidget::qt_metacast(_clname);
}

int KatePluginListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KatePluginListView::stateChange(KatePluginListItem * _t1, bool _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KateConfigPluginPage_t {
    QByteArrayData data[7];
    char stringdata0[86];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateConfigPluginPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateConfigPluginPage_t qt_meta_stringdata_KateConfigPluginPage = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KateConfigPluginPage"
QT_MOC_LITERAL(1, 21, 7), // "changed"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 11), // "stateChange"
QT_MOC_LITERAL(4, 42, 19), // "KatePluginListItem*"
QT_MOC_LITERAL(5, 62, 10), // "loadPlugin"
QT_MOC_LITERAL(6, 73, 12) // "unloadPlugin"

    },
    "KateConfigPluginPage\0changed\0\0stateChange\0"
    "KatePluginListItem*\0loadPlugin\0"
    "unloadPlugin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateConfigPluginPage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    2,   35,    2, 0x08 /* Private */,
       5,    1,   40,    2, 0x08 /* Private */,
       6,    1,   43,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4, QMetaType::Bool,    2,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,

       0        // eod
};

void KateConfigPluginPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateConfigPluginPage *_t = static_cast<KateConfigPluginPage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->stateChange((*reinterpret_cast< KatePluginListItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->loadPlugin((*reinterpret_cast< KatePluginListItem*(*)>(_a[1]))); break;
        case 3: _t->unloadPlugin((*reinterpret_cast< KatePluginListItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateConfigPluginPage::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateConfigPluginPage::changed)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KateConfigPluginPage::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_KateConfigPluginPage.data,
      qt_meta_data_KateConfigPluginPage,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateConfigPluginPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateConfigPluginPage::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateConfigPluginPage.stringdata0))
        return static_cast<void*>(const_cast< KateConfigPluginPage*>(this));
    return QFrame::qt_metacast(_clname);
}

int KateConfigPluginPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KateConfigPluginPage::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
