/****************************************************************************
** Meta object code from reading C++ file 'kterustcompletionpluginview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/rustcompletion/kterustcompletionpluginview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kterustcompletionpluginview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KTERustCompletionPluginView_t {
    QByteArrayData data[11];
    char stringdata0[154];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTERustCompletionPluginView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTERustCompletionPluginView_t qt_meta_stringdata_KTERustCompletionPluginView = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KTERustCompletionPluginView"
QT_MOC_LITERAL(1, 28, 14), // "goToDefinition"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 11), // "viewChanged"
QT_MOC_LITERAL(4, 56, 11), // "viewCreated"
QT_MOC_LITERAL(5, 68, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(6, 87, 4), // "view"
QT_MOC_LITERAL(7, 92, 13), // "viewDestroyed"
QT_MOC_LITERAL(8, 106, 15), // "documentChanged"
QT_MOC_LITERAL(9, 122, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(10, 145, 8) // "document"

    },
    "KTERustCompletionPluginView\0goToDefinition\0"
    "\0viewChanged\0viewCreated\0KTextEditor::View*\0"
    "view\0viewDestroyed\0documentChanged\0"
    "KTextEditor::Document*\0document"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTERustCompletionPluginView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x08 /* Private */,
       3,    0,   40,    2, 0x08 /* Private */,
       4,    1,   41,    2, 0x08 /* Private */,
       7,    1,   44,    2, 0x08 /* Private */,
       8,    1,   47,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QObjectStar,    6,
    QMetaType::Void, 0x80000000 | 9,   10,

       0        // eod
};

void KTERustCompletionPluginView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KTERustCompletionPluginView *_t = static_cast<KTERustCompletionPluginView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->goToDefinition(); break;
        case 1: _t->viewChanged(); break;
        case 2: _t->viewCreated((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 3: _t->viewDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 4: _t->documentChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KTERustCompletionPluginView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KTERustCompletionPluginView.data,
      qt_meta_data_KTERustCompletionPluginView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KTERustCompletionPluginView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTERustCompletionPluginView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KTERustCompletionPluginView.stringdata0))
        return static_cast<void*>(const_cast< KTERustCompletionPluginView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KTERustCompletionPluginView*>(this));
    return QObject::qt_metacast(_clname);
}

int KTERustCompletionPluginView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
