#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'sessionconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SESSIONCONFIGWIDGET_H
#define UI_SESSIONCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SessionConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *gbElements;
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QSpinBox *spinBoxRecentFilesCount;
    QSpacerItem *horizontalSpacer;
    QCheckBox *restoreVC;
    QGroupBox *gbAppStartup;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *startNewSessionRadioButton;
    QRadioButton *loadLastUserSessionRadioButton;
    QRadioButton *manuallyChooseSessionRadioButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SessionConfigWidget)
    {
        if (SessionConfigWidget->objectName().isEmpty())
            SessionConfigWidget->setObjectName(QStringLiteral("SessionConfigWidget"));
        SessionConfigWidget->resize(490, 294);
        verticalLayout = new QVBoxLayout(SessionConfigWidget);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        gbElements = new QGroupBox(SessionConfigWidget);
        gbElements->setObjectName(QStringLiteral("gbElements"));
        verticalLayout_3 = new QVBoxLayout(gbElements);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        label = new QLabel(gbElements);
        label->setObjectName(QStringLiteral("label"));
        label->setWordWrap(true);

        verticalLayout_3->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label_2 = new QLabel(gbElements);
        label_2->setObjectName(QStringLiteral("label_2"));

        horizontalLayout->addWidget(label_2);

        spinBoxRecentFilesCount = new QSpinBox(gbElements);
        spinBoxRecentFilesCount->setObjectName(QStringLiteral("spinBoxRecentFilesCount"));

        horizontalLayout->addWidget(spinBoxRecentFilesCount);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout);

        restoreVC = new QCheckBox(gbElements);
        restoreVC->setObjectName(QStringLiteral("restoreVC"));

        verticalLayout_3->addWidget(restoreVC);


        verticalLayout->addWidget(gbElements);

        gbAppStartup = new QGroupBox(SessionConfigWidget);
        gbAppStartup->setObjectName(QStringLiteral("gbAppStartup"));
        verticalLayout_2 = new QVBoxLayout(gbAppStartup);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        startNewSessionRadioButton = new QRadioButton(gbAppStartup);
        startNewSessionRadioButton->setObjectName(QStringLiteral("startNewSessionRadioButton"));

        verticalLayout_2->addWidget(startNewSessionRadioButton);

        loadLastUserSessionRadioButton = new QRadioButton(gbAppStartup);
        loadLastUserSessionRadioButton->setObjectName(QStringLiteral("loadLastUserSessionRadioButton"));

        verticalLayout_2->addWidget(loadLastUserSessionRadioButton);

        manuallyChooseSessionRadioButton = new QRadioButton(gbAppStartup);
        manuallyChooseSessionRadioButton->setObjectName(QStringLiteral("manuallyChooseSessionRadioButton"));

        verticalLayout_2->addWidget(manuallyChooseSessionRadioButton);


        verticalLayout->addWidget(gbAppStartup);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#ifndef UI_QT_NO_SHORTCUT
        label_2->setBuddy(spinBoxRecentFilesCount);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(spinBoxRecentFilesCount, restoreVC);
        QWidget::setTabOrder(restoreVC, startNewSessionRadioButton);
        QWidget::setTabOrder(startNewSessionRadioButton, loadLastUserSessionRadioButton);
        QWidget::setTabOrder(loadLastUserSessionRadioButton, manuallyChooseSessionRadioButton);

        retranslateUi(SessionConfigWidget);

        QMetaObject::connectSlotsByName(SessionConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *SessionConfigWidget)
    {
        gbElements->setTitle(tr2i18n("Session Elements", 0));
        label->setText(tr2i18n("The session contains the list of open documents, recently opened files list, bookmarks, cursor position etc. When the session is loaded all elements are restored.", 0));
        label_2->setText(tr2i18n("Maximum number of entries in recent file list:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        restoreVC->setWhatsThis(tr2i18n("Check this if you want all your views and frames restored each time you open Kate.", 0));
#endif // QT_NO_WHATSTHIS
        restoreVC->setText(tr2i18n("Include &window configuration", 0));
        gbAppStartup->setTitle(tr2i18n("Behaviour on Application Startup", 0));
        startNewSessionRadioButton->setText(tr2i18n("&Start new session", 0));
        loadLastUserSessionRadioButton->setText(tr2i18n("&Load last used session", 0));
        manuallyChooseSessionRadioButton->setText(tr2i18n("&Manually choose a session", 0));
        Q_UNUSED(SessionConfigWidget);
    } // retranslateUi

};

namespace Ui {
    class SessionConfigWidget: public Ui_SessionConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SESSIONCONFIGWIDGET_H

