/****************************************************************************
** Meta object code from reading C++ file 'configview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/gdbplugin/configview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ConfigView_t {
    QByteArrayData data[14];
    char stringdata0[169];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ConfigView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ConfigView_t qt_meta_stringdata_ConfigView = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ConfigView"
QT_MOC_LITERAL(1, 11, 6), // "showIO"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 4), // "show"
QT_MOC_LITERAL(4, 24, 16), // "slotTargetEdited"
QT_MOC_LITERAL(5, 41, 7), // "newText"
QT_MOC_LITERAL(6, 49, 18), // "slotTargetSelected"
QT_MOC_LITERAL(7, 68, 5), // "index"
QT_MOC_LITERAL(8, 74, 13), // "slotAddTarget"
QT_MOC_LITERAL(9, 88, 14), // "slotCopyTarget"
QT_MOC_LITERAL(10, 103, 16), // "slotDeleteTarget"
QT_MOC_LITERAL(11, 120, 19), // "slotAdvancedClicked"
QT_MOC_LITERAL(12, 140, 14), // "slotBrowseExec"
QT_MOC_LITERAL(13, 155, 13) // "slotBrowseDir"

    },
    "ConfigView\0showIO\0\0show\0slotTargetEdited\0"
    "newText\0slotTargetSelected\0index\0"
    "slotAddTarget\0slotCopyTarget\0"
    "slotDeleteTarget\0slotAdvancedClicked\0"
    "slotBrowseExec\0slotBrowseDir"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ConfigView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   62,    2, 0x08 /* Private */,
       6,    1,   65,    2, 0x08 /* Private */,
       8,    0,   68,    2, 0x08 /* Private */,
       9,    0,   69,    2, 0x08 /* Private */,
      10,    0,   70,    2, 0x08 /* Private */,
      11,    0,   71,    2, 0x08 /* Private */,
      12,    0,   72,    2, 0x08 /* Private */,
      13,    0,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ConfigView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ConfigView *_t = static_cast<ConfigView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showIO((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->slotTargetEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->slotTargetSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->slotAddTarget(); break;
        case 4: _t->slotCopyTarget(); break;
        case 5: _t->slotDeleteTarget(); break;
        case 6: _t->slotAdvancedClicked(); break;
        case 7: _t->slotBrowseExec(); break;
        case 8: _t->slotBrowseDir(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ConfigView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ConfigView::showIO)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject ConfigView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ConfigView.data,
      qt_meta_data_ConfigView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ConfigView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConfigView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ConfigView.stringdata0))
        return static_cast<void*>(const_cast< ConfigView*>(this));
    return QWidget::qt_metacast(_clname);
}

int ConfigView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ConfigView::showIO(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
