/****************************************************************************
** Meta object code from reading C++ file 'SearchDiskFiles.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/search/SearchDiskFiles.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SearchDiskFiles.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_SearchDiskFiles_t {
    QByteArrayData data[13];
    char stringdata0[112];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SearchDiskFiles_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SearchDiskFiles_t qt_meta_stringdata_SearchDiskFiles = {
    {
QT_MOC_LITERAL(0, 0, 15), // "SearchDiskFiles"
QT_MOC_LITERAL(1, 16, 10), // "matchFound"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 3), // "url"
QT_MOC_LITERAL(4, 32, 7), // "docName"
QT_MOC_LITERAL(5, 40, 4), // "line"
QT_MOC_LITERAL(6, 45, 6), // "column"
QT_MOC_LITERAL(7, 52, 11), // "lineContent"
QT_MOC_LITERAL(8, 64, 8), // "matchLen"
QT_MOC_LITERAL(9, 73, 10), // "searchDone"
QT_MOC_LITERAL(10, 84, 9), // "searching"
QT_MOC_LITERAL(11, 94, 4), // "file"
QT_MOC_LITERAL(12, 99, 12) // "cancelSearch"

    },
    "SearchDiskFiles\0matchFound\0\0url\0docName\0"
    "line\0column\0lineContent\0matchLen\0"
    "searchDone\0searching\0file\0cancelSearch"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SearchDiskFiles[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    6,   34,    2, 0x06 /* Public */,
       9,    0,   47,    2, 0x06 /* Public */,
      10,    1,   48,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,   51,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Int,    3,    4,    5,    6,    7,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   11,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void SearchDiskFiles::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SearchDiskFiles *_t = static_cast<SearchDiskFiles *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->matchFound((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 1: _t->searchDone(); break;
        case 2: _t->searching((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->cancelSearch(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (SearchDiskFiles::*_t)(const QString & , const QString & , int , int , const QString & , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SearchDiskFiles::matchFound)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SearchDiskFiles::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SearchDiskFiles::searchDone)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (SearchDiskFiles::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SearchDiskFiles::searching)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject SearchDiskFiles::staticMetaObject = {
    { &QThread::staticMetaObject, qt_meta_stringdata_SearchDiskFiles.data,
      qt_meta_data_SearchDiskFiles,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *SearchDiskFiles::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchDiskFiles::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_SearchDiskFiles.stringdata0))
        return static_cast<void*>(const_cast< SearchDiskFiles*>(this));
    return QThread::qt_metacast(_clname);
}

int SearchDiskFiles::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SearchDiskFiles::matchFound(const QString & _t1, const QString & _t2, int _t3, int _t4, const QString & _t5, int _t6)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void SearchDiskFiles::searchDone()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void SearchDiskFiles::searching(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_END_MOC_NAMESPACE
