/****************************************************************************
** Meta object code from reading C++ file 'katetabbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/katetabbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katetabbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateTabBar_t {
    QByteArrayData data[19];
    char stringdata0[257];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateTabBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateTabBar_t qt_meta_stringdata_KateTabBar = {
    {
QT_MOC_LITERAL(0, 0, 10), // "KateTabBar"
QT_MOC_LITERAL(1, 11, 14), // "currentChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 2), // "id"
QT_MOC_LITERAL(4, 30, 17), // "closeTabRequested"
QT_MOC_LITERAL(5, 48, 18), // "contextMenuRequest"
QT_MOC_LITERAL(6, 67, 9), // "globalPos"
QT_MOC_LITERAL(7, 77, 17), // "moreTabsRequested"
QT_MOC_LITERAL(8, 95, 5), // "count"
QT_MOC_LITERAL(9, 101, 17), // "lessTabsRequested"
QT_MOC_LITERAL(10, 119, 15), // "newTabRequested"
QT_MOC_LITERAL(11, 135, 26), // "activateViewSpaceRequested"
QT_MOC_LITERAL(12, 162, 13), // "setCurrentTab"
QT_MOC_LITERAL(13, 176, 5), // "index"
QT_MOC_LITERAL(14, 182, 18), // "tabButtonActivated"
QT_MOC_LITERAL(15, 201, 14), // "KateTabButton*"
QT_MOC_LITERAL(16, 216, 9), // "tabButton"
QT_MOC_LITERAL(17, 226, 21), // "tabButtonCloseRequest"
QT_MOC_LITERAL(18, 248, 8) // "isActive"

    },
    "KateTabBar\0currentChanged\0\0id\0"
    "closeTabRequested\0contextMenuRequest\0"
    "globalPos\0moreTabsRequested\0count\0"
    "lessTabsRequested\0newTabRequested\0"
    "activateViewSpaceRequested\0setCurrentTab\0"
    "index\0tabButtonActivated\0KateTabButton*\0"
    "tabButton\0tabButtonCloseRequest\0"
    "isActive"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateTabBar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       1,   92, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,
       5,    2,   70,    2, 0x06 /* Public */,
       7,    1,   75,    2, 0x06 /* Public */,
       9,    1,   78,    2, 0x06 /* Public */,
      10,    0,   81,    2, 0x06 /* Public */,
      11,    0,   82,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,   83,    2, 0x0a /* Public */,
      14,    1,   86,    2, 0x09 /* Protected */,
      17,    1,   89,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::QPoint,    3,    6,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, 0x80000000 | 15,   16,

 // properties: name, type, flags
      18, QMetaType::Bool, 0x00095003,

       0        // eod
};

void KateTabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateTabBar *_t = static_cast<KateTabBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->closeTabRequested((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->contextMenuRequest((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 3: _t->moreTabsRequested((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->lessTabsRequested((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->newTabRequested(); break;
        case 6: _t->activateViewSpaceRequested(); break;
        case 7: _t->setCurrentTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->tabButtonActivated((*reinterpret_cast< KateTabButton*(*)>(_a[1]))); break;
        case 9: _t->tabButtonCloseRequest((*reinterpret_cast< KateTabButton*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabBar::currentChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabBar::closeTabRequested)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KateTabBar::*_t)(int , const QPoint & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabBar::contextMenuRequest)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KateTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabBar::moreTabsRequested)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KateTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabBar::lessTabsRequested)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KateTabBar::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabBar::newTabRequested)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KateTabBar::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabBar::activateViewSpaceRequested)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KateTabBar *_t = static_cast<KateTabBar *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isActive(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KateTabBar *_t = static_cast<KateTabBar *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActive(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KateTabBar::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KateTabBar.data,
      qt_meta_data_KateTabBar,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateTabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateTabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateTabBar.stringdata0))
        return static_cast<void*>(const_cast< KateTabBar*>(this));
    return QWidget::qt_metacast(_clname);
}

int KateTabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KateTabBar::currentChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateTabBar::closeTabRequested(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KateTabBar::contextMenuRequest(int _t1, const QPoint & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KateTabBar::moreTabsRequested(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KateTabBar::lessTabsRequested(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KateTabBar::newTabRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 5, Q_NULLPTR);
}

// SIGNAL 6
void KateTabBar::activateViewSpaceRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
