/****************************************************************************
** Meta object code from reading C++ file 'katefiletreeplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/filetree/katefiletreeplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katefiletreeplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateFileTreePlugin_t {
    QByteArrayData data[4];
    char stringdata0[39];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateFileTreePlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateFileTreePlugin_t qt_meta_stringdata_KateFileTreePlugin = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KateFileTreePlugin"
QT_MOC_LITERAL(1, 19, 13), // "viewDestroyed"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 4) // "view"

    },
    "KateFileTreePlugin\0viewDestroyed\0\0"
    "view"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateFileTreePlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QObjectStar,    3,

       0        // eod
};

void KateFileTreePlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateFileTreePlugin *_t = static_cast<KateFileTreePlugin *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->viewDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KateFileTreePlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KateFileTreePlugin.data,
      qt_meta_data_KateFileTreePlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateFileTreePlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateFileTreePlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateFileTreePlugin.stringdata0))
        return static_cast<void*>(const_cast< KateFileTreePlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KateFileTreePlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_KateFileTreePluginView_t {
    QByteArrayData data[18];
    char stringdata0[316];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateFileTreePluginView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateFileTreePluginView_t qt_meta_stringdata_KateFileTreePluginView = {
    {
QT_MOC_LITERAL(0, 0, 22), // "KateFileTreePluginView"
QT_MOC_LITERAL(1, 23, 12), // "showToolView"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 12), // "hideToolView"
QT_MOC_LITERAL(4, 50, 18), // "showActiveDocument"
QT_MOC_LITERAL(5, 69, 16), // "activateDocument"
QT_MOC_LITERAL(6, 86, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(7, 109, 11), // "viewChanged"
QT_MOC_LITERAL(8, 121, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(9, 140, 14), // "documentOpened"
QT_MOC_LITERAL(10, 155, 14), // "documentClosed"
QT_MOC_LITERAL(11, 170, 15), // "viewModeChanged"
QT_MOC_LITERAL(12, 186, 15), // "sortRoleChanged"
QT_MOC_LITERAL(13, 202, 26), // "slotAboutToCreateDocuments"
QT_MOC_LITERAL(14, 229, 20), // "slotDocumentsCreated"
QT_MOC_LITERAL(15, 250, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(16, 280, 16), // "slotDocumentSave"
QT_MOC_LITERAL(17, 297, 18) // "slotDocumentSaveAs"

    },
    "KateFileTreePluginView\0showToolView\0"
    "\0hideToolView\0showActiveDocument\0"
    "activateDocument\0KTextEditor::Document*\0"
    "viewChanged\0KTextEditor::View*\0"
    "documentOpened\0documentClosed\0"
    "viewModeChanged\0sortRoleChanged\0"
    "slotAboutToCreateDocuments\0"
    "slotDocumentsCreated\0QList<KTextEditor::Document*>\0"
    "slotDocumentSave\0slotDocumentSaveAs"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateFileTreePluginView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x08 /* Private */,
       3,    0,   85,    2, 0x08 /* Private */,
       4,    0,   86,    2, 0x08 /* Private */,
       5,    1,   87,    2, 0x08 /* Private */,
       7,    1,   90,    2, 0x08 /* Private */,
       7,    0,   93,    2, 0x28 /* Private | MethodCloned */,
       9,    1,   94,    2, 0x08 /* Private */,
      10,    1,   97,    2, 0x08 /* Private */,
      11,    1,  100,    2, 0x08 /* Private */,
      12,    1,  103,    2, 0x08 /* Private */,
      13,    0,  106,    2, 0x08 /* Private */,
      14,    1,  107,    2, 0x08 /* Private */,
      16,    0,  110,    2, 0x08 /* Private */,
      17,    0,  111,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateFileTreePluginView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateFileTreePluginView *_t = static_cast<KateFileTreePluginView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showToolView(); break;
        case 1: _t->hideToolView(); break;
        case 2: _t->showActiveDocument(); break;
        case 3: _t->activateDocument((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 4: _t->viewChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 5: _t->viewChanged(); break;
        case 6: _t->documentOpened((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 7: _t->documentClosed((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 8: _t->viewModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->sortRoleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->slotAboutToCreateDocuments(); break;
        case 11: _t->slotDocumentsCreated((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 12: _t->slotDocumentSave(); break;
        case 13: _t->slotDocumentSaveAs(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        }
    }
}

const QMetaObject KateFileTreePluginView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateFileTreePluginView.data,
      qt_meta_data_KateFileTreePluginView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateFileTreePluginView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateFileTreePluginView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateFileTreePluginView.stringdata0))
        return static_cast<void*>(const_cast< KateFileTreePluginView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KateFileTreePluginView*>(this));
    if (!strcmp(_clname, "KTextEditor::SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KateFileTreePluginView*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KateFileTreePluginView*>(this));
    return QObject::qt_metacast(_clname);
}

int KateFileTreePluginView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
