/****************************************************************************
** Meta object code from reading C++ file 'plugin_katexmltools.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/xmltools/plugin_katexmltools.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin_katexmltools.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_PluginKateXMLTools_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginKateXMLTools_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginKateXMLTools_t qt_meta_stringdata_PluginKateXMLTools = {
    {
QT_MOC_LITERAL(0, 0, 18) // "PluginKateXMLTools"

    },
    "PluginKateXMLTools"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginKateXMLTools[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void PluginKateXMLTools::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject PluginKateXMLTools::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_PluginKateXMLTools.data,
      qt_meta_data_PluginKateXMLTools,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PluginKateXMLTools::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginKateXMLTools::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PluginKateXMLTools.stringdata0))
        return static_cast<void*>(const_cast< PluginKateXMLTools*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int PluginKateXMLTools::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_PluginKateXMLToolsCompletionModel_t {
    QByteArrayData data[21];
    char stringdata0[266];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginKateXMLToolsCompletionModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginKateXMLToolsCompletionModel_t qt_meta_stringdata_PluginKateXMLToolsCompletionModel = {
    {
QT_MOC_LITERAL(0, 0, 33), // "PluginKateXMLToolsCompletionM..."
QT_MOC_LITERAL(1, 34, 6), // "getDTD"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 17), // "slotInsertElement"
QT_MOC_LITERAL(4, 60, 16), // "slotCloseElement"
QT_MOC_LITERAL(5, 77, 12), // "slotFinished"
QT_MOC_LITERAL(6, 90, 5), // "KJob*"
QT_MOC_LITERAL(7, 96, 3), // "job"
QT_MOC_LITERAL(8, 100, 8), // "slotData"
QT_MOC_LITERAL(9, 109, 9), // "KIO::Job*"
QT_MOC_LITERAL(10, 119, 4), // "data"
QT_MOC_LITERAL(11, 124, 17), // "completionInvoked"
QT_MOC_LITERAL(12, 142, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(13, 161, 2), // "kv"
QT_MOC_LITERAL(14, 164, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(15, 183, 5), // "range"
QT_MOC_LITERAL(16, 189, 14), // "InvocationType"
QT_MOC_LITERAL(17, 204, 14), // "invocationType"
QT_MOC_LITERAL(18, 219, 19), // "slotDocumentDeleted"
QT_MOC_LITERAL(19, 239, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(20, 262, 3) // "doc"

    },
    "PluginKateXMLToolsCompletionModel\0"
    "getDTD\0\0slotInsertElement\0slotCloseElement\0"
    "slotFinished\0KJob*\0job\0slotData\0"
    "KIO::Job*\0data\0completionInvoked\0"
    "KTextEditor::View*\0kv\0KTextEditor::Range\0"
    "range\0InvocationType\0invocationType\0"
    "slotDocumentDeleted\0KTextEditor::Document*\0"
    "doc"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginKateXMLToolsCompletionModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x0a /* Public */,
       3,    0,   50,    2, 0x0a /* Public */,
       4,    0,   51,    2, 0x0a /* Public */,
       5,    1,   52,    2, 0x0a /* Public */,
       8,    2,   55,    2, 0x0a /* Public */,
      11,    3,   60,    2, 0x0a /* Public */,
      18,    1,   67,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QByteArray,    2,   10,
    QMetaType::Void, 0x80000000 | 12, 0x80000000 | 14, 0x80000000 | 16,   13,   15,   17,
    QMetaType::Void, 0x80000000 | 19,   20,

       0        // eod
};

void PluginKateXMLToolsCompletionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PluginKateXMLToolsCompletionModel *_t = static_cast<PluginKateXMLToolsCompletionModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->getDTD(); break;
        case 1: _t->slotInsertElement(); break;
        case 2: _t->slotCloseElement(); break;
        case 3: _t->slotFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 4: _t->slotData((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 5: _t->completionInvoked((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Range(*)>(_a[2])),(*reinterpret_cast< InvocationType(*)>(_a[3]))); break;
        case 6: _t->slotDocumentDeleted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    }
}

const QMetaObject PluginKateXMLToolsCompletionModel::staticMetaObject = {
    { &KTextEditor::CodeCompletionModel::staticMetaObject, qt_meta_stringdata_PluginKateXMLToolsCompletionModel.data,
      qt_meta_data_PluginKateXMLToolsCompletionModel,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PluginKateXMLToolsCompletionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginKateXMLToolsCompletionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PluginKateXMLToolsCompletionModel.stringdata0))
        return static_cast<void*>(const_cast< PluginKateXMLToolsCompletionModel*>(this));
    if (!strcmp(_clname, "KTextEditor::CodeCompletionModelControllerInterface"))
        return static_cast< KTextEditor::CodeCompletionModelControllerInterface*>(const_cast< PluginKateXMLToolsCompletionModel*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.CodeCompletionModelControllerInterface"))
        return static_cast< KTextEditor::CodeCompletionModelControllerInterface*>(const_cast< PluginKateXMLToolsCompletionModel*>(this));
    return KTextEditor::CodeCompletionModel::qt_metacast(_clname);
}

int PluginKateXMLToolsCompletionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::CodeCompletionModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
struct qt_meta_stringdata_PluginKateXMLToolsView_t {
    QByteArrayData data[1];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginKateXMLToolsView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginKateXMLToolsView_t qt_meta_stringdata_PluginKateXMLToolsView = {
    {
QT_MOC_LITERAL(0, 0, 22) // "PluginKateXMLToolsView"

    },
    "PluginKateXMLToolsView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginKateXMLToolsView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void PluginKateXMLToolsView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject PluginKateXMLToolsView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PluginKateXMLToolsView.data,
      qt_meta_data_PluginKateXMLToolsView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PluginKateXMLToolsView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginKateXMLToolsView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PluginKateXMLToolsView.stringdata0))
        return static_cast<void*>(const_cast< PluginKateXMLToolsView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< PluginKateXMLToolsView*>(this));
    return QObject::qt_metacast(_clname);
}

int PluginKateXMLToolsView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_InsertElement_t {
    QByteArrayData data[3];
    char stringdata0[38];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InsertElement_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InsertElement_t qt_meta_stringdata_InsertElement = {
    {
QT_MOC_LITERAL(0, 0, 13), // "InsertElement"
QT_MOC_LITERAL(1, 14, 22), // "slotHistoryTextChanged"
QT_MOC_LITERAL(2, 37, 0) // ""

    },
    "InsertElement\0slotHistoryTextChanged\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InsertElement[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void InsertElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InsertElement *_t = static_cast<InsertElement *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotHistoryTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject InsertElement::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_InsertElement.data,
      qt_meta_data_InsertElement,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *InsertElement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InsertElement::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_InsertElement.stringdata0))
        return static_cast<void*>(const_cast< InsertElement*>(this));
    return QDialog::qt_metacast(_clname);
}

int InsertElement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
