/****************************************************************************
** Meta object code from reading C++ file 'kateapp.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/kateapp.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateapp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateApp_t {
    QByteArrayData data[23];
    char stringdata0[300];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateApp_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateApp_t qt_meta_stringdata_KateApp = {
    {
QT_MOC_LITERAL(0, 0, 7), // "KateApp"
QT_MOC_LITERAL(1, 8, 11), // "mainWindows"
QT_MOC_LITERAL(2, 20, 31), // "QList<KTextEditor::MainWindow*>"
QT_MOC_LITERAL(3, 52, 0), // ""
QT_MOC_LITERAL(4, 53, 16), // "activeMainWindow"
QT_MOC_LITERAL(5, 70, 24), // "KTextEditor::MainWindow*"
QT_MOC_LITERAL(6, 95, 9), // "documents"
QT_MOC_LITERAL(7, 105, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(8, 135, 7), // "findUrl"
QT_MOC_LITERAL(9, 143, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(10, 166, 3), // "url"
QT_MOC_LITERAL(11, 170, 7), // "openUrl"
QT_MOC_LITERAL(12, 178, 8), // "encoding"
QT_MOC_LITERAL(13, 187, 13), // "closeDocument"
QT_MOC_LITERAL(14, 201, 8), // "document"
QT_MOC_LITERAL(15, 210, 14), // "closeDocuments"
QT_MOC_LITERAL(16, 225, 6), // "plugin"
QT_MOC_LITERAL(17, 232, 20), // "KTextEditor::Plugin*"
QT_MOC_LITERAL(18, 253, 4), // "name"
QT_MOC_LITERAL(19, 258, 4), // "quit"
QT_MOC_LITERAL(20, 263, 21), // "remoteMessageReceived"
QT_MOC_LITERAL(21, 285, 7), // "message"
QT_MOC_LITERAL(22, 293, 6) // "socket"

    },
    "KateApp\0mainWindows\0QList<KTextEditor::MainWindow*>\0"
    "\0activeMainWindow\0KTextEditor::MainWindow*\0"
    "documents\0QList<KTextEditor::Document*>\0"
    "findUrl\0KTextEditor::Document*\0url\0"
    "openUrl\0encoding\0closeDocument\0document\0"
    "closeDocuments\0plugin\0KTextEditor::Plugin*\0"
    "name\0quit\0remoteMessageReceived\0message\0"
    "socket"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateApp[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    3, 0x0a /* Public */,
       4,    0,   70,    3, 0x0a /* Public */,
       6,    0,   71,    3, 0x0a /* Public */,
       8,    1,   72,    3, 0x0a /* Public */,
      11,    2,   75,    3, 0x0a /* Public */,
      11,    1,   80,    3, 0x2a /* Public | MethodCloned */,
      13,    1,   83,    3, 0x0a /* Public */,
      15,    1,   86,    3, 0x0a /* Public */,
      16,    1,   89,    3, 0x0a /* Public */,
      19,    0,   92,    3, 0x0a /* Public */,
      20,    2,   93,    3, 0x0a /* Public */,

 // slots: parameters
    0x80000000 | 2,
    0x80000000 | 5,
    0x80000000 | 7,
    0x80000000 | 9, QMetaType::QUrl,   10,
    0x80000000 | 9, QMetaType::QUrl, QMetaType::QString,   10,   12,
    0x80000000 | 9, QMetaType::QUrl,   10,
    QMetaType::Bool, 0x80000000 | 9,   14,
    QMetaType::Bool, 0x80000000 | 7,    6,
    0x80000000 | 17, QMetaType::QString,   18,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString, QMetaType::QObjectStar,   21,   22,

       0        // eod
};

void KateApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateApp *_t = static_cast<KateApp *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { QList<KTextEditor::MainWindow*> _r = _t->mainWindows();
            if (_a[0]) *reinterpret_cast< QList<KTextEditor::MainWindow*>*>(_a[0]) = _r; }  break;
        case 1: { KTextEditor::MainWindow* _r = _t->activeMainWindow();
            if (_a[0]) *reinterpret_cast< KTextEditor::MainWindow**>(_a[0]) = _r; }  break;
        case 2: { QList<KTextEditor::Document*> _r = _t->documents();
            if (_a[0]) *reinterpret_cast< QList<KTextEditor::Document*>*>(_a[0]) = _r; }  break;
        case 3: { KTextEditor::Document* _r = _t->findUrl((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KTextEditor::Document**>(_a[0]) = _r; }  break;
        case 4: { KTextEditor::Document* _r = _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< KTextEditor::Document**>(_a[0]) = _r; }  break;
        case 5: { KTextEditor::Document* _r = _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KTextEditor::Document**>(_a[0]) = _r; }  break;
        case 6: { bool _r = _t->closeDocument((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 7: { bool _r = _t->closeDocuments((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 8: { KTextEditor::Plugin* _r = _t->plugin((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KTextEditor::Plugin**>(_a[0]) = _r; }  break;
        case 9: { bool _r = _t->quit();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 10: _t->remoteMessageReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        }
    }
}

const QMetaObject KateApp::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateApp.data,
      qt_meta_data_KateApp,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateApp::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateApp.stringdata0))
        return static_cast<void*>(const_cast< KateApp*>(this));
    return QObject::qt_metacast(_clname);
}

int KateApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
