#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'editrepository.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITREPOSITORY_H
#define UI_EDITREPOSITORY_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_EditRepositoryBase
{
public:
    QVBoxLayout *verticalLayout_2;
    QWidget *widget;
    QFormLayout *formLayout;
    QLabel *repoNameLabel;
    QLabel *repoNamespaceLabel;
    QLabel *repoLicenseLabel;
    QComboBox *repoLicenseEdit;
    QLabel *repoAuthorsLabel;
    KLineEdit *repoAuthorsEdit;
    QLabel *repoFileTypesLabel;
    QLabel *repoFileTypesListLabel;
    QListWidget *repoFileTypesList;
    QDialogButtonBox *buttonBox;
    QLineEdit *repoNameEdit;
    QLineEdit *repoNamespaceEdit;

    void setupUi(QWidget *EditRepositoryBase)
    {
        if (EditRepositoryBase->objectName().isEmpty())
            EditRepositoryBase->setObjectName(QStringLiteral("EditRepositoryBase"));
        EditRepositoryBase->resize(500, 323);
        EditRepositoryBase->setMinimumSize(QSize(500, 0));
        verticalLayout_2 = new QVBoxLayout(EditRepositoryBase);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        widget = new QWidget(EditRepositoryBase);
        widget->setObjectName(QStringLiteral("widget"));
        formLayout = new QFormLayout(widget);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        repoNameLabel = new QLabel(widget);
        repoNameLabel->setObjectName(QStringLiteral("repoNameLabel"));

        formLayout->setWidget(0, QFormLayout::LabelRole, repoNameLabel);

        repoNamespaceLabel = new QLabel(widget);
        repoNamespaceLabel->setObjectName(QStringLiteral("repoNamespaceLabel"));

        formLayout->setWidget(1, QFormLayout::LabelRole, repoNamespaceLabel);

        repoLicenseLabel = new QLabel(widget);
        repoLicenseLabel->setObjectName(QStringLiteral("repoLicenseLabel"));

        formLayout->setWidget(3, QFormLayout::LabelRole, repoLicenseLabel);

        repoLicenseEdit = new QComboBox(widget);
        repoLicenseEdit->setObjectName(QStringLiteral("repoLicenseEdit"));

        formLayout->setWidget(3, QFormLayout::FieldRole, repoLicenseEdit);

        repoAuthorsLabel = new QLabel(widget);
        repoAuthorsLabel->setObjectName(QStringLiteral("repoAuthorsLabel"));

        formLayout->setWidget(4, QFormLayout::LabelRole, repoAuthorsLabel);

        repoAuthorsEdit = new KLineEdit(widget);
        repoAuthorsEdit->setObjectName(QStringLiteral("repoAuthorsEdit"));

        formLayout->setWidget(4, QFormLayout::FieldRole, repoAuthorsEdit);

        repoFileTypesLabel = new QLabel(widget);
        repoFileTypesLabel->setObjectName(QStringLiteral("repoFileTypesLabel"));

        formLayout->setWidget(5, QFormLayout::LabelRole, repoFileTypesLabel);

        repoFileTypesListLabel = new QLabel(widget);
        repoFileTypesListLabel->setObjectName(QStringLiteral("repoFileTypesListLabel"));
        repoFileTypesListLabel->setText(QStringLiteral("list of selected filetypes"));

        formLayout->setWidget(5, QFormLayout::FieldRole, repoFileTypesListLabel);

        repoFileTypesList = new QListWidget(widget);
        repoFileTypesList->setObjectName(QStringLiteral("repoFileTypesList"));

        formLayout->setWidget(6, QFormLayout::SpanningRole, repoFileTypesList);

        buttonBox = new QDialogButtonBox(widget);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(7, QFormLayout::SpanningRole, buttonBox);

        repoNameEdit = new QLineEdit(widget);
        repoNameEdit->setObjectName(QStringLiteral("repoNameEdit"));

        formLayout->setWidget(0, QFormLayout::FieldRole, repoNameEdit);

        repoNamespaceEdit = new QLineEdit(widget);
        repoNamespaceEdit->setObjectName(QStringLiteral("repoNamespaceEdit"));

        formLayout->setWidget(1, QFormLayout::FieldRole, repoNamespaceEdit);


        verticalLayout_2->addWidget(widget);

#ifndef UI_QT_NO_SHORTCUT
        repoLicenseLabel->setBuddy(repoLicenseEdit);
        repoAuthorsLabel->setBuddy(repoAuthorsEdit);
        repoFileTypesLabel->setBuddy(repoFileTypesList);
#endif // QT_NO_SHORTCUT

        retranslateUi(EditRepositoryBase);

        QMetaObject::connectSlotsByName(EditRepositoryBase);
    } // setupUi

    void retranslateUi(QWidget *EditRepositoryBase)
    {
        repoNameLabel->setText(tr2i18n("Name:", 0));
        repoNamespaceLabel->setText(tr2i18n("Namespace:", 0));
        repoLicenseLabel->setText(tr2i18n("&License:", 0));
        repoAuthorsLabel->setText(tr2i18n("&Authors:", 0));
        repoFileTypesLabel->setText(tr2i18n("&File types:", 0));
        repoNameEdit->setPlaceholderText(tr2i18n("A short name for the repository", 0));
        repoNamespaceEdit->setPlaceholderText(tr2i18n("Prefix to show in code completion", 0));
        Q_UNUSED(EditRepositoryBase);
    } // retranslateUi

};

namespace Ui {
    class EditRepositoryBase: public Ui_EditRepositoryBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITREPOSITORY_H

