#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'search.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCH_H
#define UI_SEARCH_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SearchDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QToolButton *newTabButton;
    QLabel *findLabel;
    QComboBox *searchCombo;
    QPushButton *searchButton;
    QStackedWidget *stopAndNext;
    QWidget *page_3;
    QHBoxLayout *horizontalLayout;
    QPushButton *nextButton;
    QWidget *stopButtonPage;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *stopButton;
    QComboBox *searchPlaceCombo;
    QToolButton *displayOptions;
    QLabel *replaceLabel;
    QComboBox *replaceCombo;
    QPushButton *replaceButton;
    QPushButton *replaceCheckedBtn;
    QToolButton *matchCase;
    QToolButton *useRegExp;
    QSpacerItem *horizontalSpacer_3;
    QToolButton *expandResults;
    QToolButton *currentFolderButton;
    QStackedWidget *stackedWidget;
    QWidget *resultPage;
    QVBoxLayout *verticalLayout;
    QTabWidget *resultTabWidget;
    QWidget *optionsPage;
    QGridLayout *optionsLayout;
    QSpacerItem *verticalSpacer;
    QWidget *folderOptions;
    QGridLayout *gridLayout_2;
    QFrame *line;
    QLabel *folderLabel;
    QHBoxLayout *horizontalLayout_3;
    KUrlComboRequester *folderRequester;
    QToolButton *folderUpButton;
    QLabel *filterLabel;
    QHBoxLayout *horizontalLayout_5;
    KComboBox *filterCombo;
    QLabel *excludeLabel;
    KComboBox *excludeCombo;
    QHBoxLayout *horizontalLayout_6;
    QCheckBox *recursiveCheckBox;
    QCheckBox *hiddenCheckBox;
    QCheckBox *symLinkCheckBox;
    QCheckBox *binaryCheckBox;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *SearchDialog)
    {
        if (SearchDialog->objectName().isEmpty())
            SearchDialog->setObjectName(QStringLiteral("SearchDialog"));
        SearchDialog->resize(634, 204);
        verticalLayout_2 = new QVBoxLayout(SearchDialog);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        newTabButton = new QToolButton(SearchDialog);
        newTabButton->setObjectName(QStringLiteral("newTabButton"));

        gridLayout->addWidget(newTabButton, 0, 0, 1, 1);

        findLabel = new QLabel(SearchDialog);
        findLabel->setObjectName(QStringLiteral("findLabel"));

        gridLayout->addWidget(findLabel, 0, 1, 1, 1, Qt::AlignRight);

        searchCombo = new QComboBox(SearchDialog);
        searchCombo->setObjectName(QStringLiteral("searchCombo"));
        searchCombo->setEditable(true);

        gridLayout->addWidget(searchCombo, 0, 2, 1, 1);

        searchButton = new QPushButton(SearchDialog);
        searchButton->setObjectName(QStringLiteral("searchButton"));
        searchButton->setEnabled(false);

        gridLayout->addWidget(searchButton, 0, 3, 1, 1);

        stopAndNext = new QStackedWidget(SearchDialog);
        stopAndNext->setObjectName(QStringLiteral("stopAndNext"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(stopAndNext->sizePolicy().hasHeightForWidth());
        stopAndNext->setSizePolicy(sizePolicy);
        page_3 = new QWidget();
        page_3->setObjectName(QStringLiteral("page_3"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(page_3->sizePolicy().hasHeightForWidth());
        page_3->setSizePolicy(sizePolicy1);
        horizontalLayout = new QHBoxLayout(page_3);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        nextButton = new QPushButton(page_3);
        nextButton->setObjectName(QStringLiteral("nextButton"));
        nextButton->setEnabled(false);

        horizontalLayout->addWidget(nextButton);

        stopAndNext->addWidget(page_3);
        stopButtonPage = new QWidget();
        stopButtonPage->setObjectName(QStringLiteral("stopButtonPage"));
        sizePolicy1.setHeightForWidth(stopButtonPage->sizePolicy().hasHeightForWidth());
        stopButtonPage->setSizePolicy(sizePolicy1);
        horizontalLayout_2 = new QHBoxLayout(stopButtonPage);
        horizontalLayout_2->setSpacing(0);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        stopButton = new QPushButton(stopButtonPage);
        stopButton->setObjectName(QStringLiteral("stopButton"));
        sizePolicy.setHeightForWidth(stopButton->sizePolicy().hasHeightForWidth());
        stopButton->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(stopButton);

        stopAndNext->addWidget(stopButtonPage);

        gridLayout->addWidget(stopAndNext, 0, 4, 1, 1);

        searchPlaceCombo = new QComboBox(SearchDialog);
        searchPlaceCombo->setObjectName(QStringLiteral("searchPlaceCombo"));

        gridLayout->addWidget(searchPlaceCombo, 0, 5, 1, 5);

        displayOptions = new QToolButton(SearchDialog);
        displayOptions->setObjectName(QStringLiteral("displayOptions"));
        displayOptions->setCheckable(true);

        gridLayout->addWidget(displayOptions, 1, 0, 1, 1);

        replaceLabel = new QLabel(SearchDialog);
        replaceLabel->setObjectName(QStringLiteral("replaceLabel"));

        gridLayout->addWidget(replaceLabel, 1, 1, 1, 1);

        replaceCombo = new QComboBox(SearchDialog);
        replaceCombo->setObjectName(QStringLiteral("replaceCombo"));
        replaceCombo->setEditable(true);

        gridLayout->addWidget(replaceCombo, 1, 2, 1, 1);

        replaceButton = new QPushButton(SearchDialog);
        replaceButton->setObjectName(QStringLiteral("replaceButton"));
        replaceButton->setEnabled(false);

        gridLayout->addWidget(replaceButton, 1, 3, 1, 1);

        replaceCheckedBtn = new QPushButton(SearchDialog);
        replaceCheckedBtn->setObjectName(QStringLiteral("replaceCheckedBtn"));
        replaceCheckedBtn->setEnabled(false);

        gridLayout->addWidget(replaceCheckedBtn, 1, 4, 1, 1);

        matchCase = new QToolButton(SearchDialog);
        matchCase->setObjectName(QStringLiteral("matchCase"));
        matchCase->setCheckable(true);
        matchCase->setAutoRaise(true);

        gridLayout->addWidget(matchCase, 1, 5, 1, 1);

        useRegExp = new QToolButton(SearchDialog);
        useRegExp->setObjectName(QStringLiteral("useRegExp"));
        useRegExp->setCheckable(true);
        useRegExp->setAutoRaise(true);

        gridLayout->addWidget(useRegExp, 1, 6, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(13, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 1, 7, 1, 1);

        expandResults = new QToolButton(SearchDialog);
        expandResults->setObjectName(QStringLiteral("expandResults"));
        expandResults->setCheckable(true);
        expandResults->setAutoRaise(true);

        gridLayout->addWidget(expandResults, 1, 8, 1, 1);

        currentFolderButton = new QToolButton(SearchDialog);
        currentFolderButton->setObjectName(QStringLiteral("currentFolderButton"));

        gridLayout->addWidget(currentFolderButton, 1, 9, 1, 1);

        gridLayout->setColumnStretch(2, 1);

        verticalLayout_2->addLayout(gridLayout);

        stackedWidget = new QStackedWidget(SearchDialog);
        stackedWidget->setObjectName(QStringLiteral("stackedWidget"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(stackedWidget->sizePolicy().hasHeightForWidth());
        stackedWidget->setSizePolicy(sizePolicy2);
        resultPage = new QWidget();
        resultPage->setObjectName(QStringLiteral("resultPage"));
        verticalLayout = new QVBoxLayout(resultPage);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        resultTabWidget = new QTabWidget(resultPage);
        resultTabWidget->setObjectName(QStringLiteral("resultTabWidget"));
        resultTabWidget->setTabsClosable(true);
        resultTabWidget->setMovable(true);

        verticalLayout->addWidget(resultTabWidget);

        stackedWidget->addWidget(resultPage);
        optionsPage = new QWidget();
        optionsPage->setObjectName(QStringLiteral("optionsPage"));
        optionsLayout = new QGridLayout(optionsPage);
        optionsLayout->setObjectName(QStringLiteral("optionsLayout"));
        optionsLayout->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);

        optionsLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        folderOptions = new QWidget(optionsPage);
        folderOptions->setObjectName(QStringLiteral("folderOptions"));
        QSizePolicy sizePolicy3(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(folderOptions->sizePolicy().hasHeightForWidth());
        folderOptions->setSizePolicy(sizePolicy3);
        gridLayout_2 = new QGridLayout(folderOptions);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        line = new QFrame(folderOptions);
        line->setObjectName(QStringLiteral("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        gridLayout_2->addWidget(line, 0, 0, 1, 2);

        folderLabel = new QLabel(folderOptions);
        folderLabel->setObjectName(QStringLiteral("folderLabel"));
        folderLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(folderLabel, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        folderRequester = new KUrlComboRequester(folderOptions);
        folderRequester->setObjectName(QStringLiteral("folderRequester"));

        horizontalLayout_3->addWidget(folderRequester);

        folderUpButton = new QToolButton(folderOptions);
        folderUpButton->setObjectName(QStringLiteral("folderUpButton"));

        horizontalLayout_3->addWidget(folderUpButton);


        gridLayout_2->addLayout(horizontalLayout_3, 1, 1, 1, 1);

        filterLabel = new QLabel(folderOptions);
        filterLabel->setObjectName(QStringLiteral("filterLabel"));
        filterLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(filterLabel, 2, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        filterCombo = new KComboBox(folderOptions);
        filterCombo->setObjectName(QStringLiteral("filterCombo"));
        filterCombo->setEditable(true);
        filterCombo->setInsertPolicy(QComboBox::InsertAtTop);

        horizontalLayout_5->addWidget(filterCombo);

        excludeLabel = new QLabel(folderOptions);
        excludeLabel->setObjectName(QStringLiteral("excludeLabel"));

        horizontalLayout_5->addWidget(excludeLabel);

        excludeCombo = new KComboBox(folderOptions);
        excludeCombo->setObjectName(QStringLiteral("excludeCombo"));
        excludeCombo->setEditable(true);

        horizontalLayout_5->addWidget(excludeCombo);

        horizontalLayout_5->setStretch(0, 10);
        horizontalLayout_5->setStretch(2, 10);

        gridLayout_2->addLayout(horizontalLayout_5, 2, 1, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        recursiveCheckBox = new QCheckBox(folderOptions);
        recursiveCheckBox->setObjectName(QStringLiteral("recursiveCheckBox"));
        recursiveCheckBox->setChecked(true);

        horizontalLayout_6->addWidget(recursiveCheckBox);

        hiddenCheckBox = new QCheckBox(folderOptions);
        hiddenCheckBox->setObjectName(QStringLiteral("hiddenCheckBox"));

        horizontalLayout_6->addWidget(hiddenCheckBox);

        symLinkCheckBox = new QCheckBox(folderOptions);
        symLinkCheckBox->setObjectName(QStringLiteral("symLinkCheckBox"));

        horizontalLayout_6->addWidget(symLinkCheckBox);

        binaryCheckBox = new QCheckBox(folderOptions);
        binaryCheckBox->setObjectName(QStringLiteral("binaryCheckBox"));

        horizontalLayout_6->addWidget(binaryCheckBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout_6, 3, 1, 1, 1);


        optionsLayout->addWidget(folderOptions, 0, 0, 1, 1);

        stackedWidget->addWidget(optionsPage);

        verticalLayout_2->addWidget(stackedWidget);

#ifndef UI_QT_NO_SHORTCUT
        findLabel->setBuddy(searchCombo);
        replaceLabel->setBuddy(replaceCombo);
        folderLabel->setBuddy(folderRequester);
        filterLabel->setBuddy(filterCombo);
        excludeLabel->setBuddy(excludeCombo);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(newTabButton, searchCombo);
        QWidget::setTabOrder(searchCombo, replaceCombo);
        QWidget::setTabOrder(replaceCombo, searchButton);
        QWidget::setTabOrder(searchButton, nextButton);
        QWidget::setTabOrder(nextButton, stopButton);
        QWidget::setTabOrder(stopButton, replaceButton);
        QWidget::setTabOrder(replaceButton, replaceCheckedBtn);
        QWidget::setTabOrder(replaceCheckedBtn, searchPlaceCombo);
        QWidget::setTabOrder(searchPlaceCombo, matchCase);
        QWidget::setTabOrder(matchCase, useRegExp);
        QWidget::setTabOrder(useRegExp, expandResults);
        QWidget::setTabOrder(expandResults, currentFolderButton);
        QWidget::setTabOrder(currentFolderButton, displayOptions);
        QWidget::setTabOrder(displayOptions, folderRequester);
        QWidget::setTabOrder(folderRequester, folderUpButton);
        QWidget::setTabOrder(folderUpButton, filterCombo);
        QWidget::setTabOrder(filterCombo, excludeCombo);
        QWidget::setTabOrder(excludeCombo, recursiveCheckBox);
        QWidget::setTabOrder(recursiveCheckBox, hiddenCheckBox);
        QWidget::setTabOrder(hiddenCheckBox, symLinkCheckBox);
        QWidget::setTabOrder(symLinkCheckBox, binaryCheckBox);
        QWidget::setTabOrder(binaryCheckBox, resultTabWidget);

        retranslateUi(SearchDialog);

        stopAndNext->setCurrentIndex(0);
        stackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(SearchDialog);
    } // setupUi

    void retranslateUi(QWidget *SearchDialog)
    {
        newTabButton->setText(tr2i18n("...", 0));
        findLabel->setText(tr2i18n("Find:", 0));
#ifndef UI_QT_NO_TOOLTIP
        searchButton->setToolTip(tr2i18n("Search", 0));
#endif // QT_NO_TOOLTIP
        searchButton->setText(tr2i18n("Search", 0));
#ifndef UI_QT_NO_TOOLTIP
        nextButton->setToolTip(tr2i18n("Next", 0));
#endif // QT_NO_TOOLTIP
        nextButton->setText(tr2i18n("Next", 0));
        stopButton->setText(tr2i18n("Stop", 0));
        searchPlaceCombo->clear();
        searchPlaceCombo->insertItems(0, QStringList()
         << tr2i18n("In Current File", 0)
         << tr2i18n("in Open Files", 0)
         << tr2i18n("in Folder", 0)
        );
        displayOptions->setText(tr2i18n("...", 0));
        replaceLabel->setText(tr2i18n("Replace:", 0));
        replaceButton->setText(tr2i18n("Replace", 0));
        replaceCheckedBtn->setText(tr2i18n("Replace checked", 0));
#ifndef UI_QT_NO_TOOLTIP
        matchCase->setToolTip(tr2i18n("Match Case", 0));
#endif // QT_NO_TOOLTIP
        matchCase->setText(QString());
#ifndef UI_QT_NO_TOOLTIP
        useRegExp->setToolTip(tr2i18n("Use regular expressions", 0));
#endif // QT_NO_TOOLTIP
        useRegExp->setText(QString());
#ifndef UI_QT_NO_TOOLTIP
        expandResults->setToolTip(tr2i18n("Expand results", 0));
#endif // QT_NO_TOOLTIP
        expandResults->setText(QString());
#ifndef UI_QT_NO_TOOLTIP
        currentFolderButton->setToolTip(tr2i18n("Use the current document's path.", 0));
#endif // QT_NO_TOOLTIP
        folderLabel->setText(tr2i18n("Folder:", 0));
#ifndef UI_QT_NO_TOOLTIP
        folderUpButton->setToolTip(tr2i18n("Go one folder up.", 0));
#endif // QT_NO_TOOLTIP
        filterLabel->setText(tr2i18n("Filter:", 0));
        filterCombo->clear();
        filterCombo->insertItems(0, QStringList()
         << tr2i18n("*", 0)
        );
        excludeLabel->setText(tr2i18n("Exclude:", 0));
        recursiveCheckBox->setText(tr2i18n("Recursive", 0));
        hiddenCheckBox->setText(tr2i18n("Include hidden", 0));
        symLinkCheckBox->setText(tr2i18n("Follow symbolic links", 0));
        binaryCheckBox->setText(tr2i18n("Include binary files", 0));
        Q_UNUSED(SearchDialog);
    } // retranslateUi

};

namespace Ui {
    class SearchDialog: public Ui_SearchDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCH_H

