/****************************************************************************
** Meta object code from reading C++ file 'kateconsole.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/konsole/kateconsole.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateconsole.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateKonsolePlugin_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateKonsolePlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateKonsolePlugin_t qt_meta_stringdata_KateKonsolePlugin = {
    {
QT_MOC_LITERAL(0, 0, 17) // "KateKonsolePlugin"

    },
    "KateKonsolePlugin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateKonsolePlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateKonsolePlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateKonsolePlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KateKonsolePlugin.data,
      qt_meta_data_KateKonsolePlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateKonsolePlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateKonsolePlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateKonsolePlugin.stringdata0))
        return static_cast<void*>(const_cast< KateKonsolePlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KateKonsolePlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KateKonsolePluginView_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateKonsolePluginView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateKonsolePluginView_t qt_meta_stringdata_KateKonsolePluginView = {
    {
QT_MOC_LITERAL(0, 0, 21) // "KateKonsolePluginView"

    },
    "KateKonsolePluginView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateKonsolePluginView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateKonsolePluginView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateKonsolePluginView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateKonsolePluginView.data,
      qt_meta_data_KateKonsolePluginView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateKonsolePluginView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateKonsolePluginView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateKonsolePluginView.stringdata0))
        return static_cast<void*>(const_cast< KateKonsolePluginView*>(this));
    return QObject::qt_metacast(_clname);
}

int KateKonsolePluginView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KateConsole_t {
    QByteArrayData data[15];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateConsole_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateConsole_t qt_meta_stringdata_KateConsole = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KateConsole"
QT_MOC_LITERAL(1, 12, 17), // "slotPipeToConsole"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 8), // "slotSync"
QT_MOC_LITERAL(4, 40, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(5, 59, 4), // "view"
QT_MOC_LITERAL(6, 64, 14), // "slotManualSync"
QT_MOC_LITERAL(7, 79, 13), // "slotDestroyed"
QT_MOC_LITERAL(8, 93, 19), // "loadConsoleIfNeeded"
QT_MOC_LITERAL(9, 113, 15), // "slotToggleFocus"
QT_MOC_LITERAL(10, 129, 16), // "overrideShortcut"
QT_MOC_LITERAL(11, 146, 10), // "QKeyEvent*"
QT_MOC_LITERAL(12, 157, 5), // "event"
QT_MOC_LITERAL(13, 163, 5), // "bool&"
QT_MOC_LITERAL(14, 169, 8) // "override"

    },
    "KateConsole\0slotPipeToConsole\0\0slotSync\0"
    "KTextEditor::View*\0view\0slotManualSync\0"
    "slotDestroyed\0loadConsoleIfNeeded\0"
    "slotToggleFocus\0overrideShortcut\0"
    "QKeyEvent*\0event\0bool&\0override"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateConsole[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x0a /* Public */,
       3,    1,   55,    2, 0x0a /* Public */,
       3,    0,   58,    2, 0x2a /* Public | MethodCloned */,
       6,    0,   59,    2, 0x0a /* Public */,
       7,    0,   60,    2, 0x08 /* Private */,
       8,    0,   61,    2, 0x08 /* Private */,
       9,    0,   62,    2, 0x08 /* Private */,
      10,    2,   63,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11, 0x80000000 | 13,   12,   14,

       0        // eod
};

void KateConsole::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateConsole *_t = static_cast<KateConsole *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotPipeToConsole(); break;
        case 1: _t->slotSync((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 2: _t->slotSync(); break;
        case 3: _t->slotManualSync(); break;
        case 4: _t->slotDestroyed(); break;
        case 5: _t->loadConsoleIfNeeded(); break;
        case 6: _t->slotToggleFocus(); break;
        case 7: _t->overrideShortcut((*reinterpret_cast< QKeyEvent*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject KateConsole::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KateConsole.data,
      qt_meta_data_KateConsole,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateConsole::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateConsole::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateConsole.stringdata0))
        return static_cast<void*>(const_cast< KateConsole*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KateConsole*>(this));
    return QWidget::qt_metacast(_clname);
}

int KateConsole::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
struct qt_meta_stringdata_KateKonsoleConfigPage_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateKonsoleConfigPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateKonsoleConfigPage_t qt_meta_stringdata_KateKonsoleConfigPage = {
    {
QT_MOC_LITERAL(0, 0, 21) // "KateKonsoleConfigPage"

    },
    "KateKonsoleConfigPage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateKonsoleConfigPage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateKonsoleConfigPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateKonsoleConfigPage::staticMetaObject = {
    { &KTextEditor::ConfigPage::staticMetaObject, qt_meta_stringdata_KateKonsoleConfigPage.data,
      qt_meta_data_KateKonsoleConfigPage,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateKonsoleConfigPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateKonsoleConfigPage::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateKonsoleConfigPage.stringdata0))
        return static_cast<void*>(const_cast< KateKonsoleConfigPage*>(this));
    return KTextEditor::ConfigPage::qt_metacast(_clname);
}

int KateKonsoleConfigPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::ConfigPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
