/****************************************************************************
** Meta object code from reading C++ file 'tabswitcher.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/tabswitcher/tabswitcher.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabswitcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_TabSwitcherPlugin_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TabSwitcherPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TabSwitcherPlugin_t qt_meta_stringdata_TabSwitcherPlugin = {
    {
QT_MOC_LITERAL(0, 0, 17) // "TabSwitcherPlugin"

    },
    "TabSwitcherPlugin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TabSwitcherPlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void TabSwitcherPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject TabSwitcherPlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_TabSwitcherPlugin.data,
      qt_meta_data_TabSwitcherPlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *TabSwitcherPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabSwitcherPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_TabSwitcherPlugin.stringdata0))
        return static_cast<void*>(const_cast< TabSwitcherPlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int TabSwitcherPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_TabSwitcherPluginView_t {
    QByteArrayData data[15];
    char stringdata0[204];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TabSwitcherPluginView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TabSwitcherPluginView_t qt_meta_stringdata_TabSwitcherPluginView = {
    {
QT_MOC_LITERAL(0, 0, 21), // "TabSwitcherPluginView"
QT_MOC_LITERAL(1, 22, 16), // "registerDocument"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(4, 63, 8), // "document"
QT_MOC_LITERAL(5, 72, 18), // "unregisterDocument"
QT_MOC_LITERAL(6, 91, 18), // "updateDocumentName"
QT_MOC_LITERAL(7, 110, 9), // "raiseView"
QT_MOC_LITERAL(8, 120, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(9, 139, 4), // "view"
QT_MOC_LITERAL(10, 144, 11), // "walkForward"
QT_MOC_LITERAL(11, 156, 12), // "walkBackward"
QT_MOC_LITERAL(12, 169, 15), // "switchToClicked"
QT_MOC_LITERAL(13, 185, 5), // "index"
QT_MOC_LITERAL(14, 191, 12) // "activateView"

    },
    "TabSwitcherPluginView\0registerDocument\0"
    "\0KTextEditor::Document*\0document\0"
    "unregisterDocument\0updateDocumentName\0"
    "raiseView\0KTextEditor::View*\0view\0"
    "walkForward\0walkBackward\0switchToClicked\0"
    "index\0activateView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TabSwitcherPluginView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x0a /* Public */,
       5,    1,   57,    2, 0x0a /* Public */,
       6,    1,   60,    2, 0x0a /* Public */,
       7,    1,   63,    2, 0x0a /* Public */,
      10,    0,   66,    2, 0x0a /* Public */,
      11,    0,   67,    2, 0x0a /* Public */,
      12,    1,   68,    2, 0x0a /* Public */,
      14,    1,   71,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,   13,
    QMetaType::Void, QMetaType::QModelIndex,   13,

       0        // eod
};

void TabSwitcherPluginView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TabSwitcherPluginView *_t = static_cast<TabSwitcherPluginView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->registerDocument((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 1: _t->unregisterDocument((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->updateDocumentName((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->raiseView((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 4: _t->walkForward(); break;
        case 5: _t->walkBackward(); break;
        case 6: _t->switchToClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 7: _t->activateView((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject TabSwitcherPluginView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_TabSwitcherPluginView.data,
      qt_meta_data_TabSwitcherPluginView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *TabSwitcherPluginView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabSwitcherPluginView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_TabSwitcherPluginView.stringdata0))
        return static_cast<void*>(const_cast< TabSwitcherPluginView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< TabSwitcherPluginView*>(this));
    return QObject::qt_metacast(_clname);
}

int TabSwitcherPluginView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
