/****************************************************************************
** Meta object code from reading C++ file 'katetabbutton.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/katetabbutton.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katetabbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_TabCloseButton_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TabCloseButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TabCloseButton_t qt_meta_stringdata_TabCloseButton = {
    {
QT_MOC_LITERAL(0, 0, 14) // "TabCloseButton"

    },
    "TabCloseButton"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TabCloseButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void TabCloseButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject TabCloseButton::staticMetaObject = {
    { &QAbstractButton::staticMetaObject, qt_meta_stringdata_TabCloseButton.data,
      qt_meta_data_TabCloseButton,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *TabCloseButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabCloseButton::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_TabCloseButton.stringdata0))
        return static_cast<void*>(const_cast< TabCloseButton*>(this));
    return QAbstractButton::qt_metacast(_clname);
}

int TabCloseButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KateTabButton_t {
    QByteArrayData data[10];
    char stringdata0[120];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateTabButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateTabButton_t qt_meta_stringdata_KateTabButton = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KateTabButton"
QT_MOC_LITERAL(1, 14, 9), // "activated"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 14), // "KateTabButton*"
QT_MOC_LITERAL(4, 40, 9), // "tabbutton"
QT_MOC_LITERAL(5, 50, 12), // "closeRequest"
QT_MOC_LITERAL(6, 63, 19), // "setAnimatedGeometry"
QT_MOC_LITERAL(7, 83, 9), // "startGeom"
QT_MOC_LITERAL(8, 93, 7), // "endGeom"
QT_MOC_LITERAL(9, 101, 18) // "closeButtonClicked"

    },
    "KateTabButton\0activated\0\0KateTabButton*\0"
    "tabbutton\0closeRequest\0setAnimatedGeometry\0"
    "startGeom\0endGeom\0closeButtonClicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateTabButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       5,    1,   37,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    2,   40,    2, 0x0a /* Public */,
       9,    0,   45,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QRect, QMetaType::QRect,    7,    8,
    QMetaType::Void,

       0        // eod
};

void KateTabButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateTabButton *_t = static_cast<KateTabButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->activated((*reinterpret_cast< KateTabButton*(*)>(_a[1]))); break;
        case 1: _t->closeRequest((*reinterpret_cast< KateTabButton*(*)>(_a[1]))); break;
        case 2: _t->setAnimatedGeometry((*reinterpret_cast< const QRect(*)>(_a[1])),(*reinterpret_cast< const QRect(*)>(_a[2]))); break;
        case 3: _t->closeButtonClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateTabButton* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateTabButton* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateTabButton::*_t)(KateTabButton * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabButton::activated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateTabButton::*_t)(KateTabButton * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateTabButton::closeRequest)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KateTabButton::staticMetaObject = {
    { &QAbstractButton::staticMetaObject, qt_meta_stringdata_KateTabButton.data,
      qt_meta_data_KateTabButton,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateTabButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateTabButton::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateTabButton.stringdata0))
        return static_cast<void*>(const_cast< KateTabButton*>(this));
    return QAbstractButton::qt_metacast(_clname);
}

int KateTabButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KateTabButton::activated(KateTabButton * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateTabButton::closeRequest(KateTabButton * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_END_MOC_NAMESPACE
