/****************************************************************************
** Meta object code from reading C++ file 'kate_ctags_plugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/kate-ctags/kate_ctags_plugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kate_ctags_plugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateCTagsPlugin_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateCTagsPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateCTagsPlugin_t qt_meta_stringdata_KateCTagsPlugin = {
    {
QT_MOC_LITERAL(0, 0, 15) // "KateCTagsPlugin"

    },
    "KateCTagsPlugin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateCTagsPlugin[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateCTagsPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KateCTagsPlugin::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KateCTagsPlugin.data,
      qt_meta_data_KateCTagsPlugin,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateCTagsPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateCTagsPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateCTagsPlugin.stringdata0))
        return static_cast<void*>(const_cast< KateCTagsPlugin*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KateCTagsPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KateCTagsConfigPage_t {
    QByteArrayData data[9];
    char stringdata0[122];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateCTagsConfigPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateCTagsConfigPage_t qt_meta_stringdata_KateCTagsConfigPage = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateCTagsConfigPage"
QT_MOC_LITERAL(1, 20, 18), // "addGlobalTagTarget"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 18), // "delGlobalTagTarget"
QT_MOC_LITERAL(4, 59, 14), // "updateGlobalDB"
QT_MOC_LITERAL(5, 74, 10), // "updateDone"
QT_MOC_LITERAL(6, 85, 8), // "exitCode"
QT_MOC_LITERAL(7, 94, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(8, 115, 6) // "status"

    },
    "KateCTagsConfigPage\0addGlobalTagTarget\0"
    "\0delGlobalTagTarget\0updateGlobalDB\0"
    "updateDone\0exitCode\0QProcess::ExitStatus\0"
    "status"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateCTagsConfigPage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x08 /* Private */,
       3,    0,   35,    2, 0x08 /* Private */,
       4,    0,   36,    2, 0x08 /* Private */,
       5,    2,   37,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 7,    6,    8,

       0        // eod
};

void KateCTagsConfigPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateCTagsConfigPage *_t = static_cast<KateCTagsConfigPage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->addGlobalTagTarget(); break;
        case 1: _t->delGlobalTagTarget(); break;
        case 2: _t->updateGlobalDB(); break;
        case 3: _t->updateDone((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject KateCTagsConfigPage::staticMetaObject = {
    { &KTextEditor::ConfigPage::staticMetaObject, qt_meta_stringdata_KateCTagsConfigPage.data,
      qt_meta_data_KateCTagsConfigPage,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateCTagsConfigPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateCTagsConfigPage::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateCTagsConfigPage.stringdata0))
        return static_cast<void*>(const_cast< KateCTagsConfigPage*>(this));
    return KTextEditor::ConfigPage::qt_metacast(_clname);
}

int KateCTagsConfigPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::ConfigPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
