/****************************************************************************
** Meta object code from reading C++ file 'plugin_katexmlcheck.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/xmlcheck/plugin_katexmlcheck.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin_katexmlcheck.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_PluginKateXMLCheckView_t {
    QByteArrayData data[12];
    char stringdata0[145];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginKateXMLCheckView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginKateXMLCheckView_t qt_meta_stringdata_PluginKateXMLCheckView = {
    {
QT_MOC_LITERAL(0, 0, 22), // "PluginKateXMLCheckView"
QT_MOC_LITERAL(1, 23, 12), // "slotValidate"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 11), // "slotClicked"
QT_MOC_LITERAL(4, 49, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(5, 66, 4), // "item"
QT_MOC_LITERAL(6, 71, 6), // "column"
QT_MOC_LITERAL(7, 78, 14), // "slotProcExited"
QT_MOC_LITERAL(8, 93, 8), // "exitCode"
QT_MOC_LITERAL(9, 102, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(10, 123, 10), // "exitStatus"
QT_MOC_LITERAL(11, 134, 10) // "slotUpdate"

    },
    "PluginKateXMLCheckView\0slotValidate\0"
    "\0slotClicked\0QTreeWidgetItem*\0item\0"
    "column\0slotProcExited\0exitCode\0"
    "QProcess::ExitStatus\0exitStatus\0"
    "slotUpdate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginKateXMLCheckView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x0a /* Public */,
       3,    2,   35,    2, 0x0a /* Public */,
       7,    2,   40,    2, 0x0a /* Public */,
      11,    0,   45,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int,    5,    6,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 9,    8,   10,
    QMetaType::Void,

       0        // eod
};

void PluginKateXMLCheckView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PluginKateXMLCheckView *_t = static_cast<PluginKateXMLCheckView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->slotValidate();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 1: _t->slotClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->slotProcExited((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 3: _t->slotUpdate(); break;
        default: ;
        }
    }
}

const QMetaObject PluginKateXMLCheckView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PluginKateXMLCheckView.data,
      qt_meta_data_PluginKateXMLCheckView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PluginKateXMLCheckView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginKateXMLCheckView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PluginKateXMLCheckView.stringdata0))
        return static_cast<void*>(const_cast< PluginKateXMLCheckView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< PluginKateXMLCheckView*>(this));
    return QObject::qt_metacast(_clname);
}

int PluginKateXMLCheckView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_PluginKateXMLCheck_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginKateXMLCheck_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginKateXMLCheck_t qt_meta_stringdata_PluginKateXMLCheck = {
    {
QT_MOC_LITERAL(0, 0, 18) // "PluginKateXMLCheck"

    },
    "PluginKateXMLCheck"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginKateXMLCheck[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void PluginKateXMLCheck::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject PluginKateXMLCheck::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_PluginKateXMLCheck.data,
      qt_meta_data_PluginKateXMLCheck,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PluginKateXMLCheck::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginKateXMLCheck::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PluginKateXMLCheck.stringdata0))
        return static_cast<void*>(const_cast< PluginKateXMLCheck*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int PluginKateXMLCheck::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
