/****************************************************************************
** Meta object code from reading C++ file 'kateviewmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/kateviewmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateviewmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateViewManager_t {
    QByteArrayData data[58];
    char stringdata0[834];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateViewManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateViewManager_t qt_meta_stringdata_KateViewManager = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KateViewManager"
QT_MOC_LITERAL(1, 16, 11), // "viewChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(4, 48, 11), // "viewCreated"
QT_MOC_LITERAL(5, 60, 7), // "openUrl"
QT_MOC_LITERAL(6, 68, 3), // "url"
QT_MOC_LITERAL(7, 72, 12), // "activateView"
QT_MOC_LITERAL(8, 85, 4), // "view"
QT_MOC_LITERAL(9, 90, 13), // "activateSpace"
QT_MOC_LITERAL(10, 104, 1), // "v"
QT_MOC_LITERAL(11, 106, 15), // "slotDocumentNew"
QT_MOC_LITERAL(12, 122, 16), // "slotDocumentOpen"
QT_MOC_LITERAL(13, 139, 17), // "slotDocumentClose"
QT_MOC_LITERAL(14, 157, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(15, 180, 8), // "document"
QT_MOC_LITERAL(16, 189, 14), // "setActiveSpace"
QT_MOC_LITERAL(17, 204, 14), // "KateViewSpace*"
QT_MOC_LITERAL(18, 219, 2), // "vs"
QT_MOC_LITERAL(19, 222, 13), // "setActiveView"
QT_MOC_LITERAL(20, 236, 16), // "activateNextView"
QT_MOC_LITERAL(21, 253, 16), // "activatePrevView"
QT_MOC_LITERAL(22, 270, 15), // "slotViewChanged"
QT_MOC_LITERAL(23, 286, 15), // "documentCreated"
QT_MOC_LITERAL(24, 302, 3), // "doc"
QT_MOC_LITERAL(25, 306, 21), // "documentWillBeDeleted"
QT_MOC_LITERAL(26, 328, 23), // "documentSavedOrUploaded"
QT_MOC_LITERAL(27, 352, 6), // "saveAs"
QT_MOC_LITERAL(28, 359, 22), // "aboutToDeleteDocuments"
QT_MOC_LITERAL(29, 382, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(30, 412, 9), // "documents"
QT_MOC_LITERAL(31, 422, 16), // "documentsDeleted"
QT_MOC_LITERAL(32, 439, 14), // "splitViewSpace"
QT_MOC_LITERAL(33, 454, 15), // "Qt::Orientation"
QT_MOC_LITERAL(34, 470, 1), // "o"
QT_MOC_LITERAL(35, 472, 14), // "closeViewSpace"
QT_MOC_LITERAL(36, 487, 20), // "viewsInSameViewSpace"
QT_MOC_LITERAL(37, 508, 5), // "view1"
QT_MOC_LITERAL(38, 514, 5), // "view2"
QT_MOC_LITERAL(39, 520, 23), // "slotSplitViewSpaceHoriz"
QT_MOC_LITERAL(40, 544, 22), // "slotSplitViewSpaceVert"
QT_MOC_LITERAL(41, 567, 12), // "moveSplitter"
QT_MOC_LITERAL(42, 580, 7), // "Qt::Key"
QT_MOC_LITERAL(43, 588, 3), // "key"
QT_MOC_LITERAL(44, 592, 7), // "repeats"
QT_MOC_LITERAL(45, 600, 17), // "moveSplitterRight"
QT_MOC_LITERAL(46, 618, 16), // "moveSplitterLeft"
QT_MOC_LITERAL(47, 635, 14), // "moveSplitterUp"
QT_MOC_LITERAL(48, 650, 16), // "moveSplitterDown"
QT_MOC_LITERAL(49, 667, 25), // "slotCloseCurrentViewSpace"
QT_MOC_LITERAL(50, 693, 19), // "slotCloseOtherViews"
QT_MOC_LITERAL(51, 713, 18), // "slotHideOtherViews"
QT_MOC_LITERAL(52, 732, 10), // "hideOthers"
QT_MOC_LITERAL(53, 743, 20), // "reactivateActiveView"
QT_MOC_LITERAL(54, 764, 25), // "toggleSplitterOrientation"
QT_MOC_LITERAL(55, 790, 5), // "views"
QT_MOC_LITERAL(56, 796, 25), // "QList<KTextEditor::View*>"
QT_MOC_LITERAL(57, 822, 11) // "sortedViews"

    },
    "KateViewManager\0viewChanged\0\0"
    "KTextEditor::View*\0viewCreated\0openUrl\0"
    "url\0activateView\0view\0activateSpace\0"
    "v\0slotDocumentNew\0slotDocumentOpen\0"
    "slotDocumentClose\0KTextEditor::Document*\0"
    "document\0setActiveSpace\0KateViewSpace*\0"
    "vs\0setActiveView\0activateNextView\0"
    "activatePrevView\0slotViewChanged\0"
    "documentCreated\0doc\0documentWillBeDeleted\0"
    "documentSavedOrUploaded\0saveAs\0"
    "aboutToDeleteDocuments\0"
    "QList<KTextEditor::Document*>\0documents\0"
    "documentsDeleted\0splitViewSpace\0"
    "Qt::Orientation\0o\0closeViewSpace\0"
    "viewsInSameViewSpace\0view1\0view2\0"
    "slotSplitViewSpaceHoriz\0slotSplitViewSpaceVert\0"
    "moveSplitter\0Qt::Key\0key\0repeats\0"
    "moveSplitterRight\0moveSplitterLeft\0"
    "moveSplitterUp\0moveSplitterDown\0"
    "slotCloseCurrentViewSpace\0slotCloseOtherViews\0"
    "slotHideOtherViews\0hideOthers\0"
    "reactivateActiveView\0toggleSplitterOrientation\0"
    "views\0QList<KTextEditor::View*>\0"
    "sortedViews"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateViewManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      41,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  219,    2, 0x06 /* Public */,
       4,    1,  222,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,  225,    2, 0x0a /* Public */,
       7,    1,  228,    2, 0x08 /* Private */,
       9,    1,  231,    2, 0x08 /* Private */,
      11,    0,  234,    2, 0x0a /* Public */,
      12,    0,  235,    2, 0x0a /* Public */,
      13,    0,  236,    2, 0x0a /* Public */,
      13,    1,  237,    2, 0x0a /* Public */,
      16,    1,  240,    2, 0x0a /* Public */,
      19,    1,  243,    2, 0x0a /* Public */,
      20,    0,  246,    2, 0x0a /* Public */,
      21,    0,  247,    2, 0x0a /* Public */,
      22,    0,  248,    2, 0x08 /* Private */,
      23,    1,  249,    2, 0x08 /* Private */,
      25,    1,  252,    2, 0x08 /* Private */,
      26,    2,  255,    2, 0x08 /* Private */,
      28,    1,  260,    2, 0x08 /* Private */,
      31,    1,  263,    2, 0x08 /* Private */,
      32,    2,  266,    2, 0x0a /* Public */,
      32,    1,  271,    2, 0x2a /* Public | MethodCloned */,
      32,    0,  274,    2, 0x2a /* Public | MethodCloned */,
      35,    1,  275,    2, 0x0a /* Public */,
      35,    0,  278,    2, 0x2a /* Public | MethodCloned */,
      36,    2,  279,    2, 0x0a /* Public */,
       7,    1,  284,    2, 0x0a /* Public */,
      39,    0,  287,    2, 0x0a /* Public */,
      40,    0,  288,    2, 0x0a /* Public */,
      41,    2,  289,    2, 0x0a /* Public */,
      41,    1,  294,    2, 0x2a /* Public | MethodCloned */,
      45,    0,  297,    2, 0x0a /* Public */,
      46,    0,  298,    2, 0x0a /* Public */,
      47,    0,  299,    2, 0x0a /* Public */,
      48,    0,  300,    2, 0x0a /* Public */,
      49,    0,  301,    2, 0x0a /* Public */,
      50,    0,  302,    2, 0x0a /* Public */,
      51,    1,  303,    2, 0x0a /* Public */,
      53,    0,  306,    2, 0x0a /* Public */,
      54,    0,  307,    2, 0x0a /* Public */,
      55,    0,  308,    2, 0x0a /* Public */,
      57,    0,  309,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,    6,
    QMetaType::Void, 0x80000000 | 3,    8,
    QMetaType::Void, 0x80000000 | 3,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 3,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   24,
    QMetaType::Void, 0x80000000 | 14,   24,
    QMetaType::Void, 0x80000000 | 14, QMetaType::Bool,   15,   27,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, 0x80000000 | 17, 0x80000000 | 33,   18,   34,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    8,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 3, 0x80000000 | 3,   37,   38,
    0x80000000 | 3, 0x80000000 | 14,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 42, QMetaType::Int,   43,   44,
    QMetaType::Void, 0x80000000 | 42,   43,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 56,
    0x80000000 | 56,

       0        // eod
};

void KateViewManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateViewManager *_t = static_cast<KateViewManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->viewChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 1: _t->viewCreated((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 2: _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 3: _t->activateView((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 4: _t->activateSpace((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 5: _t->slotDocumentNew(); break;
        case 6: _t->slotDocumentOpen(); break;
        case 7: _t->slotDocumentClose(); break;
        case 8: _t->slotDocumentClose((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 9: _t->setActiveSpace((*reinterpret_cast< KateViewSpace*(*)>(_a[1]))); break;
        case 10: _t->setActiveView((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 11: _t->activateNextView(); break;
        case 12: _t->activatePrevView(); break;
        case 13: _t->slotViewChanged(); break;
        case 14: _t->documentCreated((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 15: _t->documentWillBeDeleted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 16: _t->documentSavedOrUploaded((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 17: _t->aboutToDeleteDocuments((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 18: _t->documentsDeleted((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 19: _t->splitViewSpace((*reinterpret_cast< KateViewSpace*(*)>(_a[1])),(*reinterpret_cast< Qt::Orientation(*)>(_a[2]))); break;
        case 20: _t->splitViewSpace((*reinterpret_cast< KateViewSpace*(*)>(_a[1]))); break;
        case 21: _t->splitViewSpace(); break;
        case 22: _t->closeViewSpace((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 23: _t->closeViewSpace(); break;
        case 24: { bool _r = _t->viewsInSameViewSpace((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::View*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 25: { KTextEditor::View* _r = _t->activateView((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KTextEditor::View**>(_a[0]) = _r; }  break;
        case 26: _t->slotSplitViewSpaceHoriz(); break;
        case 27: _t->slotSplitViewSpaceVert(); break;
        case 28: _t->moveSplitter((*reinterpret_cast< Qt::Key(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 29: _t->moveSplitter((*reinterpret_cast< Qt::Key(*)>(_a[1]))); break;
        case 30: _t->moveSplitterRight(); break;
        case 31: _t->moveSplitterLeft(); break;
        case 32: _t->moveSplitterUp(); break;
        case 33: _t->moveSplitterDown(); break;
        case 34: _t->slotCloseCurrentViewSpace(); break;
        case 35: _t->slotCloseOtherViews(); break;
        case 36: _t->slotHideOtherViews((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->reactivateActiveView(); break;
        case 38: _t->toggleSplitterOrientation(); break;
        case 39: { QList<KTextEditor::View*> _r = _t->views();
            if (_a[0]) *reinterpret_cast< QList<KTextEditor::View*>*>(_a[0]) = _r; }  break;
        case 40: { QList<KTextEditor::View*> _r = _t->sortedViews();
            if (_a[0]) *reinterpret_cast< QList<KTextEditor::View*>*>(_a[0]) = _r; }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KTextEditor::Document*> >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateViewManager::*_t)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateViewManager::viewChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateViewManager::*_t)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateViewManager::viewCreated)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KateViewManager::staticMetaObject = {
    { &QSplitter::staticMetaObject, qt_meta_stringdata_KateViewManager.data,
      qt_meta_data_KateViewManager,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateViewManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewManager::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateViewManager.stringdata0))
        return static_cast<void*>(const_cast< KateViewManager*>(this));
    return QSplitter::qt_metacast(_clname);
}

int KateViewManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    return _id;
}

// SIGNAL 0
void KateViewManager::viewChanged(KTextEditor::View * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateViewManager::viewCreated(KTextEditor::View * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_END_MOC_NAMESPACE
