/****************************************************************************
** Meta object code from reading C++ file 'plugin_search.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/search/plugin_search.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plugin_search.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Results_t {
    QByteArrayData data[1];
    char stringdata0[8];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Results_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Results_t qt_meta_stringdata_Results = {
    {
QT_MOC_LITERAL(0, 0, 7) // "Results"

    },
    "Results"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Results[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Results::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject Results::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Results.data,
      qt_meta_data_Results,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Results::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Results::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Results.stringdata0))
        return static_cast<void*>(const_cast< Results*>(this));
    if (!strcmp(_clname, "Ui::Results"))
        return static_cast< Ui::Results*>(const_cast< Results*>(this));
    return QWidget::qt_metacast(_clname);
}

int Results::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_ContainerWidget_t {
    QByteArrayData data[8];
    char stringdata0[67];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ContainerWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ContainerWidget_t qt_meta_stringdata_ContainerWidget = {
    {
QT_MOC_LITERAL(0, 0, 15), // "ContainerWidget"
QT_MOC_LITERAL(1, 16, 9), // "nextFocus"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 8), // "QWidget*"
QT_MOC_LITERAL(4, 36, 13), // "currentWidget"
QT_MOC_LITERAL(5, 50, 5), // "bool*"
QT_MOC_LITERAL(6, 56, 5), // "found"
QT_MOC_LITERAL(7, 62, 4) // "next"

    },
    "ContainerWidget\0nextFocus\0\0QWidget*\0"
    "currentWidget\0bool*\0found\0next"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ContainerWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, QMetaType::Bool,    4,    6,    7,

       0        // eod
};

void ContainerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ContainerWidget *_t = static_cast<ContainerWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->nextFocus((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ContainerWidget::*_t)(QWidget * , bool * , bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ContainerWidget::nextFocus)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject ContainerWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ContainerWidget.data,
      qt_meta_data_ContainerWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ContainerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ContainerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ContainerWidget.stringdata0))
        return static_cast<void*>(const_cast< ContainerWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int ContainerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ContainerWidget::nextFocus(QWidget * _t1, bool * _t2, bool _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KatePluginSearch_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginSearch_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginSearch_t qt_meta_stringdata_KatePluginSearch = {
    {
QT_MOC_LITERAL(0, 0, 16) // "KatePluginSearch"

    },
    "KatePluginSearch"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginSearch[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KatePluginSearch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KatePluginSearch::staticMetaObject = {
    { &KTextEditor::Plugin::staticMetaObject, qt_meta_stringdata_KatePluginSearch.data,
      qt_meta_data_KatePluginSearch,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginSearch::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginSearch::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginSearch.stringdata0))
        return static_cast<void*>(const_cast< KatePluginSearch*>(this));
    return KTextEditor::Plugin::qt_metacast(_clname);
}

int KatePluginSearch::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_KatePluginSearchView_t {
    QByteArrayData data[63];
    char stringdata0[763];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KatePluginSearchView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KatePluginSearchView_t qt_meta_stringdata_KatePluginSearchView = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KatePluginSearchView"
QT_MOC_LITERAL(1, 21, 11), // "startSearch"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 15), // "setSearchString"
QT_MOC_LITERAL(4, 50, 7), // "pattern"
QT_MOC_LITERAL(5, 58, 16), // "navigateFolderUp"
QT_MOC_LITERAL(6, 75, 16), // "setCurrentFolder"
QT_MOC_LITERAL(7, 92, 14), // "setSearchPlace"
QT_MOC_LITERAL(8, 107, 5), // "place"
QT_MOC_LITERAL(9, 113, 13), // "goToNextMatch"
QT_MOC_LITERAL(10, 127, 17), // "goToPreviousMatch"
QT_MOC_LITERAL(11, 145, 14), // "openSearchView"
QT_MOC_LITERAL(12, 160, 9), // "handleEsc"
QT_MOC_LITERAL(13, 170, 7), // "QEvent*"
QT_MOC_LITERAL(14, 178, 1), // "e"
QT_MOC_LITERAL(15, 180, 9), // "nextFocus"
QT_MOC_LITERAL(16, 190, 8), // "QWidget*"
QT_MOC_LITERAL(17, 199, 13), // "currentWidget"
QT_MOC_LITERAL(18, 213, 5), // "bool*"
QT_MOC_LITERAL(19, 219, 5), // "found"
QT_MOC_LITERAL(20, 225, 4), // "next"
QT_MOC_LITERAL(21, 230, 6), // "addTab"
QT_MOC_LITERAL(22, 237, 17), // "tabCloseRequested"
QT_MOC_LITERAL(23, 255, 5), // "index"
QT_MOC_LITERAL(24, 261, 13), // "toggleOptions"
QT_MOC_LITERAL(25, 275, 4), // "show"
QT_MOC_LITERAL(26, 280, 17), // "searchContextMenu"
QT_MOC_LITERAL(27, 298, 3), // "pos"
QT_MOC_LITERAL(28, 302, 18), // "searchPlaceChanged"
QT_MOC_LITERAL(29, 321, 22), // "startSearchWhileTyping"
QT_MOC_LITERAL(30, 344, 21), // "folderFileListChanged"
QT_MOC_LITERAL(31, 366, 10), // "matchFound"
QT_MOC_LITERAL(32, 377, 3), // "url"
QT_MOC_LITERAL(33, 381, 8), // "fileName"
QT_MOC_LITERAL(34, 390, 4), // "line"
QT_MOC_LITERAL(35, 395, 6), // "column"
QT_MOC_LITERAL(36, 402, 11), // "lineContent"
QT_MOC_LITERAL(37, 414, 8), // "matchLen"
QT_MOC_LITERAL(38, 423, 12), // "addMatchMark"
QT_MOC_LITERAL(39, 436, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(40, 459, 3), // "doc"
QT_MOC_LITERAL(41, 463, 3), // "len"
QT_MOC_LITERAL(42, 467, 10), // "searchDone"
QT_MOC_LITERAL(43, 478, 21), // "searchWhileTypingDone"
QT_MOC_LITERAL(44, 500, 13), // "indicateMatch"
QT_MOC_LITERAL(45, 514, 8), // "hasMatch"
QT_MOC_LITERAL(46, 523, 9), // "searching"
QT_MOC_LITERAL(47, 533, 4), // "file"
QT_MOC_LITERAL(48, 538, 12), // "itemSelected"
QT_MOC_LITERAL(49, 551, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(50, 568, 4), // "item"
QT_MOC_LITERAL(51, 573, 10), // "clearMarks"
QT_MOC_LITERAL(52, 584, 13), // "clearDocMarks"
QT_MOC_LITERAL(53, 598, 18), // "replaceSingleMatch"
QT_MOC_LITERAL(54, 617, 14), // "replaceChecked"
QT_MOC_LITERAL(55, 632, 11), // "replaceDone"
QT_MOC_LITERAL(56, 644, 14), // "docViewChanged"
QT_MOC_LITERAL(57, 659, 16), // "resultTabChanged"
QT_MOC_LITERAL(58, 676, 21), // "slotPluginViewCreated"
QT_MOC_LITERAL(59, 698, 4), // "name"
QT_MOC_LITERAL(60, 703, 10), // "pluginView"
QT_MOC_LITERAL(61, 714, 21), // "slotPluginViewDeleted"
QT_MOC_LITERAL(62, 736, 26) // "slotProjectFileNameChanged"

    },
    "KatePluginSearchView\0startSearch\0\0"
    "setSearchString\0pattern\0navigateFolderUp\0"
    "setCurrentFolder\0setSearchPlace\0place\0"
    "goToNextMatch\0goToPreviousMatch\0"
    "openSearchView\0handleEsc\0QEvent*\0e\0"
    "nextFocus\0QWidget*\0currentWidget\0bool*\0"
    "found\0next\0addTab\0tabCloseRequested\0"
    "index\0toggleOptions\0show\0searchContextMenu\0"
    "pos\0searchPlaceChanged\0startSearchWhileTyping\0"
    "folderFileListChanged\0matchFound\0url\0"
    "fileName\0line\0column\0lineContent\0"
    "matchLen\0addMatchMark\0KTextEditor::Document*\0"
    "doc\0len\0searchDone\0searchWhileTypingDone\0"
    "indicateMatch\0hasMatch\0searching\0file\0"
    "itemSelected\0QTreeWidgetItem*\0item\0"
    "clearMarks\0clearDocMarks\0replaceSingleMatch\0"
    "replaceChecked\0replaceDone\0docViewChanged\0"
    "resultTabChanged\0slotPluginViewCreated\0"
    "name\0pluginView\0slotPluginViewDeleted\0"
    "slotProjectFileNameChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KatePluginSearchView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      34,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  184,    2, 0x0a /* Public */,
       3,    1,  185,    2, 0x0a /* Public */,
       5,    0,  188,    2, 0x0a /* Public */,
       6,    0,  189,    2, 0x0a /* Public */,
       7,    1,  190,    2, 0x0a /* Public */,
       9,    0,  193,    2, 0x0a /* Public */,
      10,    0,  194,    2, 0x0a /* Public */,
      11,    0,  195,    2, 0x08 /* Private */,
      12,    1,  196,    2, 0x08 /* Private */,
      15,    3,  199,    2, 0x08 /* Private */,
      21,    0,  206,    2, 0x08 /* Private */,
      22,    1,  207,    2, 0x08 /* Private */,
      24,    1,  210,    2, 0x08 /* Private */,
      26,    1,  213,    2, 0x08 /* Private */,
      28,    0,  216,    2, 0x08 /* Private */,
      29,    0,  217,    2, 0x08 /* Private */,
      30,    0,  218,    2, 0x08 /* Private */,
      31,    6,  219,    2, 0x08 /* Private */,
      38,    4,  232,    2, 0x08 /* Private */,
      42,    0,  241,    2, 0x08 /* Private */,
      43,    0,  242,    2, 0x08 /* Private */,
      44,    1,  243,    2, 0x08 /* Private */,
      46,    1,  246,    2, 0x08 /* Private */,
      48,    1,  249,    2, 0x08 /* Private */,
      51,    0,  252,    2, 0x08 /* Private */,
      52,    1,  253,    2, 0x08 /* Private */,
      53,    0,  256,    2, 0x08 /* Private */,
      54,    0,  257,    2, 0x08 /* Private */,
      55,    0,  258,    2, 0x08 /* Private */,
      56,    0,  259,    2, 0x08 /* Private */,
      57,    1,  260,    2, 0x08 /* Private */,
      58,    2,  263,    2, 0x08 /* Private */,
      61,    2,  268,    2, 0x08 /* Private */,
      62,    0,  273,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 16, 0x80000000 | 18, QMetaType::Bool,   17,   19,   20,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, QMetaType::QPoint,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Int,   32,   33,   34,   35,   36,   37,
    QMetaType::Void, 0x80000000 | 39, QMetaType::Int, QMetaType::Int, QMetaType::Int,   40,   34,   35,   41,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   45,
    QMetaType::Void, QMetaType::QString,   47,
    QMetaType::Void, 0x80000000 | 49,   50,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, QMetaType::QString, QMetaType::QObjectStar,   59,   60,
    QMetaType::Void, QMetaType::QString, QMetaType::QObjectStar,   59,   60,
    QMetaType::Void,

       0        // eod
};

void KatePluginSearchView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KatePluginSearchView *_t = static_cast<KatePluginSearchView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->startSearch(); break;
        case 1: _t->setSearchString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->navigateFolderUp(); break;
        case 3: _t->setCurrentFolder(); break;
        case 4: _t->setSearchPlace((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->goToNextMatch(); break;
        case 6: _t->goToPreviousMatch(); break;
        case 7: _t->openSearchView(); break;
        case 8: _t->handleEsc((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 9: _t->nextFocus((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 10: _t->addTab(); break;
        case 11: _t->tabCloseRequested((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->toggleOptions((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->searchContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 14: _t->searchPlaceChanged(); break;
        case 15: _t->startSearchWhileTyping(); break;
        case 16: _t->folderFileListChanged(); break;
        case 17: _t->matchFound((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 18: _t->addMatchMark((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 19: _t->searchDone(); break;
        case 20: _t->searchWhileTypingDone(); break;
        case 21: _t->indicateMatch((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->searching((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: _t->itemSelected((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 24: _t->clearMarks(); break;
        case 25: _t->clearDocMarks((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 26: _t->replaceSingleMatch(); break;
        case 27: _t->replaceChecked(); break;
        case 28: _t->replaceDone(); break;
        case 29: _t->docViewChanged(); break;
        case 30: _t->resultTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->slotPluginViewCreated((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2]))); break;
        case 32: _t->slotPluginViewDeleted((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2]))); break;
        case 33: _t->slotProjectFileNameChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KatePluginSearchView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KatePluginSearchView.data,
      qt_meta_data_KatePluginSearchView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KatePluginSearchView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KatePluginSearchView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KatePluginSearchView.stringdata0))
        return static_cast<void*>(const_cast< KatePluginSearchView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KatePluginSearchView*>(this));
    if (!strcmp(_clname, "KTextEditor::SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KatePluginSearchView*>(this));
    if (!strcmp(_clname, "org.kde.KTextEditor.SessionConfigInterface"))
        return static_cast< KTextEditor::SessionConfigInterface*>(const_cast< KatePluginSearchView*>(this));
    return QObject::qt_metacast(_clname);
}

int KatePluginSearchView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    return _id;
}
struct qt_meta_stringdata_KateSearchCommand_t {
    QByteArrayData data[9];
    char stringdata0[100];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateSearchCommand_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateSearchCommand_t qt_meta_stringdata_KateSearchCommand = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KateSearchCommand"
QT_MOC_LITERAL(1, 18, 14), // "setSearchPlace"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 5), // "place"
QT_MOC_LITERAL(4, 40, 16), // "setCurrentFolder"
QT_MOC_LITERAL(5, 57, 15), // "setSearchString"
QT_MOC_LITERAL(6, 73, 7), // "pattern"
QT_MOC_LITERAL(7, 81, 11), // "startSearch"
QT_MOC_LITERAL(8, 93, 6) // "newTab"

    },
    "KateSearchCommand\0setSearchPlace\0\0"
    "place\0setCurrentFolder\0setSearchString\0"
    "pattern\0startSearch\0newTab"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateSearchCommand[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       4,    0,   42,    2, 0x06 /* Public */,
       5,    1,   43,    2, 0x06 /* Public */,
       7,    0,   46,    2, 0x06 /* Public */,
       8,    0,   47,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateSearchCommand::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateSearchCommand *_t = static_cast<KateSearchCommand *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setSearchPlace((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->setCurrentFolder(); break;
        case 2: _t->setSearchString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->startSearch(); break;
        case 4: _t->newTab(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateSearchCommand::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateSearchCommand::setSearchPlace)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateSearchCommand::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateSearchCommand::setCurrentFolder)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KateSearchCommand::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateSearchCommand::setSearchString)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KateSearchCommand::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateSearchCommand::startSearch)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KateSearchCommand::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateSearchCommand::newTab)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject KateSearchCommand::staticMetaObject = {
    { &KTextEditor::Command::staticMetaObject, qt_meta_stringdata_KateSearchCommand.data,
      qt_meta_data_KateSearchCommand,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateSearchCommand::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateSearchCommand::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateSearchCommand.stringdata0))
        return static_cast<void*>(const_cast< KateSearchCommand*>(this));
    return KTextEditor::Command::qt_metacast(_clname);
}

int KateSearchCommand::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Command::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KateSearchCommand::setSearchPlace(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateSearchCommand::setCurrentFolder()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void KateSearchCommand::setSearchString(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KateSearchCommand::startSearch()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void KateSearchCommand::newTab()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
