/****************************************************************************
** Meta object code from reading C++ file 'kateproject.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/project/kateproject.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateproject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateProject_t {
    QByteArrayData data[23];
    char stringdata0[383];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateProject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateProject_t qt_meta_stringdata_KateProject = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KateProject"
QT_MOC_LITERAL(1, 12, 17), // "projectMapChanged"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 12), // "modelChanged"
QT_MOC_LITERAL(4, 44, 12), // "indexChanged"
QT_MOC_LITERAL(5, 57, 4), // "load"
QT_MOC_LITERAL(6, 62, 13), // "globalProject"
QT_MOC_LITERAL(7, 76, 5), // "force"
QT_MOC_LITERAL(8, 82, 15), // "loadProjectDone"
QT_MOC_LITERAL(9, 98, 30), // "KateProjectSharedQStandardItem"
QT_MOC_LITERAL(10, 129, 8), // "topLevel"
QT_MOC_LITERAL(11, 138, 31), // "KateProjectSharedQMapStringItem"
QT_MOC_LITERAL(12, 170, 9), // "file2Item"
QT_MOC_LITERAL(13, 180, 13), // "loadIndexDone"
QT_MOC_LITERAL(14, 194, 29), // "KateProjectSharedProjectIndex"
QT_MOC_LITERAL(15, 224, 12), // "projectIndex"
QT_MOC_LITERAL(16, 237, 19), // "slotModifiedChanged"
QT_MOC_LITERAL(17, 257, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(18, 280, 18), // "slotModifiedOnDisk"
QT_MOC_LITERAL(19, 299, 8), // "document"
QT_MOC_LITERAL(20, 308, 10), // "isModified"
QT_MOC_LITERAL(21, 319, 56), // "KTextEditor::ModificationInte..."
QT_MOC_LITERAL(22, 376, 6) // "reason"

    },
    "KateProject\0projectMapChanged\0\0"
    "modelChanged\0indexChanged\0load\0"
    "globalProject\0force\0loadProjectDone\0"
    "KateProjectSharedQStandardItem\0topLevel\0"
    "KateProjectSharedQMapStringItem\0"
    "file2Item\0loadIndexDone\0"
    "KateProjectSharedProjectIndex\0"
    "projectIndex\0slotModifiedChanged\0"
    "KTextEditor::Document*\0slotModifiedOnDisk\0"
    "document\0isModified\0"
    "KTextEditor::ModificationInterface::ModifiedOnDiskReason\0"
    "reason"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateProject[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    2,   62,    2, 0x08 /* Private */,
       5,    1,   67,    2, 0x28 /* Private | MethodCloned */,
       8,    2,   70,    2, 0x08 /* Private */,
      13,    1,   75,    2, 0x08 /* Private */,
      16,    1,   78,    2, 0x08 /* Private */,
      18,    3,   81,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Bool, QMetaType::QVariantMap, QMetaType::Bool,    6,    7,
    QMetaType::Bool, QMetaType::QVariantMap,    6,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 11,   10,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Bool, 0x80000000 | 21,   19,   20,   22,

       0        // eod
};

void KateProject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateProject *_t = static_cast<KateProject *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->projectMapChanged(); break;
        case 1: _t->modelChanged(); break;
        case 2: _t->indexChanged(); break;
        case 3: { bool _r = _t->load((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 4: { bool _r = _t->load((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 5: _t->loadProjectDone((*reinterpret_cast< KateProjectSharedQStandardItem(*)>(_a[1])),(*reinterpret_cast< KateProjectSharedQMapStringItem(*)>(_a[2]))); break;
        case 6: _t->loadIndexDone((*reinterpret_cast< KateProjectSharedProjectIndex(*)>(_a[1]))); break;
        case 7: _t->slotModifiedChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 8: _t->slotModifiedOnDisk((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< KTextEditor::ModificationInterface::ModifiedOnDiskReason(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProjectSharedQMapStringItem >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProjectSharedQStandardItem >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProjectSharedProjectIndex >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateProject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProject::projectMapChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateProject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProject::modelChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KateProject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProject::indexChanged)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KateProject::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateProject.data,
      qt_meta_data_KateProject,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateProject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateProject::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateProject.stringdata0))
        return static_cast<void*>(const_cast< KateProject*>(this));
    return QObject::qt_metacast(_clname);
}

int KateProject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KateProject::projectMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void KateProject::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void KateProject::indexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
