/****************************************************************************
** Meta object code from reading C++ file 'schemawidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/katesql/schemawidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'schemawidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_SchemaWidget_t {
    QByteArrayData data[17];
    char stringdata0[226];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SchemaWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SchemaWidget_t qt_meta_stringdata_SchemaWidget = {
    {
QT_MOC_LITERAL(0, 0, 12), // "SchemaWidget"
QT_MOC_LITERAL(1, 13, 9), // "buildTree"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 10), // "connection"
QT_MOC_LITERAL(4, 35, 7), // "refresh"
QT_MOC_LITERAL(5, 43, 14), // "generateSelect"
QT_MOC_LITERAL(6, 58, 14), // "generateUpdate"
QT_MOC_LITERAL(7, 73, 14), // "generateInsert"
QT_MOC_LITERAL(8, 88, 14), // "generateDelete"
QT_MOC_LITERAL(9, 103, 17), // "generateStatement"
QT_MOC_LITERAL(10, 121, 25), // "QSqlDriver::StatementType"
QT_MOC_LITERAL(11, 147, 4), // "type"
QT_MOC_LITERAL(12, 152, 30), // "slotCustomContextMenuRequested"
QT_MOC_LITERAL(13, 183, 3), // "pos"
QT_MOC_LITERAL(14, 187, 16), // "slotItemExpanded"
QT_MOC_LITERAL(15, 204, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(16, 221, 4) // "item"

    },
    "SchemaWidget\0buildTree\0\0connection\0"
    "refresh\0generateSelect\0generateUpdate\0"
    "generateInsert\0generateDelete\0"
    "generateStatement\0QSqlDriver::StatementType\0"
    "type\0slotCustomContextMenuRequested\0"
    "pos\0slotItemExpanded\0QTreeWidgetItem*\0"
    "item"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SchemaWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x0a /* Public */,
       4,    0,   62,    2, 0x0a /* Public */,
       5,    0,   63,    2, 0x0a /* Public */,
       6,    0,   64,    2, 0x0a /* Public */,
       7,    0,   65,    2, 0x0a /* Public */,
       8,    0,   66,    2, 0x0a /* Public */,
       9,    1,   67,    2, 0x0a /* Public */,
      12,    1,   70,    2, 0x08 /* Private */,
      14,    1,   73,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QPoint,   13,
    QMetaType::Void, 0x80000000 | 15,   16,

       0        // eod
};

void SchemaWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SchemaWidget *_t = static_cast<SchemaWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->buildTree((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->refresh(); break;
        case 2: _t->generateSelect(); break;
        case 3: _t->generateUpdate(); break;
        case 4: _t->generateInsert(); break;
        case 5: _t->generateDelete(); break;
        case 6: _t->generateStatement((*reinterpret_cast< QSqlDriver::StatementType(*)>(_a[1]))); break;
        case 7: _t->slotCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 8: _t->slotItemExpanded((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject SchemaWidget::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_SchemaWidget.data,
      qt_meta_data_SchemaWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *SchemaWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SchemaWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_SchemaWidget.stringdata0))
        return static_cast<void*>(const_cast< SchemaWidget*>(this));
    return QTreeWidget::qt_metacast(_clname);
}

int SchemaWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
