/****************************************************************************
** Meta object code from reading C++ file 'katefiletreemodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/filetree/katefiletreemodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katefiletreemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateFileTreeModel_t {
    QByteArrayData data[13];
    char stringdata0[307];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateFileTreeModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateFileTreeModel_t qt_meta_stringdata_KateFileTreeModel = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KateFileTreeModel"
QT_MOC_LITERAL(1, 18, 32), // "triggerViewChangeAfterNameChange"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 14), // "documentOpened"
QT_MOC_LITERAL(4, 67, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(5, 90, 14), // "documentClosed"
QT_MOC_LITERAL(6, 105, 19), // "documentNameChanged"
QT_MOC_LITERAL(7, 125, 23), // "documentModifiedChanged"
QT_MOC_LITERAL(8, 149, 22), // "documentModifiedOnDisc"
QT_MOC_LITERAL(9, 172, 56), // "KTextEditor::ModificationInte..."
QT_MOC_LITERAL(10, 229, 26), // "slotAboutToDeleteDocuments"
QT_MOC_LITERAL(11, 256, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(12, 286, 20) // "slotDocumentsDeleted"

    },
    "KateFileTreeModel\0triggerViewChangeAfterNameChange\0"
    "\0documentOpened\0KTextEditor::Document*\0"
    "documentClosed\0documentNameChanged\0"
    "documentModifiedChanged\0documentModifiedOnDisc\0"
    "KTextEditor::ModificationInterface::ModifiedOnDiskReason\0"
    "slotAboutToDeleteDocuments\0"
    "QList<KTextEditor::Document*>\0"
    "slotDocumentsDeleted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateFileTreeModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   55,    2, 0x0a /* Public */,
       5,    1,   58,    2, 0x0a /* Public */,
       6,    1,   61,    2, 0x0a /* Public */,
       7,    1,   64,    2, 0x0a /* Public */,
       8,    3,   67,    2, 0x0a /* Public */,
      10,    1,   74,    2, 0x0a /* Public */,
      12,    1,   77,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Bool, 0x80000000 | 9,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void, 0x80000000 | 11,    2,

       0        // eod
};

void KateFileTreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateFileTreeModel *_t = static_cast<KateFileTreeModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->triggerViewChangeAfterNameChange(); break;
        case 1: _t->documentOpened((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->documentClosed((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->documentNameChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 4: _t->documentModifiedChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 5: _t->documentModifiedOnDisc((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< KTextEditor::ModificationInterface::ModifiedOnDiskReason(*)>(_a[3]))); break;
        case 6: _t->slotAboutToDeleteDocuments((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 7: _t->slotDocumentsDeleted((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateFileTreeModel::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateFileTreeModel::triggerViewChangeAfterNameChange)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KateFileTreeModel::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_KateFileTreeModel.data,
      qt_meta_data_KateFileTreeModel,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateFileTreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateFileTreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateFileTreeModel.stringdata0))
        return static_cast<void*>(const_cast< KateFileTreeModel*>(this));
    return QAbstractItemModel::qt_metacast(_clname);
}

int KateFileTreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KateFileTreeModel::triggerViewChangeAfterNameChange()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
