/****************************************************************************
** Meta object code from reading C++ file 'snippetview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/snippets/snippetview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'snippetview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_SnippetView_t {
    QByteArrayData data[17];
    char stringdata0[206];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SnippetView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SnippetView_t qt_meta_stringdata_SnippetView = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SnippetView"
QT_MOC_LITERAL(1, 12, 11), // "slotAddRepo"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 12), // "slotEditRepo"
QT_MOC_LITERAL(4, 38, 14), // "slotRemoveRepo"
QT_MOC_LITERAL(5, 53, 18), // "slotSnippetClicked"
QT_MOC_LITERAL(6, 72, 5), // "index"
QT_MOC_LITERAL(7, 78, 15), // "slotEditSnippet"
QT_MOC_LITERAL(8, 94, 17), // "slotRemoveSnippet"
QT_MOC_LITERAL(9, 112, 14), // "slotAddSnippet"
QT_MOC_LITERAL(10, 127, 8), // "slotGHNS"
QT_MOC_LITERAL(11, 136, 17), // "slotSnippetToGHNS"
QT_MOC_LITERAL(12, 154, 11), // "contextMenu"
QT_MOC_LITERAL(13, 166, 3), // "pos"
QT_MOC_LITERAL(14, 170, 15), // "validateActions"
QT_MOC_LITERAL(15, 186, 11), // "eventFilter"
QT_MOC_LITERAL(16, 198, 7) // "QEvent*"

    },
    "SnippetView\0slotAddRepo\0\0slotEditRepo\0"
    "slotRemoveRepo\0slotSnippetClicked\0"
    "index\0slotEditSnippet\0slotRemoveSnippet\0"
    "slotAddSnippet\0slotGHNS\0slotSnippetToGHNS\0"
    "contextMenu\0pos\0validateActions\0"
    "eventFilter\0QEvent*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SnippetView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x08 /* Private */,
       3,    0,   75,    2, 0x08 /* Private */,
       4,    0,   76,    2, 0x08 /* Private */,
       5,    1,   77,    2, 0x08 /* Private */,
       7,    0,   80,    2, 0x08 /* Private */,
       8,    0,   81,    2, 0x08 /* Private */,
       9,    0,   82,    2, 0x08 /* Private */,
      10,    0,   83,    2, 0x08 /* Private */,
      11,    0,   84,    2, 0x08 /* Private */,
      12,    1,   85,    2, 0x08 /* Private */,
      14,    0,   88,    2, 0x08 /* Private */,
      15,    2,   89,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   13,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 16,    2,    2,

       0        // eod
};

void SnippetView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SnippetView *_t = static_cast<SnippetView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotAddRepo(); break;
        case 1: _t->slotEditRepo(); break;
        case 2: _t->slotRemoveRepo(); break;
        case 3: _t->slotSnippetClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: _t->slotEditSnippet(); break;
        case 5: _t->slotRemoveSnippet(); break;
        case 6: _t->slotAddSnippet(); break;
        case 7: _t->slotGHNS(); break;
        case 8: _t->slotSnippetToGHNS(); break;
        case 9: _t->contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 10: _t->validateActions(); break;
        case 11: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        default: ;
        }
    }
}

const QMetaObject SnippetView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_SnippetView.data,
      qt_meta_data_SnippetView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *SnippetView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SnippetView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_SnippetView.stringdata0))
        return static_cast<void*>(const_cast< SnippetView*>(this));
    if (!strcmp(_clname, "Ui::SnippetViewBase"))
        return static_cast< Ui::SnippetViewBase*>(const_cast< SnippetView*>(this));
    return QWidget::qt_metacast(_clname);
}

int SnippetView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
