/****************************************************************************
** Meta object code from reading C++ file 'kateviewspace.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kate/kateviewspace.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateviewspace.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateViewSpace_t {
    QByteArrayData data[25];
    char stringdata0[308];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateViewSpace_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateViewSpace_t qt_meta_stringdata_KateViewSpace = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KateViewSpace"
QT_MOC_LITERAL(1, 14, 17), // "documentDestroyed"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 3), // "doc"
QT_MOC_LITERAL(4, 37, 18), // "updateDocumentName"
QT_MOC_LITERAL(5, 56, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(6, 79, 19), // "updateDocumentState"
QT_MOC_LITERAL(7, 99, 16), // "statusBarToggled"
QT_MOC_LITERAL(8, 116, 13), // "tabBarToggled"
QT_MOC_LITERAL(9, 130, 10), // "changeView"
QT_MOC_LITERAL(10, 141, 8), // "buttonId"
QT_MOC_LITERAL(11, 150, 10), // "makeActive"
QT_MOC_LITERAL(12, 161, 16), // "focusCurrentView"
QT_MOC_LITERAL(13, 178, 9), // "insertTab"
QT_MOC_LITERAL(14, 188, 5), // "index"
QT_MOC_LITERAL(15, 194, 9), // "removeTab"
QT_MOC_LITERAL(16, 204, 10), // "removeTabs"
QT_MOC_LITERAL(17, 215, 5), // "count"
QT_MOC_LITERAL(18, 221, 7), // "addTabs"
QT_MOC_LITERAL(19, 229, 15), // "closeTabRequest"
QT_MOC_LITERAL(20, 245, 2), // "id"
QT_MOC_LITERAL(21, 248, 15), // "showContextMenu"
QT_MOC_LITERAL(22, 264, 9), // "globalPos"
QT_MOC_LITERAL(23, 274, 17), // "createNewDocument"
QT_MOC_LITERAL(24, 292, 15) // "updateQuickOpen"

    },
    "KateViewSpace\0documentDestroyed\0\0doc\0"
    "updateDocumentName\0KTextEditor::Document*\0"
    "updateDocumentState\0statusBarToggled\0"
    "tabBarToggled\0changeView\0buttonId\0"
    "makeActive\0focusCurrentView\0insertTab\0"
    "index\0removeTab\0removeTabs\0count\0"
    "addTabs\0closeTabRequest\0id\0showContextMenu\0"
    "globalPos\0createNewDocument\0updateQuickOpen"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateViewSpace[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x0a /* Public */,
       4,    1,   97,    2, 0x0a /* Public */,
       6,    1,  100,    2, 0x0a /* Public */,
       7,    0,  103,    2, 0x08 /* Private */,
       8,    0,  104,    2, 0x08 /* Private */,
       9,    1,  105,    2, 0x08 /* Private */,
      11,    1,  108,    2, 0x08 /* Private */,
      11,    0,  111,    2, 0x28 /* Private | MethodCloned */,
      13,    2,  112,    2, 0x08 /* Private */,
      15,    2,  117,    2, 0x08 /* Private */,
      16,    1,  122,    2, 0x08 /* Private */,
      18,    1,  125,    2, 0x08 /* Private */,
      19,    1,  128,    2, 0x08 /* Private */,
      21,    2,  131,    2, 0x08 /* Private */,
      23,    0,  136,    2, 0x08 /* Private */,
      24,    0,  137,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QObjectStar,    3,
    QMetaType::Void, 0x80000000 | 5,    3,
    QMetaType::Void, 0x80000000 | 5,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 5,   14,    3,
    QMetaType::Int, 0x80000000 | 5, QMetaType::Bool,    3,    1,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::QPoint,   20,   22,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateViewSpace::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateViewSpace *_t = static_cast<KateViewSpace *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->documentDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 1: _t->updateDocumentName((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->updateDocumentState((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->statusBarToggled(); break;
        case 4: _t->tabBarToggled(); break;
        case 5: _t->changeView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->makeActive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->makeActive(); break;
        case 8: _t->insertTab((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Document*(*)>(_a[2]))); break;
        case 9: { int _r = _t->removeTab((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 10: _t->removeTabs((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->addTabs((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->closeTabRequest((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->showContextMenu((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 14: _t->createNewDocument(); break;
        case 15: _t->updateQuickOpen(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KateViewSpace::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KateViewSpace.data,
      qt_meta_data_KateViewSpace,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateViewSpace::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewSpace::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateViewSpace.stringdata0))
        return static_cast<void*>(const_cast< KateViewSpace*>(this));
    return QWidget::qt_metacast(_clname);
}

int KateViewSpace::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
