/****************************************************************************
** Meta object code from reading C++ file 'TargetModel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/katebuild-plugin/TargetModel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TargetModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_TargetModel_t {
    QByteArrayData data[20];
    char stringdata0[205];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TargetModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TargetModel_t qt_meta_stringdata_TargetModel = {
    {
QT_MOC_LITERAL(0, 0, 11), // "TargetModel"
QT_MOC_LITERAL(1, 12, 5), // "clear"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 12), // "addTargetSet"
QT_MOC_LITERAL(4, 32, 7), // "setName"
QT_MOC_LITERAL(5, 40, 7), // "workDir"
QT_MOC_LITERAL(6, 48, 10), // "addCommand"
QT_MOC_LITERAL(7, 59, 7), // "rootRow"
QT_MOC_LITERAL(8, 67, 7), // "cmdName"
QT_MOC_LITERAL(9, 75, 7), // "command"
QT_MOC_LITERAL(10, 83, 15), // "copyTargetOrSet"
QT_MOC_LITERAL(11, 99, 5), // "index"
QT_MOC_LITERAL(12, 105, 13), // "defaultTarget"
QT_MOC_LITERAL(13, 119, 10), // "deleteItem"
QT_MOC_LITERAL(14, 130, 15), // "deleteTargetSet"
QT_MOC_LITERAL(15, 146, 9), // "targetSet"
QT_MOC_LITERAL(16, 156, 10), // "targetSets"
QT_MOC_LITERAL(17, 167, 16), // "QList<TargetSet>"
QT_MOC_LITERAL(18, 184, 9), // "itemIndex"
QT_MOC_LITERAL(19, 194, 10) // "targetName"

    },
    "TargetModel\0clear\0\0addTargetSet\0setName\0"
    "workDir\0addCommand\0rootRow\0cmdName\0"
    "command\0copyTargetOrSet\0index\0"
    "defaultTarget\0deleteItem\0deleteTargetSet\0"
    "targetSet\0targetSets\0QList<TargetSet>\0"
    "itemIndex\0targetName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TargetModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x0a /* Public */,
       3,    2,   75,    2, 0x0a /* Public */,
       6,    3,   80,    2, 0x0a /* Public */,
      10,    1,   87,    2, 0x0a /* Public */,
      12,    1,   90,    2, 0x0a /* Public */,
      13,    1,   93,    2, 0x0a /* Public */,
      14,    1,   96,    2, 0x0a /* Public */,
      16,    0,   99,    2, 0x0a /* Public */,
       9,    1,  100,    2, 0x0a /* Public */,
       8,    1,  103,    2, 0x0a /* Public */,
       5,    1,  106,    2, 0x0a /* Public */,
      19,    1,  109,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Int, QMetaType::QString, QMetaType::QString,    4,    5,
    QMetaType::QModelIndex, QMetaType::Int, QMetaType::QString, QMetaType::QString,    7,    8,    9,
    QMetaType::QModelIndex, QMetaType::QModelIndex,   11,
    QMetaType::QModelIndex, QMetaType::QModelIndex,   11,
    QMetaType::Void, QMetaType::QModelIndex,   11,
    QMetaType::Void, QMetaType::QString,   15,
    0x80000000 | 17,
    QMetaType::QString, QMetaType::QModelIndex,   18,
    QMetaType::QString, QMetaType::QModelIndex,   18,
    QMetaType::QString, QMetaType::QModelIndex,   18,
    QMetaType::QString, QMetaType::QModelIndex,   18,

       0        // eod
};

void TargetModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TargetModel *_t = static_cast<TargetModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->clear(); break;
        case 1: { int _r = _t->addTargetSet((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 2: { QModelIndex _r = _t->addCommand((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = _r; }  break;
        case 3: { QModelIndex _r = _t->copyTargetOrSet((*reinterpret_cast< const QModelIndex(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = _r; }  break;
        case 4: { QModelIndex _r = _t->defaultTarget((*reinterpret_cast< const QModelIndex(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = _r; }  break;
        case 5: _t->deleteItem((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 6: _t->deleteTargetSet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: { QList<TargetSet> _r = _t->targetSets();
            if (_a[0]) *reinterpret_cast< QList<TargetSet>*>(_a[0]) = _r; }  break;
        case 8: { QString _r = _t->command((*reinterpret_cast< const QModelIndex(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 9: { QString _r = _t->cmdName((*reinterpret_cast< const QModelIndex(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 10: { QString _r = _t->workDir((*reinterpret_cast< const QModelIndex(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 11: { QString _r = _t->targetName((*reinterpret_cast< const QModelIndex(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        default: ;
        }
    }
}

const QMetaObject TargetModel::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_TargetModel.data,
      qt_meta_data_TargetModel,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *TargetModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TargetModel::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_TargetModel.stringdata0))
        return static_cast<void*>(const_cast< TargetModel*>(this));
    return QAbstractItemModel::qt_metacast(_clname);
}

int TargetModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
