/****************************************************************************
** Meta object code from reading C++ file 'kateprojectpluginview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/project/kateprojectpluginview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateprojectpluginview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateProjectPluginView_t {
    QByteArrayData data[32];
    char stringdata0[525];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateProjectPluginView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateProjectPluginView_t qt_meta_stringdata_KateProjectPluginView = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KateProjectPluginView"
QT_MOC_LITERAL(1, 22, 22), // "projectFileNameChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 17), // "projectMapChanged"
QT_MOC_LITERAL(4, 64, 17), // "projectLookupWord"
QT_MOC_LITERAL(5, 82, 4), // "word"
QT_MOC_LITERAL(6, 87, 14), // "viewForProject"
QT_MOC_LITERAL(7, 102, 44), // "QPair<KateProjectView*,KatePr..."
QT_MOC_LITERAL(8, 147, 12), // "KateProject*"
QT_MOC_LITERAL(9, 160, 7), // "project"
QT_MOC_LITERAL(10, 168, 15), // "slotViewCreated"
QT_MOC_LITERAL(11, 184, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(12, 203, 4), // "view"
QT_MOC_LITERAL(13, 208, 17), // "slotViewDestroyed"
QT_MOC_LITERAL(14, 226, 15), // "slotProjectPrev"
QT_MOC_LITERAL(15, 242, 15), // "slotProjectNext"
QT_MOC_LITERAL(16, 258, 17), // "slotProjectReload"
QT_MOC_LITERAL(17, 276, 16), // "slotProjectIndex"
QT_MOC_LITERAL(18, 293, 15), // "slotViewChanged"
QT_MOC_LITERAL(19, 309, 18), // "slotCurrentChanged"
QT_MOC_LITERAL(20, 328, 5), // "index"
QT_MOC_LITERAL(21, 334, 22), // "slotDocumentUrlChanged"
QT_MOC_LITERAL(22, 357, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(23, 380, 8), // "document"
QT_MOC_LITERAL(24, 389, 26), // "slotContextMenuAboutToShow"
QT_MOC_LITERAL(25, 416, 15), // "projectFileName"
QT_MOC_LITERAL(26, 432, 11), // "projectName"
QT_MOC_LITERAL(27, 444, 14), // "projectBaseDir"
QT_MOC_LITERAL(28, 459, 10), // "projectMap"
QT_MOC_LITERAL(29, 470, 12), // "projectFiles"
QT_MOC_LITERAL(30, 483, 24), // "allProjectsCommonBaseDir"
QT_MOC_LITERAL(31, 508, 16) // "allProjectsFiles"

    },
    "KateProjectPluginView\0projectFileNameChanged\0"
    "\0projectMapChanged\0projectLookupWord\0"
    "word\0viewForProject\0"
    "QPair<KateProjectView*,KateProjectInfoView*>\0"
    "KateProject*\0project\0slotViewCreated\0"
    "KTextEditor::View*\0view\0slotViewDestroyed\0"
    "slotProjectPrev\0slotProjectNext\0"
    "slotProjectReload\0slotProjectIndex\0"
    "slotViewChanged\0slotCurrentChanged\0"
    "index\0slotDocumentUrlChanged\0"
    "KTextEditor::Document*\0document\0"
    "slotContextMenuAboutToShow\0projectFileName\0"
    "projectName\0projectBaseDir\0projectMap\0"
    "projectFiles\0allProjectsCommonBaseDir\0"
    "allProjectsFiles"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateProjectPluginView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       7,  110, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x06 /* Public */,
       3,    0,   85,    2, 0x06 /* Public */,
       4,    1,   86,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   89,    2, 0x0a /* Public */,
      10,    1,   92,    2, 0x08 /* Private */,
      13,    1,   95,    2, 0x08 /* Private */,
      14,    0,   98,    2, 0x08 /* Private */,
      15,    0,   99,    2, 0x08 /* Private */,
      16,    0,  100,    2, 0x08 /* Private */,
      17,    0,  101,    2, 0x08 /* Private */,
      18,    0,  102,    2, 0x08 /* Private */,
      19,    1,  103,    2, 0x08 /* Private */,
      21,    1,  106,    2, 0x08 /* Private */,
      24,    0,  109,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,

 // slots: parameters
    0x80000000 | 7, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::QObjectStar,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   20,
    QMetaType::Void, 0x80000000 | 22,   23,
    QMetaType::Void,

 // properties: name, type, flags
      25, QMetaType::QString, 0x00495001,
      26, QMetaType::QString, 0x00095001,
      27, QMetaType::QString, 0x00095001,
      28, QMetaType::QVariantMap, 0x00495001,
      29, QMetaType::QStringList, 0x00095001,
      30, QMetaType::QString, 0x00095001,
      31, QMetaType::QStringList, 0x00095001,

 // properties: notify_signal_id
       0,
       0,
       0,
       1,
       0,
       0,
       0,

       0        // eod
};

void KateProjectPluginView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateProjectPluginView *_t = static_cast<KateProjectPluginView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->projectFileNameChanged(); break;
        case 1: _t->projectMapChanged(); break;
        case 2: _t->projectLookupWord((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: { QPair<KateProjectView*,KateProjectInfoView*> _r = _t->viewForProject((*reinterpret_cast< KateProject*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPair<KateProjectView*,KateProjectInfoView*>*>(_a[0]) = _r; }  break;
        case 4: _t->slotViewCreated((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 5: _t->slotViewDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 6: _t->slotProjectPrev(); break;
        case 7: _t->slotProjectNext(); break;
        case 8: _t->slotProjectReload(); break;
        case 9: _t->slotProjectIndex(); break;
        case 10: _t->slotViewChanged(); break;
        case 11: _t->slotCurrentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->slotDocumentUrlChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 13: _t->slotContextMenuAboutToShow(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KateProject* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KateProjectPluginView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProjectPluginView::projectFileNameChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KateProjectPluginView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProjectPluginView::projectMapChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KateProjectPluginView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KateProjectPluginView::projectLookupWord)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KateProjectPluginView *_t = static_cast<KateProjectPluginView *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->projectFileName(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->projectName(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->projectBaseDir(); break;
        case 3: *reinterpret_cast< QVariantMap*>(_v) = _t->projectMap(); break;
        case 4: *reinterpret_cast< QStringList*>(_v) = _t->projectFiles(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->allProjectsCommonBaseDir(); break;
        case 6: *reinterpret_cast< QStringList*>(_v) = _t->allProjectsFiles(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KateProjectPluginView::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KateProjectPluginView.data,
      qt_meta_data_KateProjectPluginView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateProjectPluginView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateProjectPluginView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateProjectPluginView.stringdata0))
        return static_cast<void*>(const_cast< KateProjectPluginView*>(this));
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(const_cast< KateProjectPluginView*>(this));
    return QObject::qt_metacast(_clname);
}

int KateProjectPluginView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KateProjectPluginView::projectFileNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void KateProjectPluginView::projectMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void KateProjectPluginView::projectLookupWord(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_END_MOC_NAMESPACE
