/****************************************************************************
** Meta object code from reading C++ file 'kwrite.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kate-17.04.3/kwrite/kwrite.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwrite.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KWrite_t {
    QByteArrayData data[22];
    char stringdata0[251];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KWrite_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KWrite_t qt_meta_stringdata_KWrite = {
    {
QT_MOC_LITERAL(0, 0, 6), // "KWrite"
QT_MOC_LITERAL(1, 7, 7), // "slotNew"
QT_MOC_LITERAL(2, 15, 0), // ""
QT_MOC_LITERAL(3, 16, 9), // "slotFlush"
QT_MOC_LITERAL(4, 26, 8), // "slotOpen"
QT_MOC_LITERAL(5, 35, 3), // "url"
QT_MOC_LITERAL(6, 39, 7), // "newView"
QT_MOC_LITERAL(7, 47, 15), // "toggleStatusBar"
QT_MOC_LITERAL(8, 63, 13), // "toggleMenuBar"
QT_MOC_LITERAL(9, 77, 11), // "showMessage"
QT_MOC_LITERAL(10, 89, 8), // "editKeys"
QT_MOC_LITERAL(11, 98, 12), // "editToolbars"
QT_MOC_LITERAL(12, 111, 11), // "aboutEditor"
QT_MOC_LITERAL(13, 123, 15), // "modifiedChanged"
QT_MOC_LITERAL(14, 139, 20), // "slotNewToolbarConfig"
QT_MOC_LITERAL(15, 160, 13), // "slotDropEvent"
QT_MOC_LITERAL(16, 174, 11), // "QDropEvent*"
QT_MOC_LITERAL(17, 186, 17), // "slotEnableActions"
QT_MOC_LITERAL(18, 204, 6), // "enable"
QT_MOC_LITERAL(19, 211, 10), // "urlChanged"
QT_MOC_LITERAL(20, 222, 8), // "sizeHint"
QT_MOC_LITERAL(21, 231, 19) // "documentNameChanged"

    },
    "KWrite\0slotNew\0\0slotFlush\0slotOpen\0"
    "url\0newView\0toggleStatusBar\0toggleMenuBar\0"
    "showMessage\0editKeys\0editToolbars\0"
    "aboutEditor\0modifiedChanged\0"
    "slotNewToolbarConfig\0slotDropEvent\0"
    "QDropEvent*\0slotEnableActions\0enable\0"
    "urlChanged\0sizeHint\0documentNameChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KWrite[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x0a /* Public */,
       3,    0,  105,    2, 0x0a /* Public */,
       4,    0,  106,    2, 0x0a /* Public */,
       4,    1,  107,    2, 0x0a /* Public */,
       6,    0,  110,    2, 0x0a /* Public */,
       7,    0,  111,    2, 0x0a /* Public */,
       8,    1,  112,    2, 0x0a /* Public */,
       8,    0,  115,    2, 0x2a /* Public | MethodCloned */,
      10,    0,  116,    2, 0x0a /* Public */,
      11,    0,  117,    2, 0x0a /* Public */,
      12,    0,  118,    2, 0x0a /* Public */,
      13,    0,  119,    2, 0x0a /* Public */,
      14,    0,  120,    2, 0x08 /* Private */,
      15,    1,  121,    2, 0x0a /* Public */,
      17,    1,  124,    2, 0x0a /* Public */,
      19,    0,  127,    2, 0x0a /* Public */,
      20,    0,  128,    2, 0x0a /* Public */,
      21,    0,  129,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::QSize,
    QMetaType::Void,

       0        // eod
};

void KWrite::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KWrite *_t = static_cast<KWrite *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotNew(); break;
        case 1: _t->slotFlush(); break;
        case 2: _t->slotOpen(); break;
        case 3: _t->slotOpen((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->newView(); break;
        case 5: _t->toggleStatusBar(); break;
        case 6: _t->toggleMenuBar((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->toggleMenuBar(); break;
        case 8: _t->editKeys(); break;
        case 9: _t->editToolbars(); break;
        case 10: _t->aboutEditor(); break;
        case 11: _t->modifiedChanged(); break;
        case 12: _t->slotNewToolbarConfig(); break;
        case 13: _t->slotDropEvent((*reinterpret_cast< QDropEvent*(*)>(_a[1]))); break;
        case 14: _t->slotEnableActions((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->urlChanged(); break;
        case 16: { QSize _r = _t->sizeHint();
            if (_a[0]) *reinterpret_cast< QSize*>(_a[0]) = _r; }  break;
        case 17: _t->documentNameChanged(); break;
        default: ;
        }
    }
}

const QMetaObject KWrite::staticMetaObject = {
    { &KParts::MainWindow::staticMetaObject, qt_meta_stringdata_KWrite.data,
      qt_meta_data_KWrite,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KWrite::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWrite::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KWrite.stringdata0))
        return static_cast<void*>(const_cast< KWrite*>(this));
    return KParts::MainWindow::qt_metacast(_clname);
}

int KWrite::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
