/****************************************************************************
** Meta object code from reading C++ file 'katefilebrowser.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kate-17.04.3/addons/filebrowser/katefilebrowser.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katefilebrowser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KateFileBrowser_t {
    QByteArrayData data[14];
    char stringdata0[182];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateFileBrowser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateFileBrowser_t qt_meta_stringdata_KateFileBrowser = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KateFileBrowser"
QT_MOC_LITERAL(1, 16, 16), // "slotFilterChange"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 6), // "setDir"
QT_MOC_LITERAL(4, 41, 3), // "url"
QT_MOC_LITERAL(5, 45, 19), // "selectorViewChanged"
QT_MOC_LITERAL(6, 65, 18), // "QAbstractItemView*"
QT_MOC_LITERAL(7, 84, 12), // "fileSelected"
QT_MOC_LITERAL(8, 97, 9), // "KFileItem"
QT_MOC_LITERAL(9, 107, 17), // "updateDirOperator"
QT_MOC_LITERAL(10, 125, 1), // "u"
QT_MOC_LITERAL(11, 127, 18), // "updateUrlNavigator"
QT_MOC_LITERAL(12, 146, 20), // "setActiveDocumentDir"
QT_MOC_LITERAL(13, 167, 14) // "autoSyncFolder"

    },
    "KateFileBrowser\0slotFilterChange\0\0"
    "setDir\0url\0selectorViewChanged\0"
    "QAbstractItemView*\0fileSelected\0"
    "KFileItem\0updateDirOperator\0u\0"
    "updateUrlNavigator\0setActiveDocumentDir\0"
    "autoSyncFolder"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateFileBrowser[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x0a /* Public */,
       3,    1,   62,    2, 0x0a /* Public */,
       3,    1,   65,    2, 0x0a /* Public */,
       5,    1,   68,    2, 0x0a /* Public */,
       7,    1,   71,    2, 0x08 /* Private */,
       9,    1,   74,    2, 0x08 /* Private */,
      11,    1,   77,    2, 0x08 /* Private */,
      12,    0,   80,    2, 0x08 /* Private */,
      13,    0,   81,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, QMetaType::QUrl,   10,
    QMetaType::Void, QMetaType::QUrl,   10,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateFileBrowser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KateFileBrowser *_t = static_cast<KateFileBrowser *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotFilterChange((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->setDir((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 2: _t->setDir((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->selectorViewChanged((*reinterpret_cast< QAbstractItemView*(*)>(_a[1]))); break;
        case 4: _t->fileSelected((*reinterpret_cast< const KFileItem(*)>(_a[1]))); break;
        case 5: _t->updateDirOperator((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 6: _t->updateUrlNavigator((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 7: _t->setActiveDocumentDir(); break;
        case 8: _t->autoSyncFolder(); break;
        default: ;
        }
    }
}

const QMetaObject KateFileBrowser::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KateFileBrowser.data,
      qt_meta_data_KateFileBrowser,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KateFileBrowser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateFileBrowser::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KateFileBrowser.stringdata0))
        return static_cast<void*>(const_cast< KateFileBrowser*>(this));
    return QWidget::qt_metacast(_clname);
}

int KateFileBrowser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
